-- * PLSQL:       co2_barometric_files_pkg.sql Version 1.1 09/01/2016
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the pressure File information for
-- *              a specific well.
-- * Copyright (c) 2016 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_barometric_files_pkg AS
  PROCEDURE getXML;
  PROCEDURE getXML(sLOC IN VARCHAR2);
  PROCEDURE getXML(sKID IN VARCHAR2);
  PROCEDURE dtd_and_columns;
END co2_barometric_files_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_barometric_files_pkg AS
--
  PROCEDURE getXML IS
--
  l_count         NUMBER(6);     -- Total Number of LAS Files
-- Pressure File Information
  o_kid   iqstrat.barometric_files.kid%TYPE;     
  o_type  iqstrat.barometric_files.file_type%TYPE; 
  o_url   iqstrat.barometric_files.file_url%TYPE; 
  o_path  iqstrat.barometric_files.file_path%TYPE; 
  o_name  iqstrat.barometric_files.file_name%TYPE; 
  o_loc   iqstrat.barometric_files.file_location%TYPE; 
  o_zone  iqstrat.barometric_files.zone%TYPE;
  o_start VARCHAR2(40);
  o_end   VARCHAR2(40);
  o_date  VARCHAR2(40);
--
-- File Cursor to retrieve all the Files for pressure data
--
  CURSOR crsr IS
    SELECT kid,                   -- Primary Key for the LAS File
           file_type,             -- File Type - CSV, XML, etc.
           file_url,              -- URL File Path
           file_path,             -- Unix File Path for URL Ref
           file_name,             -- Filename of File
           file_location,         -- File Location
           TO_CHAR(start_Date, 'YYYYMMDDHH24MISS') AS ORDER_DATE,
           TO_CHAR(start_date, 'YYYY-MM-DD HH24:MI:SS'),  -- Starting Time
           TO_CHAR(end_date,   'YYYY-MM-DD HH24:MI:SS')   -- Ending Time
      FROM barometric_files
     WHERE file_type = 'CSV'
    ORDER BY ORDER_DATE;
--
  BEGIN
--
--  Count the total number of LAS Files for a specific well.
--
    SELECT COUNT(kid)
      INTO l_count                   -- Total Number of Digital LAS Files
      FROM barometric_files
     WHERE file_type = 'CSV';
--
--  Build XML File
--
    dtd_and_columns;
--
    OPEN crsr;
--
    htp.print('<files records="'||l_count||'">');
--
    LOOP
      FETCH crsr
       INTO o_kid,
            o_type,
            o_url,
            o_path,
            o_name,
            o_loc,
            o_date,
            o_start,
            o_end;
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('  <data key="'||o_kid||'" '||
                        'type="'||o_type||'" '|| 
                        'url="'||o_url||'" '||
                        'path="'||o_path||'" '||
                        'filename="'||o_name||'" '||
                        'location="'||o_loc||'" '||
                        'start="'||o_start||'" '||
                        'end="'||o_end||'"/>');
--
    END LOOP;
    htp.print('</files>');
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END getXML;
--
--
  PROCEDURE getXML(sLOC IN VARCHAR2) IS
--
  l_count         NUMBER(6);     -- Total Number of LAS Files
-- Pressure File Information
  o_kid   iqstrat.barometric_files.kid%TYPE;     
  o_type  iqstrat.barometric_files.file_type%TYPE; 
  o_url   iqstrat.barometric_files.file_url%TYPE; 
  o_path  iqstrat.barometric_files.file_path%TYPE; 
  o_name  iqstrat.barometric_files.file_name%TYPE; 
  o_loc   iqstrat.barometric_files.file_location%TYPE; 
  o_zone  iqstrat.barometric_files.zone%TYPE;
  o_start VARCHAR2(40);
  o_end   VARCHAR2(40);
--
-- File Cursor to retrieve all the Files for pressure data
--
  CURSOR crsr (sLOC VARCHAR2) IS
    SELECT kid,                   -- Primary Key for the LAS File
           file_type,             -- File Type - CSV, XML, etc.
           file_url,              -- URL File Path
           file_path,             -- Unix File Path for URL Ref
           file_name,             -- Filename of File
           file_location,         -- File Location
           TO_CHAR(start_date, 'YYYY-MM-DD HH24:MI:SS'),  -- Starting Time
           TO_CHAR(end_date,   'YYYY-MM-DD HH24:MI:SS')   -- Ending Time
      FROM barometric_files
     WHERE file_location = sLOC;
--
  BEGIN
--
--  Count the total number of LAS Files for a specific well.
--
    SELECT COUNT(kid)
      INTO l_count                   -- Total Number of Digital LAS Files
      FROM barometric_files
     WHERE file_location = sLOC;
--
--  Build XML File
--
    dtd_and_columns;
--
    OPEN crsr(sLOC);
--
    htp.print('<files records="'||l_count||'">');
--
    LOOP
      FETCH crsr
       INTO o_kid,
            o_type,
            o_url,
            o_path,
            o_name,
            o_loc,
            o_start,
            o_end;
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('  <data key="'||o_kid||'" '||
                        'type="'||o_type||'" '|| 
                        'url="'||o_url||'" '||
                        'path="'||o_path||'" '||
                        'filename="'||o_name||'" '||
                        'location="'||o_loc||'" '||
                        'start="'||o_start||'" '||
                        'end="'||o_end||'"/>');
--
    END LOOP;
    htp.print('</files>');
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END getXML;
--
--
  PROCEDURE getXML(sKID IN VARCHAR2) IS
--
  l_count         NUMBER(6);     -- Total Number of LAS Files
-- Pressure File Information
  o_kid   iqstrat.barometric_files.kid%TYPE;     
  o_type  iqstrat.barometric_files.file_type%TYPE; 
  o_url   iqstrat.barometric_files.file_url%TYPE; 
  o_path  iqstrat.barometric_files.file_path%TYPE; 
  o_name  iqstrat.barometric_files.file_name%TYPE; 
  o_loc   iqstrat.barometric_files.file_location%TYPE; 
  o_zone  iqstrat.barometric_files.zone%TYPE;
  o_start VARCHAR2(40);
  o_end   VARCHAR2(40);
--
-- File Cursor to retrieve all the Files for pressure data
--
  CURSOR crsr (sKID VARCHAR2) IS
    SELECT kid,                   -- Primary Key for the LAS File
           file_type,             -- File Type - CSV, XML, etc.
           file_url,              -- URL File Path
           file_path,             -- Unix File Path for URL Ref
           file_name,             -- Filename of File
           file_location,         -- File Location
           TO_CHAR(start_date, 'YYYY-MM-DD HH24:MI:SS'),  -- Starting Time
           TO_CHAR(end_date,   'YYYY-MM-DD HH24:MI:SS')   -- Ending Time
      FROM barometric_files
     WHERE kid = sKID;
--
  BEGIN
--
--  Count the total number of LAS Files for a specific well.
--
    SELECT COUNT(kid)
      INTO l_count                   -- Total Number of Digital LAS Files
      FROM barometric_files
     WHERE kid = sKID;
--
--  Build XML File
--
    dtd_and_columns;
--
    OPEN crsr(sKID);
--
    htp.print('<files records="'||l_count||'">');
--
    LOOP
      FETCH crsr
       INTO o_kid,
            o_type,
            o_url,
            o_path,
            o_name,
            o_loc,
            o_start,
            o_end;
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('  <data key="'||o_kid||'" '||
                        'type="'||o_type||'" '|| 
                        'url="'||o_url||'" '||
                        'path="'||o_path||'" '||
                        'filename="'||o_name||'" '||
                        'location="'||o_loc||'" '||
                        'start="'||o_start||'" '||
                        'end="'||o_end||'"/>');
--
    END LOOP;
    htp.print('</files>');
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END getXML;
--
--
-- PROCEDURE    dtd_and_columns
-- Description: This procedure will build the DTD and the Columns in the core
--              data table.
  PROCEDURE dtd_and_columns IS
--
  BEGIN
--
    htp.print('<?xml version="1.0"?>');
    htp.print('<!DOCTYPE files [');
    htp.print('<!ELEMENT files (data*)+>');
    htp.print('<!ATTLIST files records CDATA #REQUIRED>');
    htp.print('<!ELEMENT data  EMPTY>');
    htp.print('<!ATTLIST data key      CDATA #REQUIRED');
    htp.print('               type     CDATA #IMPLIED');
    htp.print('               url      CDATA #IMPLIED');
    htp.print('               path     CDATA #REQUIRED');
    htp.print('               filename CDATA #REQUIRED');
    htp.print('               location CDATA #IMPLIED');
    htp.print('               start    CDATA #IMPLIED');
    htp.print('               end      CDATA #IMPLIED>]>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END dtd_and_columns;
END co2_barometric_files_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON co2_barometric_files_pkg to apex_public_user;
