-- * PLSQL:       co2_brine_data_summary_pkg.sql Version 1.1 05/01/2015
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the Headers information.
-- * Copyright (c) 2015 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_brine_data_summary_pkg AS
  PROCEDURE build_web_page(sKID IN VARCHAR2);
  PROCEDURE build_table(sKID IN VARCHAR2);
  PROCEDURE build_left_column(sKID IN VARCHAR2);
  PROCEDURE build_anions_column(sKID IN VARCHAR2);
  PROCEDURE build_cations_column(sKID IN VARCHAR2);
  PROCEDURE build_table_base(sKID IN VARCHAR2);
  PROCEDURE build_title_icons(sTitle IN VARCHAR2, sLAB IN VARCHAR2);
--  
  FUNCTION sum_TDS(sKID IN VARCHAR2) RETURN VARCHAR2;
  FUNCTION is_number(str IN VARCHAR2) RETURN VARCHAR2;
END co2_brine_data_summary_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_brine_data_summary_pkg AS
--
-- PROCEDURE    build_web_page()
-- Description: This procedure will buiild the single brine data web page.
-- * Input:     sKID = brine data kid 
-- * Output:    Summary Web Page for specific brine data record.
--
  PROCEDURE build_web_page(sKID IN VARCHAR2) IS
--  
    l_cnt NUMBER;
    o_LAB VARCHAR2(255);     
--
    o_well_kid iqstrat.co2_brine_sample.well_kid%TYPE;       -- Well KID
    o_lab_kid  iqstrat.co2_brine_sample.lab_kid%TYPE;        -- LAB KID
    o_sampled  VARCHAR2(60);                                 -- Sampled Date
    o_received VARCHAR2(60);                                 -- Recieved Date
    o_reported VARCHAR2(60);                                 -- Reported Date
    o_desc     iqstrat.co2_brine_sample.description%TYPE;    -- description
--  
    o_kid      iqstrat.CO2_brine_wells.kid%TYPE;             -- well kid
    o_api      iqstrat.CO2_brine_wells.api_number%TYPE;      -- API-Number
    o_WELL     iqstrat.CO2_brine_wells.name%TYPE;            -- well name
    o_TRS      VARCHAR2(60);                                 -- TRS
    o_LAT      iqstrat.CO2_brine_wells.nad27_latitude%TYPE;  -- latitude
    o_LONG     iqstrat.CO2_brine_wells.nad27_longitude%TYPE; -- longitude
    o_GL       iqstrat.CO2_brine_wells.elevation_gl%TYPE;    -- GL
    o_KB       iqstrat.CO2_brine_wells.elevation_kb%TYPE;    -- KB
    o_DF       iqstrat.CO2_brine_wells.elevation_df%TYPE;    -- DF
--    
-- Cursors
--
    CURSOR crsrh(sKID IN VARCHAR2) IS
      SELECT well_kid,
             lab_kid,
             NVL(TO_CHAR(sampled_date, 'MM/DD/YYYY HH24:MI'), '&nbsp'),
             NVL(TO_CHAR(recieved_date,'MM/DD/YYYY HH24:MI'), '&nbsp'),
             NVL(TO_CHAR(reported_date,'MM/DD/YYYY HH24:MI'), '&nbsp'),
             description
        FROM co2_brine_sample
       WHERE kid = sKID;
--
    CURSOR crsrw(sKID IN VARCHAR2) IS
      SELECT name,
             api_number,
             'T'||township||township_direction||' '||
             'R'||range||range_direction||' '||
             'S'||section,
             nad27_longitude,
             nad27_latitude,
             elevation_gl,
             elevation_kb,
             elevation_df
        FROM co2_brine_wells
       WHERE kid = sKID;
--
    CURSOR crsrw1(sKID IN VARCHAR2) IS
      SELECT lease_name||' '||well_name,
             api_number,
             'T'||township||township_direction||' '||
             'R'||range||range_direction||' '||
             'S'||section,
             nad27_longitude,
             nad27_latitude,
             elevation_gl,
             elevation_kb,
             elevation_df
        FROM co2_brine_well
       WHERE kid = sKID;
--
  BEGIN
--
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('CO2 Well Brine Data Summary Page');
    htp.headClose;
--
    htp.print('<BODY>');
--    
    OPEN crsrh(sKID);
    LOOP
      FETCH crsrh
       INTO o_well_kid, -- Well Header KID
            o_lab_kid,  -- Lab KID
            o_sampled,  -- Sampled Date
            o_received, -- Recieved Date
            o_reported, -- Reported Date
            o_desc;     -- Description
      EXIT WHEN crsrh%NOTFOUND;       
    END LOOP;
    CLOSE crsrh;
--
    SELECT COUNT(kid)
      INTO l_cnt
      FROM co2_brine_well
     WHERE kid = o_well_kid;
--
    IF (l_cnt > 0) THEN
      OPEN crsrw1(o_well_kid);
      LOOP
        FETCH crsrw1
         INTO o_WELL,   -- Well Name
              o_api,    -- API-Number
              o_TRS,    -- TRS Location of Well
              o_LONG,   -- longitude
              o_LAT,    -- latitude
              o_GL,     -- GL
              o_KB,     -- KB
              o_DF;     -- DF
        EXIT WHEN crsrw1%NOTFOUND;
      END LOOP;
      CLOSE crsrw1;
--
    ELSE
      OPEN crsrw(o_well_kid);
      LOOP
        FETCH crsrw
         INTO o_WELL,   -- Well Name
              o_api,    -- API-Number
              o_TRS,    -- TRS Location of Well
              o_LONG,   -- longitude
              o_LAT,    -- latitude
              o_GL,     -- GL
              o_KB,     -- KB
              o_DF;     -- DF
        EXIT WHEN crsrw%NOTFOUND;
      END LOOP;
      CLOSE crsrw;
    END IF;
--
    build_title_icons(o_WELL, o_lab_kid);
--  
    SELECT COUNT(KID)
      INTO l_cnt
      FROM CO2_Brine_Laboratory
     WHERE KID = o_lab_kid;
--
    IF (l_cnt > 0) THEN
      SELECT 'Laboratory'||'<br>'||
             name||'<br>'||
             address||'<br>'||
             city||', '||
             (SELECT name 
                FROM global.states 
               WHERE code = CBL.state_code)||' '||
             zipcode
        INTO o_LAB
        FROM CO2_Brine_Laboratory CBL
       WHERE KID = o_lab_kid;
    END IF;
--
    htp.print('<table class=header cellpadding="2" cellspacing="2" border="0" width="100%">');
    htp.print('<tr>');
    htp.print('<td width="20%"><h3>');
    htp.print('Lease: '||o_WELL||'<br>');
    IF (LENGTH(o_api) > 0) THEN
      htp.print('API-Number: '||o_api||'<br>');
    END IF;
    htp.print('Location: '||o_TRS||'<br>');
    htp.print('Longitude: '||o_LONG||'<br>');
    htp.print('Latitude: '||o_LAT||'<br>');
    IF (o_GL > 0.0) THEN
      htp.print('Elevation (GL):  '||o_GL||'</h3>');
    ELSIF (o_KB > 0.0) THEN
      htp.print('Elevation (KB):  '||o_KB||'</h3>');
    ELSIF (o_DF > 0.0) THEN
      htp.print('Elevation (DF):  '||o_DF||'</h3>');
    END IF;
    htp.print('</h3></td>');
    htp.print('    <td width="60%"><center>&nbsp;</center></td>');
    IF (l_cnt >0) THEN
      htp.print('    <td width="20%" valign="top"><h3>'||o_LAB||'</h3></td>');
    END IF;     
    htp.print('  </tr>');
--      
    htp.print('<hr>');
--
    htp.print('<p>');
    htp.print('<table width="100%">');
    htp.print('  <tr><th>Sample Date: '||o_sampled||
              '</th><th>Recieved Date: '||o_received||
              '</th><th>Report Date: '||o_reported||'</th></tr>');
    htp.print('  <tr><td colspan="3">Description: '||o_desc||'</td></tr>');
    htp.print('</table>');
    htp.print('<HR>');
--
--  Build Main Data Table
--
    build_table(sKID);
--
    SELECT COUNT(kid)
      INTO l_cnt
      FROM co2_brine_sample CBS
     WHERE kid = sKID
       AND well_kid = o_well_kid
       AND 0 < (SELECT COUNT(value)
                   FROM co2_brine_data
                  WHERE sample_kid = CBS.kid
                    AND data_type_kid = 4);
--
    IF (l_cnt > 0) THEN
--
      htp.print('<HR>');
--
      htp.print('  <p><b>Click icon images below to display web apps:</b>');
      htp.print('  <p>');
      htp.print('<table>');
      htp.print('  <tr><th>Sample Plot &amp;</th><th>Piper Diagram</th></tr>');
      htp.print('  <tr><td><a href="http://www.kgs.ku.edu/PRS/Ozark/Software/BRINE/SamplePlot.html?sKID='||sKID||'" target="body"> <img src="http://www.kgs.ku.edu/PRS/Ozark/Software/BRINE/images/sample-icon.png" border="0" align="left" ></a></td>');
      htp.print('      <td><a href="http://www.kgs.ku.edu/PRS/Ozark/Software/BRINE/PiperDiagram.html?sKID='||sKID||'" target="body"> <img src="http://www.kgs.ku.edu/PRS/Ozark/Software/BRINE/images/Piper-icon.png" border="0" align="left" ></a></td>');
      htp.print('  </tr>');
      htp.print('</table>');
--
      htp.print('  <P><i>Note: You will need a JAVA JRE on your PC to run the web apps, you  can download it free from java.com.</i>');
      htp.print('<HR>');
    END IF;
--    
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
--    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_web_page;
--
--
-- PROCEDURE    build_table
-- Description: This procedure will add the data table to the Web Page
-- Input:       sKID = the Brine Data Sample Primary KEY
--
  PROCEDURE build_table(sKID IN VARCHAR2) IS
--
  BEGIN
--  
    htp.print('<table cellpadding="2" cellspacing="2" border="1" width="100%">');
    htp.print('  <tr><th class=header width="34%">Field Data</th>');
    htp.print('      <th class=header width="66%" colspan="2">Analysis of Sample</th></tr>');
    htp.print('  <tr>');
--
--  Build Left Column
--
    build_left_column(sKID);
--
--  Build Anions Column
--
    build_anions_column(sKID);
--    
--  Build Cations Column
--
    build_cations_column(sKID);
--
    htp.print('  </tr>');
--
--  Build Base Row
--
    build_table_base(sKID);
--    
    htp.print('</table>');  
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('build_table() An error occurred: '||SQLERRM);
  END build_table;
--
--
-- PROCEDURE    build_left_column
-- Description: This procedure will add left column to the data table to 
--              the Web Page
-- Input:       sKID = the Brine Data Sample Primary KEY
--
  PROCEDURE build_left_column(sKID IN VARCHAR2) IS
--
    l_cnt    NUMBER;
--
    o_id     iqstrat.co2_brine_data.sample_kid%TYPE; -- id
    o_anal   iqstrat.co2_brine_data.analysis%TYPE;   -- analysis
    o_value  iqstrat.co2_brine_data.value%TYPE;      -- value
    o_units  iqstrat.co2_brine_data.units%TYPE;      -- units
    o_data   NUMBER;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT data_type_kid,
             analysis,
             value,
             NVL(units, '&nbsp;')
        FROM co2_brine_data
       WHERE (data_type_kid > 107
          OR  data_type_kid = 99)
         AND data_type_kid != 215
         AND data_type_kid != 216
         AND data_type_kid != 217
         AND data_type_kid != 221
         AND data_type_kid != 222
         AND sample_kid = sKID;
--
  BEGIN
--  
    htp.print('  <td valign="top">');
    htp.print('    <table  cellpadding="1" cellspacing="1" border="1"  width="100%">');
    htp.print('      <tr><th class=header>Data Description</th><th class=header>Value</th><th class=header>units</th></tr>');
--    
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_id,    -- ID
            o_anal,  -- Description
            o_value, -- Value 
            o_units; -- Units
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('<tr><td>'||o_anal||
                '</td><td align="right">'||o_value||
                '</td><td>'||o_units||'</td></tr>');
--
    END LOOP;
    CLOSE crsr;
--
    htp.print('    </table>');
    htp.print('  </td>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('build_left_column() An error occurred: '||SQLERRM);
  END build_left_column;
--
--
-- PROCEDURE    build_anions_column
-- Description: This procedure will add left column to the data table to 
--              the Web Page
-- Input:       sKID = the Brine Data Sample Primary KEY
--
  PROCEDURE build_anions_column(sKID IN VARCHAR2) IS
--
    l_cnt    NUMBER;
--
    o_id     iqstrat.co2_brine_data.sample_kid%TYPE; -- id
    o_anal   iqstrat.co2_brine_data.analysis%TYPE;   -- analysis
    o_value  iqstrat.co2_brine_data.value%TYPE;      -- value
    o_units  iqstrat.co2_brine_data.units%TYPE;      -- units
    o_data   NUMBER;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT data_type_kid,
             (SELECT description 
                FROM co2_brine_data_type
               WHERE id = CBD.data_type_kid), --analysis,
             value,
             NVL(units, '&nbsp;')
        FROM co2_brine_data CBD
       WHERE data_type_kid > 49
         AND data_type_kid < 99
         AND sample_kid = sKID;
--
  BEGIN
--  
    htp.print('  <td valign="top">');
    htp.print('    <table  cellpadding="1" cellspacing="1" border="1"  width="100%">');
    htp.print('      <tr><th class=header>Data Anions</th><th class=header>Value</th><th class=header>units</th></tr>');
--    
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_id,    -- ID
            o_anal,  -- Description
            o_value, -- Value 
            o_units; -- Units
      EXIT WHEN crsr%NOTFOUND;
--
      IF (o_units = 'ug/L') THEN
        o_units := '&mu;g/L';
      END IF;
--
      htp.print('<tr><td>'||o_anal||
                '</td><td align="right">'||o_value||
                '</td><td>'||o_units||'</td></tr>');
--
    END LOOP;
    CLOSE crsr;
--
    htp.print('    </table>');
    htp.print('  </td>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('build_left_column() An error occurred: '||SQLERRM);
  END build_anions_column;
--
--
-- PROCEDURE    build_cations_column
-- Description: This procedure will add left column to the data table to 
--              the Web Page
-- Input:       sKID = the Brine Data Sample Primary KEY
--
  PROCEDURE build_cations_column(sKID IN VARCHAR2) IS
--
    l_cnt    NUMBER;
--
    o_id     iqstrat.co2_brine_data.sample_kid%TYPE; -- id
    o_anal   iqstrat.co2_brine_data.analysis%TYPE;   -- analysis
    o_value  iqstrat.co2_brine_data.value%TYPE;      -- value
    o_units  iqstrat.co2_brine_data.units%TYPE;      -- units
    o_data   NUMBER;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT data_type_kid,
             (SELECT description 
                FROM co2_brine_data_type
               WHERE id = CBD.data_type_kid), --analysis,
             value,
             NVL(units, '&nbsp;')
        FROM co2_brine_data CBD
       WHERE (data_type_kid < 50
          OR  data_type_kid > 99
         AND  data_type_kid < 110)
         AND sample_kid = sKID;
--
  BEGIN
--  
    htp.print('  <td valign="top">');
    htp.print('    <table  cellpadding="1" cellspacing="1" border="1"  width="100%">');
    htp.print('      <tr><th class=header>Data Cations</th><th class=header>Value</th><th class=header>units</th></tr>');
--    
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_id,    -- ID
            o_anal,  -- Description
            o_value, -- Value 
            o_units; -- Units
      EXIT WHEN crsr%NOTFOUND;
--
      IF (o_units = 'ug/L') THEN
        o_units := '&mu;g/L';
      END IF;
--
      htp.print('<tr><td>'||o_anal||
                '</td><td align="right">'||o_value||
                '</td><td>'||o_units||'</td></tr>');
--
    END LOOP;
    CLOSE crsr;
--
    htp.print('    </table>');
    htp.print('  </td>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('build_left_column() An error occurred: '||SQLERRM);
  END build_cations_column;
--
--
-- PROCEDURE    build_table_base
-- Description: This procedure will add left column to the data table to 
--              the Web Page
-- Input:       sKID = the Brine Data Sample Primary KEY
--
  PROCEDURE build_table_base(sKID IN VARCHAR2) IS
--
    l_cnt    NUMBER;
    l_done   NUMBER;
    o_sum    NUMBER;
    l_Na     NUMBER;
--
    o_id     iqstrat.co2_brine_data.sample_kid%TYPE; -- id
    o_anal   iqstrat.co2_brine_data.analysis%TYPE;   -- analysis
    o_value  iqstrat.co2_brine_data.value%TYPE;      -- value
    o_units  iqstrat.co2_brine_data.units%TYPE;      -- units
    o_data   NUMBER;
--
    o_tds    VARCHAR2(100);
    o_ratio  VARCHAR2(100);
    o_hard   VARCHAR2(100);
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT data_type_kid,
             analysis,
             value,
             NVL(units, '&nbsp;')
        FROM co2_brine_data
       WHERE (data_type_kid = 215
         OR   data_type_kid = 216
         OR   data_type_kid = 217
         OR   data_type_kid = 221
         OR   data_type_kid = 222)
         AND sample_kid = sKID;
--
  BEGIN
--  
    l_done  := 0;
    o_tds   := '<th>&nbsp;</th>';
    o_ratio := '<th>&nbsp;</th>';
    o_hard  := '<th>&nbsp;</th>';
--
    SELECT COUNT(data_type_kid)
      INTO l_Na
      FROM co2_brine_data
     WHERE data_type_kid = 4
       AND sample_kid = sKID;
    
--
    IF (l_Na > 0) THEN
      o_sum  := sum_TDS(sKID);
      o_tds  := '<th>Total Solids Computed = '||o_sum||' mg/L</th>';
    END IF;
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_id,    -- ID
            o_anal,  -- Description
            o_value, -- Value 
            o_units; -- Units
      EXIT WHEN crsr%NOTFOUND;
--
      IF ((o_id = 215) OR (o_id = 216) OR (o_id = 217)) THEN
        IF (l_done = 0) THEN
          o_tds  := '<th>'||o_anal||' = '||o_value||' '||o_units||'</th>';
          l_done := 1;
        END IF;
      END IF;
--      
      IF (o_id = 222) THEN
        o_ratio  := '<th>'||o_anal||' = '||o_value||' '||o_units||'</th>';
      END IF;
--      
      IF (o_id = 221) THEN
        o_hard  := '<th>'||o_anal||' = '||o_value||' '||o_units||'</th>';
      END IF;
--      
    END LOOP;
    CLOSE crsr;
--
    htp.print('<tr>'||o_tds||o_ratio||o_hard||'<tr>');
--
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('build_table_base() An error occurred: '||SQLERRM);
  END build_table_base;
--
--
-- PROCEDURE    build_title_icons
-- Description: This procedure will add the Title icons to the Web Page
--
  PROCEDURE build_title_icons(sTitle IN VARCHAR2, sLAB IN VARCHAR2) IS
--
    l_cnt NUMBER;
    o_LAB VARCHAR2(255);     
--
  BEGIN
--
    SELECT COUNT(KID)
      INTO l_cnt
      FROM CO2_Brine_Laboratory
     WHERE KID = sLAB;
--
    IF (l_cnt > 0) THEN
      SELECT 'Laboratory'||'<br>'||
             name||'<br>'||
             address||'<br>'||
             city||', '||
             (SELECT name 
                FROM global.states 
               WHERE code = CBL.state_code)||' '||
             zipcode
        INTO o_LAB
        FROM CO2_Brine_Laboratory CBL
       WHERE KID = sLAB;
    END IF;
--
    htp.print('<table class=header cellpadding="2" cellspacing="2" border="0" width="100%">');
    htp.print('  <tr>');
    htp.print('    <td width="10%">');
    htp.print('      <a href="http://www.kgs.ku.edu/"');
    htp.print('         target="body">');
    htp.print('         <img src="http://www.kgs.ku.edu/PRS/Ozark/Summary/images/kgsSmB.png"');
    htp.print('              border="0"');
    htp.print('              align="left"></a>');
    htp.print('    </td>');
    htp.print('    <td width="70%"><center><h1>South-central Kansas CO<sub>2</sub> Project<br>'||sTitle||'<br>Brine Data</h1></center></td>');
--    IF (l_cnt >0) THEN
--      htp.print('    <td width="20%"><h2>'||o_LAB||'</h2></td>');
--    END IF;     
    htp.print('  </tr>');
    htp.print('</table>');
--
    htp.line;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('build_title_icons() An error occurred: '||SQLERRM);
  END build_title_icons;
--
--
-- FUNCTION sum_TDS()
-- Description: This procedure will sum all the analytes to compute a TDS
-- Input:       sKID  = the brine sample KID
-- Ouput:       o_sum = computed TDS.
--
  FUNCTION sum_TDS(sKID IN VARCHAR2) RETURN VARCHAR2 IS
--
    l_cnt    NUMBER;
    o_data   NUMBER;
    o_sum    NUMBER;
--
    o_id     iqstrat.co2_brine_data.sample_kid%TYPE; -- id
    o_anal   iqstrat.co2_brine_data.analysis%TYPE;   -- analysis
    o_value  iqstrat.co2_brine_data.value%TYPE;      -- value
    o_units  iqstrat.co2_brine_data.units%TYPE;      -- units
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT data_type_kid,
             (SELECT description 
                FROM co2_brine_data_type
               WHERE id = CBD.data_type_kid), --analysis,
             value,
             NVL(units, '&nbsp;')
        FROM co2_brine_data CBD
       WHERE (data_type_kid > 0
         AND  data_type_kid < 110
         AND  data_type_kid != 99)
         AND sample_kid = sKID;
--
  BEGIN
--
    o_sum := 0.0;
--    
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_id,    -- ID
            o_anal,  -- Description
            o_value, -- Value 
            o_units; -- Units
      EXIT WHEN crsr%NOTFOUND;
--
      IF (is_number(o_value) = 'YES') THEN
        IF (o_units = 'ug/L') THEN
          o_data := TO_NUMBER(o_value) / 1000.0;
        ELSE
          o_data := TO_NUMBER(o_value);
        END IF;
        o_sum := o_sum + o_data;
      END IF;
--      
    END LOOP;
    CLOSE crsr;
--
    RETURN (o_sum);
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('sum_TDS() An error occurred: '||SQLERRM);
  END sum_TDS;
--
--
-- FUNCTION is_number()
-- Description: This procedure will check if the string is a number
-- Input:       str = the string that is being check to see if it is a number
-- Ouput:       o_result = YES it is a number; NO it is NOT a number.
--
  FUNCTION is_number(str IN VARCHAR2) RETURN VARCHAR2 IS
--
  o_result VARCHAR2(200);
--
  BEGIN
--
    SELECT DECODE(TRANSLATE(LTRIM(str,'-'),'*0123456789.','*'),null,str,'?') 
      INTO o_result
      FROM DUAL;
--
    IF (o_result = '?') THEN
      o_result := 'NO';
    ELSE
      o_result := 'YES';
    END IF;
--
    RETURN (o_result);   
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('is_number() An error occurred: '||SQLERRM);
  END is_number;
--
--
END co2_brine_data_summary_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON co2_brine_data_summary_pkg TO apex_public_user;