-- * PLSQL:       co2_brine_data_type_pkg.sql Version 1.1 05/01/2015
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the Headers information.
-- * Copyright (c) 2015 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_brine_data_type_pkg AS
  PROCEDURE build_web_page;
  PROCEDURE build_cations_column;
  PROCEDURE build_anions_column;
  PROCEDURE build_other_column;
  PROCEDURE build_title_icons(sTitle IN VARCHAR2);
END co2_brine_data_type_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_brine_data_type_pkg AS
--
-- PROCEDURE    build_web_page()
-- Description: This procedure will buiild the single brine data web page.
-- * Output:    Summary Web Page for specific brine data record.
--
  PROCEDURE build_web_page IS
--  
--
  BEGIN
--
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('CO2 Well Brine Data Types Database Table');
    htp.headClose;
--
    htp.print('<BODY>');
    build_title_icons( 'Brine Data Types Database Table Contents' );
--
    htp.print('<p>');
    htp.p('<table cellpadding="1" cellspacing="1" border="1" width="100%">');
--
--  Add Cations List
--
    htp.print('<tr>');
--    
    build_cations_column;
--
--  Add Anions List
--
    build_anions_column;
--    
--  Other Data
--
    build_other_column;
--    
    htp.print('</tr>');
--
    htp.print('<HR>');
    htp.bodyClose;
    htp.htmlClose;
--
    htp.p('</table>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
--    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_web_page;
--
--
-- PROCEDURE    build_cations_column
-- Description: This procedure will add cations columns to the data table to 
--              the Web Page
--
  PROCEDURE build_cations_column IS
--
    l_cnt    NUMBER;
--
    o_id     iqstrat.co2_brine_data_type.id%TYPE;          -- id
    o_mnem   iqstrat.co2_brine_data_type.mnemonic%TYPE;    -- mnemonics
    o_desc   iqstrat.co2_brine_data_type.description%TYPE; -- description
--
    CURSOR crsr IS
      SELECT id,
             mnemonic, 
             description
        FROM co2_brine_data_type
       WHERE (id < 50
          OR (id > 99
         AND  id < 110))
      ORDER BY id;
--
  BEGIN
--  
    htp.print('  <td valign="top">');
    htp.print('    <table  cellpadding="1" cellspacing="1" border="1"  width="100%">');
    htp.print('      <tr><th class=header colspan="3">Cations</th></tr>');
    htp.print('      <tr><th class=header width="10%">ID</th>'||
                  '<th class=header width="20%">Mnemonic</th>'||
                  '<th class=header width="70%">Description</th></tr>');
--    
    OPEN crsr;
    LOOP
      FETCH crsr
       INTO o_id,    -- ID - Primary KEY
            o_mnem,  -- Mnemonic
            o_desc;  -- Description
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('      <tr><td>'||o_id||
                '</td><td>'||o_mnem||
                '</td><td>'||o_desc||'</td></tr>');
--
    END LOOP;
    CLOSE crsr;
--
    htp.print('    </table>');
    htp.print('  </td>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('build_cations_column() An error occurred: '||SQLERRM);
  END build_cations_column;
--
--
-- PROCEDURE    build_anions_column
-- Description: This procedure will add anions columns to the data table to 
--              the Web Page
--
  PROCEDURE build_anions_column IS
--
    l_cnt    NUMBER;
--
    o_id     iqstrat.co2_brine_data_type.id%TYPE;          -- id
    o_mnem   iqstrat.co2_brine_data_type.mnemonic%TYPE;    -- mnemonics
    o_desc   iqstrat.co2_brine_data_type.description%TYPE; -- description
--
    CURSOR crsr IS
      SELECT id,
             mnemonic, 
             description
        FROM co2_brine_data_type
       WHERE id > 49
         AND id < 99
      ORDER BY id;
--
  BEGIN
--  
    htp.print('  <td valign="top">');
    htp.print('    <table  cellpadding="1" cellspacing="1" border="1"  width="100%">');
    htp.print('      <tr><th class=header colspan="3">Anions</th></tr>');
    htp.print('      <tr><th class=header width="10%">ID</th>'||
                  '<th class=header width="20%">Mnemonic</th>'||
                  '<th class=header width="70%">Description</th></tr>');
--    
    OPEN crsr;
    LOOP
      FETCH crsr
       INTO o_id,    -- ID - Primary KEY
            o_mnem,  -- Mnemonic
            o_desc;  -- Description
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('      <tr><td>'||o_id||
                '</td><td>'||o_mnem||
                '</td><td>'||o_desc||'</td></tr>');
--
    END LOOP;
    CLOSE crsr;
--
    htp.print('    </table>');
    htp.print('  </td>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('build_anions_column() An error occurred: '||SQLERRM);
  END build_anions_column;
--
--
-- PROCEDURE    build_other_column
-- Description: This procedure will add other data columns to the data table to 
--              the Web Page
--
  PROCEDURE build_other_column IS
--
    l_cnt    NUMBER;
--
    o_id     iqstrat.co2_brine_data_type.id%TYPE;          -- id
    o_mnem   iqstrat.co2_brine_data_type.mnemonic%TYPE;    -- mnemonics
    o_desc   iqstrat.co2_brine_data_type.description%TYPE; -- description
--
    CURSOR crsr IS
      SELECT id,
             mnemonic, 
             description
        FROM co2_brine_data_type
       WHERE id > 109
      ORDER BY id;
--
  BEGIN
--  
    htp.print('  <td valign="top">');
    htp.print('    <table  cellpadding="1" cellspacing="1" border="1"  width="100%">');
    htp.print('      <tr><th class=header colspan="3">Other Data</th></tr>');
    htp.print('      <tr><th class=header width="10%">ID</th>'||
                  '<th class=header width="20%">Mnemonic</th>'||
                  '<th class=header width="70%">Description</th></tr>');
--    
    OPEN crsr;
    LOOP
      FETCH crsr
       INTO o_id,    -- ID - Primary KEY
            o_mnem,  -- Mnemonic
            o_desc;  -- Description
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('      <tr><td>'||o_id||
                '</td><td>'||o_mnem||
                '</td><td>'||o_desc||'</td></tr>');
--
    END LOOP;
    CLOSE crsr;
--
    htp.print('    </table>');
    htp.print('  </td>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('build_other_column() An error occurred: '||SQLERRM);
  END build_other_column;
--
--
-- PROCEDURE    build_title_icons
-- Description: This procedure will add the Title icons to the Web Page
--
  PROCEDURE build_title_icons(sTitle IN VARCHAR2) IS
--
  BEGIN
--
    htp.print('<table class=header cellpadding="2" cellspacing="2" border="0" width="100%">');
    htp.print('  <tr>');
    htp.print('    <td width=108>');
    htp.print('      <a href="http://www.kgs.ku.edu/"');
    htp.print('         target="body">');
    htp.print('         <img src="http://www.kgs.ku.edu/PRS/Ozark/Summary/images/kgsSmB.png"');
    htp.print('              border="0"');
    htp.print('              align="left"></a>');
    htp.print('    </td>');
    htp.print('    <td><center><h1>South-central Kansas CO<sub>2</sub> Project<br>'||sTitle||'</h1></center></td>');
    htp.print('  </tr>');
    htp.print('</table>');
--
    htp.line;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
  END build_title_icons;
--
--
END co2_brine_data_type_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON co2_brine_data_type_pkg TO apex_public_user;