-- * PLSQL:       co2_brine_summary_csv_pkg.sql Version 1.1 05/01/2015
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the Headers information.
-- * Copyright (c) 2015 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_brine_summary_csv_pkg AS
  PROCEDURE build_web_page;
  PROCEDURE build_web_page(field IN VARCHAR2);
  PROCEDURE build_web_page(sID IN VARCHAR2);
  PROCEDURE build_row(sKID IN VARCHAR2);
  PROCEDURE build_row(sKID IN VARCHAR2, sID IN VARCHAR2);
  PROCEDURE build_subset(sKID IN VARCHAR2, sID IN VARCHAR2);
  FUNCTION is_number(str IN VARCHAR2) RETURN VARCHAR2;
END co2_brine_summary_csv_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_brine_summary_csv_pkg AS
--
-- PROCEDURE    build_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sCounty = the county to select from 
-- * Output:    Summary Web Page for specific County of Kansas.
--
  PROCEDURE build_web_page IS
--  
    o_kid  iqstrat.co2_brine_sample.kid%TYPE;   -- Sample KID
    o_wkid iqstrat.co2_brine_sample.well_kid%TYPE;   -- Sample KID
--
   CURSOR crsr IS
     SELECT kid, well_kid
       FROM co2_brine_sample
     ORDER BY field_name, well_kid, sampled_date;
--
  BEGIN
--  
    htp.print('<HTML><HEAD><TITLE>DOE_CO2_Wells</TITLE></HEAD><BODY>');


    htp.print('WELL,API-Number,TRS,lat, long, UTM-X, UTM-Y, UTM Zone,Sampled,Reported,Formation,Top,Base,'||
              'PH,Ca,Mg,Sr,Na,K,Fe,Mn,Cl,Br,I,SO4,CO3,HCO3,BO3,PO4,TDS,Ratio,LAB,</br>');
    htp.print('NAME,NUMBER,-,deg,deg,,,,DATE,DATE,Name,FT,FT,'||
              '-,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,-,-,</br>');

--
--  Build Table
--
      OPEN crsr;
      LOOP
        FETCH crsr
         INTO o_kid, -- Sample KID
              o_wkid; -- Well header KID
        EXIT WHEN crsr%NOTFOUND;
--
        build_row(o_kid);
--
      END LOOP;
      CLOSE crsr;
--    
    htp.print('</BODY></HTML>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.print('</BODY></HTML>');
--
  END build_web_page;
--
--
-- PROCEDURE    build_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     field = the field 
-- * Output:    Summary Web Page for specific County of Kansas.
--
  PROCEDURE build_web_page(field IN VARCHAR2) IS
--  
    o_kid  iqstrat.co2_brine_sample.kid%TYPE;   -- Sample KID
    o_wkid iqstrat.co2_brine_sample.well_kid%TYPE;   -- Sample KID
--
   CURSOR crsr(sField IN VARCHAR2) IS
     SELECT kid, well_kid
       FROM co2_brine_sample
      WHERE UPPER(field_name) = UPPER(sField)
     ORDER BY field_name, well_kid, sampled_date;
--
  BEGIN
--  
    htp.print('<HTML><HEAD><TITLE>DOE_CO2_Wells</TITLE></HEAD><BODY>');


    htp.print('WELL,API-Number,TRS,lat, long, UTM-X, UTM-Y, UTM Zone,Sampled,Reported,Formation,Top,Base,'||
              'PH,Ca,Mg,Sr,Na,K,Fe,Mn,Cl,Br,I,SO4,CO3,HCO3,BO3,PO4,TDS,Ratio,LAB,</br>');
    htp.print('NAME,NUMBER,-,deg,deg,,,,DATE,DATE,Name,FT,FT,'||
              '-,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,-,-,</br>');

--
--  Build Table
--
      OPEN crsr(field);
      LOOP
        FETCH crsr
         INTO o_kid, -- Sample KID
              o_wkid; -- Well header KID
        EXIT WHEN crsr%NOTFOUND;
--
        build_row(o_kid);
--
      END LOOP;
      CLOSE crsr;
--    
    htp.print('</BODY></HTML>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.print('</BODY></HTML>');
--
  END build_web_page;
--
--
-- PROCEDURE    build_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sID = the field 
-- * Output:    Summary Web Page for specific County of Kansas.
--
  PROCEDURE build_web_page(sID IN VARCHAR2) IS
--  
    o_kid  iqstrat.co2_brine_sample.kid%TYPE;   -- Sample KID
    o_wkid iqstrat.co2_brine_sample.well_kid%TYPE;   -- Well KID
    o_id   iqstrat.co2_brine_sample.group_id%TYPE;   -- Group ID
--
   CURSOR crsr(sField IN VARCHAR2) IS
     SELECT kid, well_kid, group_id
       FROM co2_brine_sample
      WHERE group_id = sID
     ORDER BY group_no, sampled_date, well_kid;
--
  BEGIN
--  
    htp.print('<HTML><HEAD><TITLE>DOE_CO2_Wells</TITLE></HEAD><BODY>');


    IF (sID = 'LAB') THEN
      htp.print('WELL,API-Number,TRS,lat, long, UTM-X, UTM-Y, UTM Zone,ID,No,Sampled,Reported,Formation,Top,Base,'||
                'PH,Ca,Mg,Sr,Na,K,Fe,Mn,Cl,Br,I,SO4,CO3,HCO3,BO3,PO4,TDS,Ratio,LAB,</br>');
      htp.print('NAME,NUMBER,-,deg,deg,,,,,,DATE,DATE,Name,FT,FT,'||
                '-,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,mg/L,-,-,</br>');
    ELSE
      htp.print('WELL,API-Number,TRS,lat, long, UTM-X, UTM-Y, UTM Zone,ID,No,Sampled,'||
                'PH,TEMP,SO4,TDS,LAB,</br>');
      htp.print('NAME,NUMBER,-,deg,deg,,,,,,DATE,'||
                '-,deg C,mg/L,mg/L,-,</br>');
    END IF;

--
--  Build Table
--
      OPEN crsr(sID);
      LOOP
        FETCH crsr
         INTO o_kid,  -- Sample KID
              o_wkid, -- Well header KID
              o_id;   -- group ID
        EXIT WHEN crsr%NOTFOUND;
--
        IF (sID = 'LAB') THEN
          build_row(o_kid, o_id);
        ELSE
          build_subset(o_kid, o_id);
        END IF;
--
      END LOOP;
      CLOSE crsr;
--    
    htp.print('</BODY></HTML>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.print('</BODY></HTML>');
--
  END build_web_page;
--
--
-- PROCEDURE    build_row()
-- Description: This procedure will add the table row for sample
-- * Input:     sKID = Sample KID
-- * Output:    The sample data row
--
  PROCEDURE build_row(sKID IN VARCHAR2) IS
--
    l_cnt    NUMBER;
--
    o_id     iqstrat.co2_brine_data.sample_kid%TYPE; -- id
    o_value  iqstrat.co2_brine_data.value%TYPE; -- value
    o_units  iqstrat.co2_brine_data.units%TYPE; -- units
    o_data   NUMBER;
    o_Fe_d   NUMBER;
    o_Mn_d   NUMBER;
-- Cations
    o_Ca     iqstrat.co2_brine_data.value%TYPE; -- 10 Calcium Value
    o_Mg     iqstrat.co2_brine_data.value%TYPE; --  9 Magnesium Value
    o_Na     iqstrat.co2_brine_data.value%TYPE; --  4 Sodium Value
    o_K      iqstrat.co2_brine_data.value%TYPE; --  5 Potassium Value
    o_Fe     iqstrat.co2_brine_data.value%TYPE; -- 32 Iron Value
    o_Mn     iqstrat.co2_brine_data.value%TYPE; -- 29 Manganese Value
    o_Al     iqstrat.co2_brine_data.value%TYPE; -- 13 Aluminum Value
    o_Sr     iqstrat.co2_brine_data.value%TYPE; -- 11 Strontium Value
-- Anions
    o_Cl     iqstrat.co2_brine_data.value%TYPE; -- 52 Chloride Value
    o_Br     iqstrat.co2_brine_data.value%TYPE; -- 53 Bromide Value
    o_I      iqstrat.co2_brine_data.value%TYPE; -- 54 Iodide Value
    o_SO4    iqstrat.co2_brine_data.value%TYPE; -- 87 Sulphate Value
    o_CO3    iqstrat.co2_brine_data.value%TYPE; -- 57 Carbonate Value
    o_HCO3   iqstrat.co2_brine_data.value%TYPE; -- 58 Bicarbonate Value
    o_PO4    iqstrat.co2_brine_data.value%TYPE; -- 75 Phosphate Value
    o_BO3    iqstrat.co2_brine_data.value%TYPE; -- 56 Borate Value
-- Other
    o_kid    iqstrat.CO2_brine_wells.kid%TYPE;  -- well kid
    o_WELL   iqstrat.CO2_brine_wells.name%TYPE; -- well name
    o_API    iqstrat.CO2_brine_wells.api_number%TYPE; -- api-number
    o_lat    co2_brine_well.nad27_latitude%TYPE;
    o_long   co2_brine_well.nad27_longitude%TYPE;
    o_utm_x  co2_brine_well.nad27_utm_x%TYPE;
    o_utm_y  co2_brine_well.nad27_utm_y%TYPE;
    o_utm_z  co2_brine_well.nad27_utm_zone%TYPE;
    o_TRS    VARCHAR2(60); 
    o_lab    VARCHAR2(255); -- Lab KID
    o_lab_kid iqstrat.CO2_brine_sample.lab_kid%TYPE; -- api-number
--    
    o_S_DATE VARCHAR2(40);                                -- Sample Date
    o_R_DATE VARCHAR2(40);                                -- Reported Date
    o_FLUID  iqstrat.co2_brine_sample.amount_fluid%TYPE;  -- Amount of Fluid
    o_FUNITS iqstrat.co2_brine_sample.amount_fluid_units%TYPE;  -- Fluid Units
--   
    o_TDS    NUMBER;
--
    o_PH     iqstrat.co2_brine_data.value%TYPE; -- 203 PH
    o_FORM   iqstrat.co2_brine_data.value%TYPE; -- 300 Formation
    o_TOP    iqstrat.co2_brine_data.value%TYPE; -- 302 Top Depth
    o_BASE   iqstrat.co2_brine_data.value%TYPE; -- 303 Base Depth
    o_RATIO  iqstrat.co2_brine_data.value%TYPE; -- 222 Base Depth
--    
-- Cursors
--
    CURSOR crsrh(sKID IN VARCHAR2) IS
      SELECT well_kid,
             NVL(TO_CHAR(sampled_date, 'MM/DD/YYYY HH24:MI'), 'NA'),
             NVL(amount_fluid, 0),
             NVL(amount_fluid_units, 'NA'),
             NVL(TO_CHAR(reported_date, 'MM/DD/YYYY HH24:MI'), 'NA'),
             lab_kid
--             REPLACE(SELECT name FROM CO2_Brine_Laboratory where kid = co2.lab_kid), ',', ' ')
        FROM co2_brine_sample co2
       WHERE kid = sKID;
--
    CURSOR crsrw(sKID IN VARCHAR2) IS
      SELECT NVL(name, 'NA'),
             NVL(api_number, 'NA'),
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, 'NA')
        FROM co2_brine_wells
       WHERE kid = sKID;
--
    CURSOR crsrw1(sKID IN VARCHAR2) IS
      SELECT NVL(REPLACE(lease_name,',',' ')||' '||well_name, 'NA'),
             NVL(api_number, 'NA'),
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, 'NA'),
             nad27_latitude,
             nad27_longitude,
             nad27_utm_x,
             nad27_utm_y,
             nad27_utm_zone
        FROM co2_brine_well
       WHERE kid = sKID;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT data_type_kid,
             value,
             units
        FROM co2_brine_data
       WHERE data_type_kid IN ( 11, 10, 9, 4, 5, 32, 33, 34, 29, 30, 31, 
                                13, 52, 53, 54, 56, 
                                87, 57, 58, 75, 203, 300, 302, 303, 222 )
         AND sample_kid = sKID;
--
  BEGIN
--
      OPEN crsrh(sKID);
      LOOP
        FETCH crsrh
         INTO o_kid,    -- Well Header KID
              o_S_DATE, -- Sample Date 
              o_FLUID,  -- Sample Volume
              o_FUNITS, -- Sample Volume Units
              o_R_DATE, -- Report Date
              o_lab_kid;    -- lab kid
        EXIT WHEN crsrh%NOTFOUND;  
--        
        SELECT COUNT(kid) 
          INTO l_cnt
          FROM CO2_Brine_Laboratory
         WHERE kid = o_lab_kid;
--
        IF (l_cnt > 0) THEN
          SELECT REPLACE(name, ',', ' ') 
            INTO o_lab
            FROM CO2_Brine_Laboratory
           WHERE kid = o_lab_kid;
        END IF;
      END LOOP;      
      CLOSE crsrh;
--
      SELECT COUNT(kid)
        INTO l_cnt
        FROM co2_brine_well
       WHERE kid = o_kid;
--
      IF (l_cnt > 0) THEN
        OPEN crsrw1(o_kid);
        LOOP
          FETCH crsrw1
           INTO o_WELL,   -- Well Name
                o_API,    -- API-Number
                o_TRS,    -- TRS Location of Well
                o_lat,    -- Latitude
                o_long,   -- Longitude
                o_utm_x,  -- UTM-X
                o_utm_y,  -- UTM-Y
                o_utm_z;  -- UTM-Zone
          EXIT WHEN crsrw1%NOTFOUND;
        END LOOP;
        CLOSE crsrw1;
--
      ELSE
        OPEN crsrw(o_kid);
        LOOP
          FETCH crsrw
           INTO o_WELL,   -- Well Name
                o_API,
                o_TRS;    -- TRS Location of Well
          EXIT WHEN crsrw%NOTFOUND;
          o_lat  := 0.0;
          o_long := 0.0;
        END LOOP;
        CLOSE crsrw;
--      
      END IF;
--
      o_Ca   := 'NA'; -- 10 Calcium Value
      o_Mg   := 'NA'; --  9 Magnesium Value
      o_Na   := 'NA'; --  4 Sodium Value
      o_K    := 'NA'; --  5 Potassium Value
      o_Fe   := 'NA'; -- 32 Iron Value
      o_Mn   := 'NA'; -- 29 Manganese Value
      o_Al   := 'NA'; -- 13 Aluminum Value
      o_Sr   := 'NA'; -- 11 Strontium Value
-- Anions
      o_Cl   := 'NA'; -- 52 Chloride Value
      o_Br   := 'NA'; -- 53 Bromide Value
      o_I    := 'NA'; -- 54 Iodide Value
      o_SO4  := 'NA'; -- 87 Sulphate Value
      o_CO3  := 'NA'; -- 57 Carbonate Value
      o_HCO3 := 'NA'; -- 58 Bicarbonate Value
      o_PO4  := 'NA'; -- 75 Phosphate Value
      o_BO3  := 'NA'; -- 56 Borate Value
--
-- Computed TDS
--
      o_TDS  := iqstrat.co2_brine_data_summary_pkg.sum_TDS(sKID); 
--      
-- Other
--
      o_PH    := 'NA'; -- 203 PH
      o_FORM  := 'NA'; -- 300 Formation
      o_TOP   := 'NA'; -- 302 Top Depth
      o_BASE  := 'NA'; -- 303 Base Depth
      o_RATIO := 'NA'; -- 222 Ratio
--
      OPEN crsr(sKID);
      LOOP
        FETCH crsr
         INTO o_id,    -- Analyte ID
              o_value, -- Value 
              o_units; -- Units
        EXIT WHEN crsr%NOTFOUND;
--
        IF (o_units = 'ug/L') THEN
          o_data := 0;
          IF (is_number(o_value) = 'YES') THEN
            o_data := TO_NUMBER(o_value) / 1000.0;        
          END IF;
          o_value := o_data;
        END IF;
--        
        IF (o_id = 300) THEN    -- IF Formation Name THEN
          o_FORM := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 302) THEN    -- IF Top Depth THEN
          o_TOP := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 303) THEN    -- IF Base Depth THEN
          o_BASE := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 203) THEN    -- IF PH THEN
          o_PH := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 222) THEN    -- IF RATIO THEN
          o_RATIO := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 10) THEN    -- IF Calcium THEN
          o_Ca := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 11) THEN    -- IF Strontium THEN
          o_Sr := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 9) THEN     -- IF Magnesium THEN
          o_Mg := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 4) THEN     -- IF Sodium THEN
          o_Na := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 5) THEN     -- IF Potassium THEN
          o_K := o_value;   --   Set Data
        END IF;
--
        o_data := 0.0;
        IF (is_number(o_value) = 'YES') THEN
          o_data := TO_NUMBER(o_value);
        END IF;
--
        o_Fe_d := 0.0;
--
--        IF ((o_id = 32) OR (o_id = 33) OR (o_id = 34)) THEN
--          o_Fe := o_value;   --   Set Data
--        END IF;
--        
        IF (o_id = 32) THEN    -- IF Iron THEN
          o_Fe_d := o_Fe_d + o_data;   --   Set Data
          o_Fe   := o_Fe_d;
        END IF;
--
        IF (o_id = 33) THEN    -- IF Iron THEN
          o_Fe_d := o_Fe_d + o_data;   --   Set Data
          o_Fe   := o_Fe_d;
        END IF;
--
        IF (o_id = 34) THEN    -- IF Iron THEN
          o_Fe_d := o_Fe_d + o_data;   --   Set Data
          o_Fe   := o_Fe_d;
        END IF;
--
        o_Mn_d := 0.0;
--
        IF (o_id = 29) THEN    -- IF Manganese THEN
          o_Mn_d := o_Mn_d + o_data;   --   Set Data
          o_Mn   := o_Mn_d;   --   Set Data
        END IF;
--
        IF (o_id = 30) THEN    -- IF Manganese THEN
          o_Mn_d := o_Mn_d + o_data;   --   Set Data
          o_Mn   := o_Mn_d;   --   Set Data
        END IF;
--
        IF (o_id = 31) THEN    -- IF Manganese THEN
          o_Mn_d := o_Mn_d + o_data;   --   Set Data
          o_Mn   := o_Mn_d;   --   Set Data
        END IF;
--
        IF (o_id = 13) THEN    -- IF Aluminum THEN
          o_Al := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 52) THEN    -- IF Cloride THEN
          o_Cl := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 53) THEN    -- IF Bromide THEN
          o_Br := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 54) THEN    -- IF Iodide THEN
          o_I := o_value;    --   Set Data
        END IF;
--
        IF (o_id = 87) THEN    -- IF Sulphate THEN
          o_SO4 := o_value;  --   Set Data
        END IF;
--
        IF (o_id = 57) THEN    -- IF Carbonate THEN
          o_CO3 := o_value;  --   Set Data
        END IF;
--
        IF (o_id = 58) THEN    -- IF Bicarbonate THEN
          o_HCO3 := o_value; --   Set Data
        END IF;
--
        IF (o_id = 56) THEN    -- IF Borate THEN
          o_BO3 := o_value;  --   Set Data
        END IF;
--
        IF (o_id = 75) THEN    -- IF Phosphate THEN
          o_PO4 := o_value;  --   Set Data
        END IF;
--
      END LOOP;
      CLOSE crsr;
--
      htp.print(o_WELL||','||o_API||','||o_TRS||','||o_lat||','||o_long||
      ','||o_utm_x||','||o_utm_y||','||o_utm_z||
      ','||o_S_DATE||','||o_R_DATE||
      ','||o_FORM||','||o_TOP||','||o_BASE||','||o_PH||
      ','||o_Ca||','||o_Mg||','||o_Sr||','||o_Na||','||o_K||','||o_Fe||','||o_Mn||
      ','||o_Cl||','||o_Br||','||o_I||','||o_SO4||','||o_CO3||','||o_HCO3||','||o_BO3||','||o_PO4||
      ','||o_TDS||','||o_RATIO||','||o_lab||',<br>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('Brine KID='||sKID||' Well KID='||o_kid||' '||SQLERRM||'</td>');
--
  END build_row;
--
--
-- PROCEDURE    build_row()
-- Description: This procedure will add the table row for sample
-- * Input:     sKID = Sample KID
-- * Output:    The sample data row
--
  PROCEDURE build_row(sKID IN VARCHAR2, sID IN VARCHAR2) IS
--
    l_cnt    NUMBER;
--
    o_id     iqstrat.co2_brine_data.sample_kid%TYPE; -- id
    o_value  iqstrat.co2_brine_data.value%TYPE; -- value
    o_units  iqstrat.co2_brine_data.units%TYPE; -- units
    o_data   NUMBER;
    o_Fe_d   NUMBER;
    o_Mn_d   NUMBER;
-- Cations
    o_Ca     iqstrat.co2_brine_data.value%TYPE; -- 10 Calcium Value
    o_Mg     iqstrat.co2_brine_data.value%TYPE; --  9 Magnesium Value
    o_Na     iqstrat.co2_brine_data.value%TYPE; --  4 Sodium Value
    o_K      iqstrat.co2_brine_data.value%TYPE; --  5 Potassium Value
    o_Fe     iqstrat.co2_brine_data.value%TYPE; -- 32 Iron Value
    o_Mn     iqstrat.co2_brine_data.value%TYPE; -- 29 Manganese Value
    o_Al     iqstrat.co2_brine_data.value%TYPE; -- 13 Aluminum Value
    o_Sr     iqstrat.co2_brine_data.value%TYPE; -- 11 Strontium Value
-- Anions
    o_Cl     iqstrat.co2_brine_data.value%TYPE; -- 52 Chloride Value
    o_Br     iqstrat.co2_brine_data.value%TYPE; -- 53 Bromide Value
    o_I      iqstrat.co2_brine_data.value%TYPE; -- 54 Iodide Value
    o_SO4    iqstrat.co2_brine_data.value%TYPE; -- 87 Sulphate Value
    o_CO3    iqstrat.co2_brine_data.value%TYPE; -- 57 Carbonate Value
    o_HCO3   iqstrat.co2_brine_data.value%TYPE; -- 58 Bicarbonate Value
    o_PO4    iqstrat.co2_brine_data.value%TYPE; -- 75 Phosphate Value
    o_BO3    iqstrat.co2_brine_data.value%TYPE; -- 56 Borate Value
-- Other
    o_kid    iqstrat.CO2_brine_wells.kid%TYPE;  -- well kid
    o_WELL   iqstrat.CO2_brine_wells.name%TYPE; -- well name
    o_API    iqstrat.CO2_brine_wells.api_number%TYPE; -- api-number
    o_lat    co2_brine_well.nad27_latitude%TYPE;
    o_long   co2_brine_well.nad27_longitude%TYPE;
    o_utm_x  co2_brine_well.nad27_utm_x%TYPE;
    o_utm_y  co2_brine_well.nad27_utm_y%TYPE;
    o_utm_z  co2_brine_well.nad27_utm_zone%TYPE;
    o_TRS    VARCHAR2(60); 
    o_lab    VARCHAR2(255); -- Lab KID
    o_lab_kid iqstrat.CO2_brine_sample.lab_kid%TYPE; -- api-number
--    
    o_S_DATE VARCHAR2(40);                                -- Sample Date
    o_R_DATE VARCHAR2(40);                                -- Reported Date
    o_FLUID  iqstrat.co2_brine_sample.amount_fluid%TYPE;  -- Amount of Fluid
    o_FUNITS iqstrat.co2_brine_sample.amount_fluid_units%TYPE;  -- Fluid Units
    o_group_no iqstrat.co2_brine_sample.group_no%TYPE;  -- Fluid Units
    o_group_id iqstrat.co2_brine_sample.group_id%TYPE;  -- Fluid Units
--   
    o_TDS    NUMBER;
--
    o_PH     iqstrat.co2_brine_data.value%TYPE; -- 203 PH
    o_FORM   iqstrat.co2_brine_data.value%TYPE; -- 300 Formation
    o_TOP    iqstrat.co2_brine_data.value%TYPE; -- 302 Top Depth
    o_BASE   iqstrat.co2_brine_data.value%TYPE; -- 303 Base Depth
    o_RATIO  iqstrat.co2_brine_data.value%TYPE; -- 222 Base Depth
--    
-- Cursors
--
    CURSOR crsrh(sKID IN VARCHAR2, sID IN VARCHAR2) IS
      SELECT well_kid,
             NVL(TO_CHAR(sampled_date, 'MM/DD/YYYY HH24:MI'), 'NA'),
             NVL(amount_fluid, 0),
             NVL(amount_fluid_units, 'NA'),
             NVL(TO_CHAR(reported_date, 'MM/DD/YYYY HH24:MI'), 'NA'),
             lab_kid,
             group_id,
             group_no
--             REPLACE(SELECT name FROM CO2_Brine_Laboratory where kid = co2.lab_kid), ',', ' ')
        FROM co2_brine_sample co2
       WHERE kid = sKID
         AND group_id = sID;
--
    CURSOR crsrw(sKID IN VARCHAR2) IS
      SELECT NVL(name, 'NA'),
             NVL(api_number, 'NA'),
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, 'NA')
        FROM co2_brine_wells
       WHERE kid = sKID;
--
    CURSOR crsrw1(sKID IN VARCHAR2) IS
      SELECT NVL(REPLACE(lease_name,',',' ')||' '||well_name, 'NA'),
             NVL(api_number, 'NA'),
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, 'NA'),
             nad27_latitude,
             nad27_longitude,
             nad27_utm_x,
             nad27_utm_y,
             nad27_utm_zone
        FROM co2_brine_well
       WHERE kid = sKID;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT data_type_kid,
             value,
             units
        FROM co2_brine_data
       WHERE data_type_kid IN ( 11, 10, 9, 4, 5, 32, 33, 34, 29, 30, 31, 
                                13, 52, 53, 54, 56, 
                                87, 57, 58, 75, 203, 300, 302, 303, 222 )
         AND sample_kid = sKID;
--
  BEGIN
--
      OPEN crsrh(sKID, sID);
      LOOP
        FETCH crsrh
         INTO o_kid,      -- Well Header KID
              o_S_DATE,   -- Sample Date 
              o_FLUID,    -- Sample Volume
              o_FUNITS,   -- Sample Volume Units
              o_R_DATE,   -- Report Date
              o_lab_kid,  -- lab kid
              o_group_id, -- Group ID
              o_group_no; -- Group Number
        EXIT WHEN crsrh%NOTFOUND;  
--        
        SELECT COUNT(kid) 
          INTO l_cnt
          FROM CO2_Brine_Laboratory
         WHERE kid = o_lab_kid;
--
        IF (l_cnt > 0) THEN
          SELECT REPLACE(name, ',', ' ') 
            INTO o_lab
            FROM CO2_Brine_Laboratory
           WHERE kid = o_lab_kid;
        END IF;
      END LOOP;      
      CLOSE crsrh;
--
      SELECT COUNT(kid)
        INTO l_cnt
        FROM co2_brine_well
       WHERE kid = o_kid;
--
      IF (l_cnt > 0) THEN
        OPEN crsrw1(o_kid);
        LOOP
          FETCH crsrw1
           INTO o_WELL,   -- Well Name
                o_API,    -- API-Number
                o_TRS,    -- TRS Location of Well
                o_lat,    -- Latitude
                o_long,   -- Longitude
                o_utm_x,  -- UTM-X
                o_utm_y,  -- UTM-Y
                o_utm_z;  -- UTM-Zone
          EXIT WHEN crsrw1%NOTFOUND;
        END LOOP;
        CLOSE crsrw1;
--
      ELSE
        OPEN crsrw(o_kid);
        LOOP
          FETCH crsrw
           INTO o_WELL,   -- Well Name
                o_API,
                o_TRS;    -- TRS Location of Well
          EXIT WHEN crsrw%NOTFOUND;
          o_lat  := 0.0;
          o_long := 0.0;
        END LOOP;
        CLOSE crsrw;
--      
      END IF;
--
      o_Ca   := 'NA'; -- 10 Calcium Value
      o_Mg   := 'NA'; --  9 Magnesium Value
      o_Na   := 'NA'; --  4 Sodium Value
      o_K    := 'NA'; --  5 Potassium Value
      o_Fe   := 'NA'; -- 32 Iron Value
      o_Mn   := 'NA'; -- 29 Manganese Value
      o_Al   := 'NA'; -- 13 Aluminum Value
      o_Sr   := 'NA'; -- 11 Strontium Value
-- Anions
      o_Cl   := 'NA'; -- 52 Chloride Value
      o_Br   := 'NA'; -- 53 Bromide Value
      o_I    := 'NA'; -- 54 Iodide Value
      o_SO4  := 'NA'; -- 87 Sulphate Value
      o_CO3  := 'NA'; -- 57 Carbonate Value
      o_HCO3 := 'NA'; -- 58 Bicarbonate Value
      o_PO4  := 'NA'; -- 75 Phosphate Value
      o_BO3  := 'NA'; -- 56 Borate Value
--
-- Computed TDS
--
      o_TDS  := iqstrat.co2_brine_data_summary_pkg.sum_TDS(sKID); 
--      
-- Other
--
      o_PH    := 'NA'; -- 203 PH
      o_FORM  := 'NA'; -- 300 Formation
      o_TOP   := 'NA'; -- 302 Top Depth
      o_BASE  := 'NA'; -- 303 Base Depth
      o_RATIO := 'NA'; -- 222 Ratio
--
      OPEN crsr(sKID);
      LOOP
        FETCH crsr
         INTO o_id,    -- Analyte ID
              o_value, -- Value 
              o_units; -- Units
        EXIT WHEN crsr%NOTFOUND;
--
        IF (o_units = 'ug/L') THEN
          o_data := 0;
          IF (is_number(o_value) = 'YES') THEN
            o_data := TO_NUMBER(o_value) / 1000.0;        
          END IF;
          o_value := o_data;
        END IF;
--        
        IF (o_id = 300) THEN    -- IF Formation Name THEN
          o_FORM := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 302) THEN    -- IF Top Depth THEN
          o_TOP := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 303) THEN    -- IF Base Depth THEN
          o_BASE := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 203) THEN    -- IF PH THEN
          o_PH := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 222) THEN    -- IF RATIO THEN
          o_RATIO := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 10) THEN    -- IF Calcium THEN
          o_Ca := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 11) THEN    -- IF Strontium THEN
          o_Sr := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 9) THEN     -- IF Magnesium THEN
          o_Mg := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 4) THEN     -- IF Sodium THEN
          o_Na := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 5) THEN     -- IF Potassium THEN
          o_K := o_value;   --   Set Data
        END IF;
--
        o_data := 0.0;
        IF (is_number(o_value) = 'YES') THEN
          o_data := TO_NUMBER(o_value);
        END IF;
--
        o_Fe_d := 0.0;
--
--        IF ((o_id = 32) OR (o_id = 33) OR (o_id = 34)) THEN
--          o_Fe := o_value;   --   Set Data
--        END IF;
--        
        IF (o_id = 32) THEN    -- IF Iron THEN
          o_Fe_d := o_Fe_d + o_data;   --   Set Data
          o_Fe   := o_Fe_d;
        END IF;
--
        IF (o_id = 33) THEN    -- IF Iron THEN
          o_Fe_d := o_Fe_d + o_data;   --   Set Data
          o_Fe   := o_Fe_d;
        END IF;
--
        IF (o_id = 34) THEN    -- IF Iron THEN
          o_Fe_d := o_Fe_d + o_data;   --   Set Data
          o_Fe   := o_Fe_d;
        END IF;
--
        o_Mn_d := 0.0;
--
        IF (o_id = 29) THEN    -- IF Manganese THEN
          o_Mn_d := o_Mn_d + o_data;   --   Set Data
          o_Mn   := o_Mn_d;   --   Set Data
        END IF;
--
        IF (o_id = 30) THEN    -- IF Manganese THEN
          o_Mn_d := o_Mn_d + o_data;   --   Set Data
          o_Mn   := o_Mn_d;   --   Set Data
        END IF;
--
        IF (o_id = 31) THEN    -- IF Manganese THEN
          o_Mn_d := o_Mn_d + o_data;   --   Set Data
          o_Mn   := o_Mn_d;   --   Set Data
        END IF;
--
        IF (o_id = 13) THEN    -- IF Aluminum THEN
          o_Al := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 52) THEN    -- IF Cloride THEN
          o_Cl := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 53) THEN    -- IF Bromide THEN
          o_Br := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 54) THEN    -- IF Iodide THEN
          o_I := o_value;    --   Set Data
        END IF;
--
        IF (o_id = 87) THEN    -- IF Sulphate THEN
          o_SO4 := o_value;  --   Set Data
        END IF;
--
        IF (o_id = 57) THEN    -- IF Carbonate THEN
          o_CO3 := o_value;  --   Set Data
        END IF;
--
        IF (o_id = 58) THEN    -- IF Bicarbonate THEN
          o_HCO3 := o_value; --   Set Data
        END IF;
--
        IF (o_id = 56) THEN    -- IF Borate THEN
          o_BO3 := o_value;  --   Set Data
        END IF;
--
        IF (o_id = 75) THEN    -- IF Phosphate THEN
          o_PO4 := o_value;  --   Set Data
        END IF;
--
      END LOOP;
      CLOSE crsr;
--
      htp.print(o_WELL||','||o_API||','||o_TRS||','||o_lat||','||o_long||
      ','||o_utm_x||','||o_utm_y||','||o_utm_z||','||o_group_id||','||o_group_no||
      ','||o_S_DATE||','||o_R_DATE||
      ','||o_FORM||','||o_TOP||','||o_BASE||','||o_PH||
      ','||o_Ca||','||o_Mg||','||o_Sr||','||o_Na||','||o_K||','||o_Fe||','||o_Mn||
      ','||o_Cl||','||o_Br||','||o_I||','||o_SO4||','||o_CO3||','||o_HCO3||','||o_BO3||','||o_PO4||
      ','||o_TDS||','||o_RATIO||','||o_lab||',<br>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('Brine KID='||sKID||' Well KID='||o_kid||' '||SQLERRM||'</td>');
--
  END build_row;
--
--
-- PROCEDURE    build_subset()
-- Description: This procedure will add the table row for sample
-- * Input:     sKID = Sample KID
-- * Output:    The sample data row
--
  PROCEDURE build_subset(sKID IN VARCHAR2, sID IN VARCHAR2) IS
--
    l_cnt    NUMBER;
--
    o_id     iqstrat.co2_brine_data.sample_kid%TYPE; -- id
    o_value  iqstrat.co2_brine_data.value%TYPE; -- value
    o_units  iqstrat.co2_brine_data.units%TYPE; -- units
    o_data   NUMBER;
    o_Fe_d   NUMBER;
    o_Mn_d   NUMBER;
-- Cations
    o_Ca     iqstrat.co2_brine_data.value%TYPE; -- 10 Calcium Value
    o_Mg     iqstrat.co2_brine_data.value%TYPE; --  9 Magnesium Value
    o_Na     iqstrat.co2_brine_data.value%TYPE; --  4 Sodium Value
    o_K      iqstrat.co2_brine_data.value%TYPE; --  5 Potassium Value
    o_Fe     iqstrat.co2_brine_data.value%TYPE; -- 32 Iron Value
    o_Mn     iqstrat.co2_brine_data.value%TYPE; -- 29 Manganese Value
    o_Al     iqstrat.co2_brine_data.value%TYPE; -- 13 Aluminum Value
    o_Sr     iqstrat.co2_brine_data.value%TYPE; -- 11 Strontium Value
-- Anions
    o_Cl     iqstrat.co2_brine_data.value%TYPE; -- 52 Chloride Value
    o_Br     iqstrat.co2_brine_data.value%TYPE; -- 53 Bromide Value
    o_I      iqstrat.co2_brine_data.value%TYPE; -- 54 Iodide Value
    o_SO4    iqstrat.co2_brine_data.value%TYPE; -- 87 Sulphate Value
    o_CO3    iqstrat.co2_brine_data.value%TYPE; -- 57 Carbonate Value
    o_HCO3   iqstrat.co2_brine_data.value%TYPE; -- 58 Bicarbonate Value
    o_PO4    iqstrat.co2_brine_data.value%TYPE; -- 75 Phosphate Value
    o_BO3    iqstrat.co2_brine_data.value%TYPE; -- 56 Borate Value
-- Other
    o_kid    iqstrat.CO2_brine_wells.kid%TYPE;  -- well kid
    o_WELL   iqstrat.CO2_brine_wells.name%TYPE; -- well name
    o_API    iqstrat.CO2_brine_wells.api_number%TYPE; -- api-number
    o_lat    co2_brine_well.nad27_latitude%TYPE;
    o_long   co2_brine_well.nad27_longitude%TYPE;
    o_utm_x  co2_brine_well.nad27_utm_x%TYPE;
    o_utm_y  co2_brine_well.nad27_utm_y%TYPE;
    o_utm_z  co2_brine_well.nad27_utm_zone%TYPE;
    o_TRS    VARCHAR2(60); 
    o_lab    VARCHAR2(255); -- Lab KID
    o_lab_kid iqstrat.CO2_brine_sample.lab_kid%TYPE; -- api-number
--    
    o_S_DATE VARCHAR2(40);                                -- Sample Date
    o_R_DATE VARCHAR2(40);                                -- Reported Date
    o_FLUID  iqstrat.co2_brine_sample.amount_fluid%TYPE;  -- Amount of Fluid
    o_FUNITS iqstrat.co2_brine_sample.amount_fluid_units%TYPE;  -- Fluid Units
    o_group_no iqstrat.co2_brine_sample.group_no%TYPE;  -- Fluid Units
    o_group_id iqstrat.co2_brine_sample.group_id%TYPE;  -- Fluid Units
--   
    o_TDS    NUMBER;
--
    o_PH     iqstrat.co2_brine_data.value%TYPE; -- 203 PH
    o_TEMP   iqstrat.co2_brine_data.value%TYPE; -- 205 degrees C
    o_FORM   iqstrat.co2_brine_data.value%TYPE; -- 300 Formation
    o_TOP    iqstrat.co2_brine_data.value%TYPE; -- 302 Top Depth
    o_BASE   iqstrat.co2_brine_data.value%TYPE; -- 303 Base Depth
    o_RATIO  iqstrat.co2_brine_data.value%TYPE; -- 222 Base Depth
--    
-- Cursors
--
    CURSOR crsrh(sKID IN VARCHAR2, sID IN VARCHAR2) IS
      SELECT well_kid,
             NVL(TO_CHAR(sampled_date, 'MM/DD/YYYY HH24:MI'), 'NA'),
             NVL(amount_fluid, 0),
             NVL(amount_fluid_units, 'NA'),
             NVL(TO_CHAR(reported_date, 'MM/DD/YYYY HH24:MI'), 'NA'),
             lab_kid,
             group_id,
             group_no
--             REPLACE(SELECT name FROM CO2_Brine_Laboratory where kid = co2.lab_kid), ',', ' ')
        FROM co2_brine_sample co2
       WHERE kid = sKID
         AND group_id = sID;
--
    CURSOR crsrw(sKID IN VARCHAR2) IS
      SELECT NVL(name, 'NA'),
             NVL(api_number, 'NA'),
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, 'NA')
        FROM co2_brine_wells
       WHERE kid = sKID;
--
    CURSOR crsrw1(sKID IN VARCHAR2) IS
      SELECT NVL(REPLACE(lease_name,',',' ')||' '||well_name, 'NA'),
             NVL(api_number, 'NA'),
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, 'NA'),
             nad27_latitude,
             nad27_longitude,
             nad27_utm_x,
             nad27_utm_y,
             nad27_utm_zone
        FROM co2_brine_well
       WHERE kid = sKID;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT data_type_kid,
             value,
             units
        FROM co2_brine_data
       WHERE data_type_kid IN ( 11, 10, 9, 4, 5, 32, 33, 34, 29, 30, 31, 
                                13, 52, 53, 54, 56, 
                                87, 57, 58, 75, 203, 205, 300, 302, 303, 222 )
         AND sample_kid = sKID;
--
  BEGIN
--
      OPEN crsrh(sKID, sID);
      LOOP
        FETCH crsrh
         INTO o_kid,      -- Well Header KID
              o_S_DATE,   -- Sample Date 
              o_FLUID,    -- Sample Volume
              o_FUNITS,   -- Sample Volume Units
              o_R_DATE,   -- Report Date
              o_lab_kid,  -- lab kid
              o_group_id, -- Group ID
              o_group_no; -- Group Number
        EXIT WHEN crsrh%NOTFOUND;  
--        
        SELECT COUNT(kid) 
          INTO l_cnt
          FROM CO2_Brine_Laboratory
         WHERE kid = o_lab_kid;
--
        IF (l_cnt > 0) THEN
          SELECT REPLACE(name, ',', ' ') 
            INTO o_lab
            FROM CO2_Brine_Laboratory
           WHERE kid = o_lab_kid;
        ELSE
          o_lab := 'NA';
        END IF;
      END LOOP;      
      CLOSE crsrh;
--
      SELECT COUNT(kid)
        INTO l_cnt
        FROM co2_brine_well
       WHERE kid = o_kid;
--
      IF (l_cnt > 0) THEN
        OPEN crsrw1(o_kid);
        LOOP
          FETCH crsrw1
           INTO o_WELL,   -- Well Name
                o_API,    -- API-Number
                o_TRS,    -- TRS Location of Well
                o_lat,    -- Latitude
                o_long,   -- Longitude
                o_utm_x,  -- UTM-X
                o_utm_y,  -- UTM-Y
                o_utm_z;  -- UTM-Zone
          EXIT WHEN crsrw1%NOTFOUND;
        END LOOP;
        CLOSE crsrw1;
--
      ELSE
        OPEN crsrw(o_kid);
        LOOP
          FETCH crsrw
           INTO o_WELL,   -- Well Name
                o_API,
                o_TRS;    -- TRS Location of Well
          EXIT WHEN crsrw%NOTFOUND;
          o_lat  := 0.0;
          o_long := 0.0;
        END LOOP;
        CLOSE crsrw;
--      
      END IF;
--
      o_Ca   := 'NA'; -- 10 Calcium Value
      o_Mg   := 'NA'; --  9 Magnesium Value
      o_Na   := 'NA'; --  4 Sodium Value
      o_K    := 'NA'; --  5 Potassium Value
      o_Fe   := 'NA'; -- 32 Iron Value
      o_Mn   := 'NA'; -- 29 Manganese Value
      o_Al   := 'NA'; -- 13 Aluminum Value
      o_Sr   := 'NA'; -- 11 Strontium Value
-- Anions
      o_Cl   := 'NA'; -- 52 Chloride Value
      o_Br   := 'NA'; -- 53 Bromide Value
      o_I    := 'NA'; -- 54 Iodide Value
      o_SO4  := 'NA'; -- 87 Sulphate Value
      o_CO3  := 'NA'; -- 57 Carbonate Value
      o_HCO3 := 'NA'; -- 58 Bicarbonate Value
      o_PO4  := 'NA'; -- 75 Phosphate Value
      o_BO3  := 'NA'; -- 56 Borate Value
--
-- Computed TDS
--
--      o_TDS  := iqstrat.co2_brine_data_summary_pkg.sum_TDS(sKID); 
--      
-- Other
--
      o_PH    := 'NA'; -- 203 PH
      o_FORM  := 'NA'; -- 300 Formation
      o_TOP   := 'NA'; -- 302 Top Depth
      o_BASE  := 'NA'; -- 303 Base Depth
      o_RATIO := 'NA'; -- 222 Ratio
--
      OPEN crsr(sKID);
      LOOP
        FETCH crsr
         INTO o_id,    -- Analyte ID
              o_value, -- Value 
              o_units; -- Units
        EXIT WHEN crsr%NOTFOUND;
--
        IF (o_units = 'ug/L') THEN
          o_data := 0;
          IF (is_number(o_value) = 'YES') THEN
            o_data := TO_NUMBER(o_value) / 1000.0;        
          END IF;
          o_value := o_data;
        END IF;
--        
        IF (o_id = 300) THEN    -- IF Formation Name THEN
          o_FORM := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 302) THEN    -- IF Top Depth THEN
          o_TOP := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 303) THEN    -- IF Base Depth THEN
          o_BASE := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 203) THEN    -- IF PH THEN
          o_PH := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 205) THEN    -- IF PH THEN
          o_TEMP := o_value; --   Set Data
        END IF;
--        
        IF (o_id = 222) THEN    -- IF RATIO THEN
          o_RATIO := o_value;   --   Set Data
        END IF;
--        
        IF (o_id = 10) THEN    -- IF Calcium THEN
          o_Ca := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 11) THEN    -- IF Strontium THEN
          o_Sr := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 9) THEN     -- IF Magnesium THEN
          o_Mg := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 4) THEN     -- IF Sodium THEN
          o_Na := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 5) THEN     -- IF Potassium THEN
          o_K := o_value;   --   Set Data
        END IF;
--
        o_data := 0.0;
        IF (is_number(o_value) = 'YES') THEN
          o_data := TO_NUMBER(o_value);
        END IF;
--
        o_Fe_d := 0.0;
--
--        IF ((o_id = 32) OR (o_id = 33) OR (o_id = 34)) THEN
--          o_Fe := o_value;   --   Set Data
--        END IF;
--        
        IF (o_id = 32) THEN    -- IF Iron THEN
          o_Fe_d := o_Fe_d + o_data;   --   Set Data
          o_Fe   := o_Fe_d;
        END IF;
--
        IF (o_id = 33) THEN    -- IF Iron THEN
          o_Fe_d := o_Fe_d + o_data;   --   Set Data
          o_Fe   := o_Fe_d;
        END IF;
--
        IF (o_id = 34) THEN    -- IF Iron THEN
          o_Fe_d := o_Fe_d + o_data;   --   Set Data
          o_Fe   := o_Fe_d;
        END IF;
--
        o_Mn_d := 0.0;
--
        IF (o_id = 29) THEN    -- IF Manganese THEN
          o_Mn_d := o_Mn_d + o_data;   --   Set Data
          o_Mn   := o_Mn_d;   --   Set Data
        END IF;
--
        IF (o_id = 30) THEN    -- IF Manganese THEN
          o_Mn_d := o_Mn_d + o_data;   --   Set Data
          o_Mn   := o_Mn_d;   --   Set Data
        END IF;
--
        IF (o_id = 31) THEN    -- IF Manganese THEN
          o_Mn_d := o_Mn_d + o_data;   --   Set Data
          o_Mn   := o_Mn_d;   --   Set Data
        END IF;
--
        IF (o_id = 13) THEN    -- IF Aluminum THEN
          o_Al := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 52) THEN    -- IF Cloride THEN
          o_Cl := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 53) THEN    -- IF Bromide THEN
          o_Br := o_value;   --   Set Data
        END IF;
--
        IF (o_id = 54) THEN    -- IF Iodide THEN
          o_I := o_value;    --   Set Data
        END IF;
--
        IF (o_id = 87) THEN    -- IF Sulphate THEN
          o_SO4 := o_value;  --   Set Data
        END IF;
--
        IF (o_id = 57) THEN    -- IF Carbonate THEN
          o_CO3 := o_value;  --   Set Data
        END IF;
--
        IF (o_id = 58) THEN    -- IF Bicarbonate THEN
          o_HCO3 := o_value; --   Set Data
        END IF;
--
        IF (o_id = 56) THEN    -- IF Borate THEN
          o_BO3 := o_value;  --   Set Data
        END IF;
--
        IF (o_id = 75) THEN    -- IF Phosphate THEN
          o_PO4 := o_value;  --   Set Data
        END IF;
--
      END LOOP;
      CLOSE crsr;
--
      htp.print(o_WELL||','||o_API||','||o_TRS||','||o_lat||','||o_long||
      ','||o_utm_x||','||o_utm_y||','||o_utm_z||
      ','||o_group_id||','||o_group_no||','||o_S_DATE||
      ','||o_PH||','||o_TEMP||','||o_SO4||','||o_TDS||','||o_lab||',<br>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('Brine KID='||sKID||' Well KID='||o_kid||' '||SQLERRM||'</td>');
--
  END build_subset;
--
--
-- FUNCTION    is_number
-- Description: This procedure will check if the string is a number
--
  FUNCTION is_number(str IN VARCHAR2) RETURN VARCHAR2 IS
--
  o_result VARCHAR2(200);
--
  BEGIN
--
    SELECT DECODE(TRANSLATE(LTRIM(str,'-'),'*0123456789.','*'),null,str,'?') 
      INTO o_result
      FROM DUAL;
--
    IF (o_result = '?') THEN
      o_result := 'NO';
    ELSE
      o_result := 'YES';
    END IF;
--
    RETURN (o_result);   
--
  END is_number;
--
--
END co2_brine_summary_csv_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON co2_brine_summary_csv_pkg TO apex_public_user;