-- * PLSQL:       co2_events_pkg.sql Version 1.1 08/03/2015
-- * Author:      John R. Victorine
-- * Description: This Package will build the Kansas Earthquake Data XML File.
-- * Copyright (c) 2015 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_events_pkg AS
--
  PROCEDURE getXML;
--
  PROCEDURE dtd_and_columns;
--
END co2_events_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_events_pkg AS
--
-- PROCEDURE    getXML
-- Description: This procedure will get earthquake data as xml by Key.  
-- 
  PROCEDURE getXML IS
--
    l_count NUMBER;
--
    o_kid      iqstrat.co2_events.kid%TYPE;         -- Primary Key
    o_date     VARCHAR2(60);                        -- 'YYYY-MM-DD HH24:MI:SS'
    o_date2    VARCHAR2(60);                        -- 'MM/DD/YYYY HH24:MI:SS'
    o_utc      VARCHAR2(60);
    o_lat      iqstrat.co2_events.latitude%TYPE;    -- latitude
    o_long     iqstrat.co2_events.longitude%TYPE;   -- longitude
    o_depth    iqstrat.co2_events.depth%TYPE;       -- depth
    o_dunits   iqstrat.co2_events.units%TYPE;       -- depth units
    o_mag      iqstrat.co2_events.local_mag%TYPE;   -- local magnitude
    o_mag_mom  iqstrat.co2_events.moment_mag%TYPE;  -- moment magnitude
    o_src      VARCHAR2(40);
    d_hr       NUMBER;
--
    o_temp     VARCHAR(4096);
--
   CURSOR crsr IS
     SELECT kid, 
            TO_CHAR(event, 'YYYY-MM-DD HH24:MI:SS') AS str,
            TO_CHAR(CAST(FROM_TZ(CAST(event AS TIMESTAMP), 'UTC') AT TIME ZONE sessiontimezone
	        AS DATE), 'MM/DD/YYYY HH24:MI:SS'),
--            TO_CHAR(event, 'MM/DD/YYYY HH24:MI:SS'),
            latitude,
            longitude,
            depth,
            units,
            NVL(local_mag,  -999),
            NVL(moment_mag, -999),
            'CO2 Sensor Array'
       FROM iqstrat.co2_events
      WHERE event is NOT NULL
     ORDER BY str;
--
  BEGIN
--
--  ADD DTD to XML
--
    dtd_and_columns;
--
--
    SELECT COUNT(kid)
      INTO l_count
      FROM iqstrat.co2_events
     WHERE event is NOT NULL;
--       AND state='KS';
--
    htp.print('<event>');
    htp.print('  <data records="'||l_count||'">');
--
--  GET Sensor Data 
--
    OPEN crsr;
    LOOP
      FETCH crsr
       INTO o_kid,     -- Unique KEY
            o_date,    -- Date
            o_date2,   -- Date 2
            o_lat,     -- Latitude
            o_long,    -- Longitude
            o_depth,   -- Depth
            o_dunits,  -- Depth Units
            o_mag,     -- Magnitude local
            o_mag_mom, -- Magnitude moment
            o_src;     -- Source of data
      EXIT WHEN crsr%NOTFOUND;
--      
      o_temp := '    <row KID="'||o_kid||'" ';
      o_temp := o_temp||'date_str="'||o_date||'" ';
--      o_temp := o_temp||'utc="'||o_utc||'" ';
      o_temp := o_temp||'central="'||o_date2||'" ';
      o_temp := o_temp||'lat="'||o_lat||'" ';
      o_temp := o_temp||'long="'||o_long||'" ';
      o_temp := o_temp||'depth="'||o_depth||'" ';
      o_temp := o_temp||'depth_units="'||o_dunits||'" ';
      IF (o_mag > -999) THEN
      o_temp := o_temp||'mag_local="'||o_mag||'" ';
      END IF;
      IF (o_mag_mom > -999) THEN
      o_temp := o_temp||'mag_moment="'||o_mag_mom||'" ';
      END IF;
      o_temp := o_temp||'source="'||o_src||'"/>';
--      
      htp.print(o_temp);
--
    END LOOP;
    CLOSE crsr;
--
    htp.print('  </data>');
    htp.print('</event>');
--             
--             
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred in getXML(): '||SQLERRM);
  END getXML;
--
--
-- PROCEDURE    dtd_and_columns
-- Description: This procedure will build the DTD.
--
  PROCEDURE dtd_and_columns IS
--
  BEGIN
--
  htp.print('<?xml version="1.0"?>');
  htp.print('<!DOCTYPE event [');
  htp.print('<!ELEMENT event (data*)+>');
  htp.print('<!ELEMENT data (row*)>');
  htp.print('<!ATTLIST data records  CDATA #REQUIRED>');
  htp.print('<!ELEMENT row EMPTY>');
  htp.print('<!ATTLIST row  KID         CDATA #IMPLIED');    -- Primary KEY
  htp.print('               date_str    CDATA #IMPLIED');    -- Date and Time String
  htp.print('               utc         CDATA #IMPLIED');    -- Universal Data and Time String
  htp.print('               central     CDATA #IMPLIED');    -- Central Date and Time String
  htp.print('               lat         CDATA #IMPLIED');    -- Latitude  
  htp.print('               long        CDATA #IMPLIED');    -- Longitude 
  htp.print('               depth       CDATA #IMPLIED');    -- Depth of event
  htp.print('               depth_units CDATA #IMPLIED');    -- Depth units
  htp.print('               mag_local   CDATA #IMPLIED');    -- Local Magnitude
  htp.print('               mag_moment  CDATA #IMPLIED');    -- Moment Magnitude
  htp.print('               state       CDATA #IMPLIED');    -- State
  htp.print('               source      CDATA #IMPLIED>]>'); --Source
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred in dtd_and_columns(): '||SQLERRM);
  END dtd_and_columns;
--
--
END co2_events_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON  co2_events_pkg to apex_public_user;