-- * PLSQL:       co2_events_summary_pkg.sql Version 1.1 10/08/2014
-- * Author:      John R. Victorine
-- * Description: This Package will build a summary page identifing cuttings reports
-- *              by county.
-- * Copyright (c) 2014 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_events_summary_pkg AS
  PROCEDURE build_page;
  PROCEDURE build_web_page(sEvent IN VARCHAR2,
                           sTitle IN VARCHAR2);
  PROCEDURE build_csv_page(sEvent IN VARCHAR2,
                           sTitle IN VARCHAR2);
  PROCEDURE build_csv_all_page;
-----
  PROCEDURE build_title_icons(sTitle IN VARCHAR2);
  PROCEDURE build_finish(sEvent IN VARCHAR2,
                         sTitle IN VARCHAR2);
  PROCEDURE build_main_finish;
END co2_events_summary_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_events_summary_pkg AS
--
-- PROCEDURE    build_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-nu mbers and construct a XML.
-- * Input:     sEvent = the Date String to retrieve seismic data
--              sTitle = The title of the web page
-- * Output:    Summary Web Page for specific month of Kansas.
--
  PROCEDURE build_page IS
--
    l_count  NUMBER;
    o_date   VARCHAR2(10);
    o_title  VARCHAR2(20);
--
    CURSOR crsr IS
      SELECT UNIQUE(TO_CHAR(event, 'YYYY/MM')) AS STR
        FROM co2_events
      ORDER BY STR;
--
  BEGIN
--
    SELECT COUNT(UNIQUE(TO_CHAR(event, 'YYYY/MM')))
      INTO l_count
      FROM co2_events;
--
--  Start HTML
--
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('Monthly Summary Pages');
    htp.headClose;
--    
    htp.print('<BODY>');
--
    build_title_icons( 'Monthly Summary Pages for' );
--
    htp.print('<p>');
    htp.print('<b>Create a Comma Separated Values (CSV) Web Page for ALL Seismic Data: </b>');
    htp.print('  <a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_events_summary_pkg.build_csv_all_page"'||
              ' target="body"> seismic data.csv</a>'); 
--    
    htp.print('<center><table cellpadding="2" cellspacing="2" border="1" width="100%">');
    htp.p('<TH bgColor=#b0c4de>Month Year</TH>');
    htp.p('<TH bgColor=#b0c4de>Monthly Summary Page</TH>');
    htp.p('<TH bgColor=#b0c4de>Monthly CSV File</TH>');
    htp.tableRowClose;
    htp.print('</center>');

    IF (l_count > 0) THEN
--
      OPEN crsr;
      LOOP
        FETCH crsr
         INTO o_date;   -- Date - Format 'YYYY//MM'
        EXIT WHEN crsr%NOTFOUND;
--
        SELECT UNIQUE(TO_CHAR(event, 'MONTH YYYY'))
          INTO o_title
	  FROM co2_events
         WHERE TO_CHAR(event, 'YYYY/MM') = o_date;
--
        htp.print('<tr>');
        htp.print('  <td>'||o_title||'</td>');
        htp.print('  <td>'||
        '<a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_events_summary_pkg.build_web_page?sEvent='||
        o_date||'&sTitle='||o_title||'" target="body">'||o_title||'.HTML</a></td>');
        htp.print('  <td>'||
        '<a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_events_summary_pkg.build_csv_page?sEvent='||
        o_date||'&sTitle='||o_title||'" target="body">'||o_title||'.CSV</a></td>');
        htp.print('</tr>');
--        
      END LOOP;
      CLOSE crsr;
--
    END IF;
--   
    htp.tableClose;
--
    build_main_finish;
--    
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_page;
--
--
-- PROCEDURE    build_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-nu mbers and construct a XML.
-- * Input:     sEvent = the Date String to retrieve seismic data
--              sTitle = The title of the web page
-- * Output:    Summary Web Page for specific month of Kansas.
--
  PROCEDURE build_web_page(sEvent IN VARCHAR2,
                           sTitle IN VARCHAR2) IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    iqstrat.co2_events.kid%TYPE;        -- table primary key
    o_date   VARCHAR2(12);                       -- Date - Format 'DD/MM/YYYY'
    o_time   VARCHAR2(12);                       -- Time - Format 'HH24:MI:SS'
    o_lat    iqstrat.co2_events.latitude%TYPE;   -- latitude of event
    o_long   iqstrat.co2_events.longitude%TYPE;  -- longitude of event
    o_depth  iqstrat.co2_events.depth%TYPE;      -- depth of event
    o_units  iqstrat.co2_events.units%TYPE;      -- depth units
    o_local  iqstrat.co2_events.local_mag%TYPE;  -- local magnitude
    o_momnt  iqstrat.co2_events.moment_mag%TYPE; -- moment magnitude
--
    CURSOR crsr(data IN VARCHAR2) IS
      SELECT TO_CHAR(event, 'MM/DD/YYYY') AS dEvent,
             TO_CHAR(event, 'HH24:MI:SS') AS tEvent,
             latitude,
             longitude,
             depth,
             LOWER(units),
             NVL(local_mag,  -999),
             NVL(moment_mag, -999)            
        FROM iqstrat.co2_events
       WHERE TO_CHAR(event, 'YYYY/MM') = data
      ORDER BY dEvent,tEvent;
--
  BEGIN
--
    SELECT COUNT(kid)
      INTO l_count
      FROM iqstrat.co2_events
     WHERE TO_CHAR(event, 'YYYY/MM') = sEvent;
--
--  Start HTML
--
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('CO2 Seismic Sensor Data');
    htp.headClose;
--    
    htp.print('<BODY>');
--
    build_title_icons( 'Summary Page for '||INITCAP(sTitle) );
--
--    htp.tableRowOpen('CENTER');
    htp.print('<center><table cellpadding="2" cellspacing="2" border="1" width="100%">');
    htp.p('<TH bgColor=#b0c4de colspan="5">&nbsp;</TH>');
    htp.p('<TH bgColor=#b0c4de colspan="2">Magnitude</TH>');
    htp.tableRowClose;
--
    htp.p('<TH bgColor=#b0c4de>Date</TH>');
    htp.p('<TH bgColor=#b0c4de>Time</TH>');
    htp.p('<TH bgColor=#b0c4de>Latiude</TH>');
    htp.p('<TH bgColor=#b0c4de>Longitude</TH>');
    htp.p('<TH bgColor=#b0c4de>Depth (km)</TH>');
    htp.p('<TH bgColor=#b0c4de>Local</TH>');
    htp.p('<TH bgColor=#b0c4de>Moment</TH>');      
    htp.tableRowClose;
    htp.print('</center>');
--
    IF (l_count > 0) THEN
--
      OPEN crsr(sEvent);
      LOOP
        FETCH crsr
         INTO o_date,   -- Date - Format 'DD/MM/YYYY'
              o_time,   -- Time - Format 'HH24:MI:SS'
              o_lat,    -- latitude of event
              o_long,   -- longitude of event
              o_depth,  -- depth of event
              o_units,  -- depth units
              o_local,  -- local magnitude
              o_momnt;  -- moment magnitude
        EXIT WHEN crsr%NOTFOUND;
--
        htp.print('<tr>');
        htp.print('  <td>'||o_date||'</td>');
        htp.print('  <td>'||o_time||'</td>');
        htp.print('  <td>'||o_lat||'</td>');
        htp.print('  <td>'||o_long||'</td>');
        htp.print('  <td>'||o_depth||'</td>');
        IF (o_local > -999) THEN
          htp.print('  <td>'||o_local||'</td>');
        ELSE
          htp.print('  <td>&nbsp;</td>');
        END IF;
        IF (o_momnt > -999) THEN
          htp.print('  <td>'||o_momnt||'</td>');      
        ELSE
          htp.print('  <td>&nbsp;</td>');
        END IF;
        htp.print('</tr>');
--
      END LOOP;
      CLOSE crsr;
--
    END IF;
--
    htp.tableClose;
--
    build_finish(sEvent, sTitle);
--    
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_web_page;
--
--
-- PROCEDURE    build_csv_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-nu mbers and construct a XML.
-- * Input:     sEvent = the Date String to retrieve seismic data
--              sTitle = The title of the web page
-- * Output:    Summary Web Page for specific month of Kansas.
--
  PROCEDURE build_csv_page(sEvent IN VARCHAR2,
                           sTitle IN VARCHAR2) IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    iqstrat.co2_events.kid%TYPE;        -- table primary key
    o_date   VARCHAR2(12);                       -- Date - Format 'DD/MM/YYYY'
    o_time   VARCHAR2(12);                       -- Time - Format 'HH24:MI:SS'
    o_lat    iqstrat.co2_events.latitude%TYPE;   -- latitude of event
    o_long   iqstrat.co2_events.longitude%TYPE;  -- longitude of event
    o_depth  iqstrat.co2_events.depth%TYPE;      -- depth of event
    o_units  iqstrat.co2_events.units%TYPE;      -- depth units
    o_local  iqstrat.co2_events.local_mag%TYPE;  -- local magnitude
    o_momnt  iqstrat.co2_events.moment_mag%TYPE; -- moment magnitude
    o_temp   VARCHAR2(255);
--
    CURSOR crsr(data IN VARCHAR2) IS
      SELECT TO_CHAR(event, 'MM/DD/YYYY') AS dEvent,
             TO_CHAR(event, 'HH24:MI:SS') AS tEvent,
             latitude,
             longitude,
             depth,
             LOWER(units),
             NVL(local_mag,  -999),
             NVL(moment_mag, -999)            
        FROM iqstrat.co2_events
       WHERE TO_CHAR(event, 'YYYY/MM') = data
      ORDER BY dEvent,tEvent;
--
  BEGIN
--
    SELECT COUNT(kid)
      INTO l_count
      FROM iqstrat.co2_events
     WHERE TO_CHAR(event, 'YYYY/MM') = sEvent;
--
--  Start HTML
--
    htp.print('<HTML><HEAD><TITLE>CO2 Seismic Events</TITLE></HEAD><BODY>');
    htp.p( 'Summary Page for '||sTitle||' Seismic Array Data <br>');
--
    o_temp := 'Date,Time,Latitude,Longitude,depth,units,ml,mm, <br>';
    htp.p( o_temp );
--
    IF (l_count > 0) THEN
--
      OPEN crsr(sEvent);
      LOOP
        FETCH crsr
         INTO o_date,   -- Date - Format 'DD/MM/YYYY'
              o_time,   -- Time - Format 'HH24:MI:SS'
              o_lat,    -- latitude of event
              o_long,   -- longitude of event
              o_depth,  -- depth of event
              o_units,  -- depth units
              o_local,  -- local magnitude
              o_momnt;  -- moment magnitude
        EXIT WHEN crsr%NOTFOUND;
--
--
--      CSV Well Record
-- 
        o_temp := o_date||','||o_time||','||o_lat||','||o_long||','||o_depth||','||o_units||',';
--      
        IF (o_local > -999) THEN
          o_temp := o_temp||o_local||',';
        ELSE
          o_temp := o_temp||' ,';
        END IF;
--      
        IF (o_momnt > -999) THEN
          o_temp := o_temp||o_momnt||',';
        ELSE
          o_temp := o_temp||' ,';
        END IF;
--
        htp.p( o_temp||'<br>' );
--
      END LOOP;
      CLOSE crsr;
--
    htp.print('</BODY></HTML>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
--
  END build_csv_page;
--
--
-- PROCEDURE    build_csv_all_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-nu mbers and construct a XML.
-- * Output:    Summary Web Page .
--
  PROCEDURE build_csv_all_page IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_str    VARCHAR2(10);
    o_kid    iqstrat.co2_events.kid%TYPE;        -- table primary key
    o_date   VARCHAR2(12);                       -- Date - Format 'DD/MM/YYYY'
    o_time   VARCHAR2(12);                       -- Time - Format 'HH24:MI:SS'
    o_lat    iqstrat.co2_events.latitude%TYPE;   -- latitude of event
    o_long   iqstrat.co2_events.longitude%TYPE;  -- longitude of event
    o_depth  iqstrat.co2_events.depth%TYPE;      -- depth of event
    o_units  iqstrat.co2_events.units%TYPE;      -- depth units
    o_local  iqstrat.co2_events.local_mag%TYPE;  -- local magnitude
    o_momnt  iqstrat.co2_events.moment_mag%TYPE; -- moment magnitude
    o_temp   VARCHAR2(255);
--
    CURSOR crsr IS
      SELECT TO_CHAR(event, 'YYYY/MM') AS str,
             TO_CHAR(event, 'MM/DD/YYYY') AS dEvent,
             TO_CHAR(event, 'HH24:MI:SS') AS tEvent,
             latitude,
             longitude,
             depth,
             LOWER(units),
             NVL(local_mag,  -999),
             NVL(moment_mag, -999)            
        FROM iqstrat.co2_events
      ORDER BY str;
--
  BEGIN
--
    SELECT COUNT(kid)
      INTO l_count
      FROM iqstrat.co2_events;
--
--  Start HTML
--
    htp.print('<HTML><HEAD><TITLE>CO2 Seismic Events</TITLE></HEAD><BODY>');
    htp.p( 'Summary Page for Seismic Array Data <br>');
--
    o_temp := 'Date,Time,Latitude,Longitude,depth,units,ml,mm, <br>';
    htp.p( o_temp );
--
    IF (l_count > 0) THEN
--
      OPEN crsr;
      LOOP
        FETCH crsr
         INTO o_str,    -- ORDER BY 'YYYY/MM'
              o_date,   -- Date - Format 'DD/MM/YYYY'
              o_time,   -- Time - Format 'HH24:MI:SS'
              o_lat,    -- latitude of event
              o_long,   -- longitude of event
              o_depth,  -- depth of event
              o_units,  -- depth units
              o_local,  -- local magnitude
              o_momnt;  -- moment magnitude
        EXIT WHEN crsr%NOTFOUND;
--
--
--      CSV Well Record
-- 
        o_temp := o_date||','||o_time||','||o_lat||','||o_long||','||o_depth||','||o_units||',';
--      
        IF (o_local > -999) THEN
          o_temp := o_temp||o_local||',';
        ELSE
          o_temp := o_temp||' ,';
        END IF;
--      
        IF (o_momnt > -999) THEN
          o_temp := o_temp||o_momnt||',';
        ELSE
          o_temp := o_temp||' ,';
        END IF;
--
        htp.p( o_temp||'<br>' );
--
      END LOOP;
      CLOSE crsr;
--
    htp.print('</BODY></HTML>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
--
  END build_csv_all_page;
--
--
-- PROCEDURE    build_title_icons
-- Description: This procedure will add the Title icons to the Web Page
--
  PROCEDURE build_title_icons(sTitle IN VARCHAR2) IS
--
  BEGIN
--
    htp.print('<table class=header cellpadding="2" cellspacing="2" border="0" width="100%">');
    htp.print('  <tr>');
    htp.print('    <td width=108>');
    htp.print('      <a href="http://www.kgs.ku.edu/"');
    htp.print('         target="body">');
    htp.print('         <img src="http://www.kgs.ku.edu/PRS/Ozark/Summary/images/kgsSmB.png"');
    htp.print('              border="0"');
    htp.print('              align="left"></a>');
    htp.print('    </td>');
    htp.print('    <td><center><h1>South-central Kansas CO<sub>2</sub> Project<br>'||sTitle||'<br>Seismic Array Data</h1></center></td>');
    htp.print('  </tr>');
    htp.print('</table>');
--
    htp.line;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
  END build_title_icons;
--
--
-- PROCEDURE    build_finish
-- Description: This procedure will close out the Web Page
--
  PROCEDURE build_finish(sEvent IN VARCHAR2,
                         sTitle IN VARCHAR2) IS
--
  BEGIN
--
    htp.line;
--
-- End Section for the Web Page
--
    htp.print('This web page generated by ORACLE PLSQL Stored '||
              'Procedure http://chasm.kgs.ku.edu/ords/iqstrat.co2_events_summary_pkg.build_web_page?sEvent='||sEvent||
              '&sTitle='||sTitle);
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
  END build_finish;
--
--
-- PROCEDURE    build_main_finish
-- Description: This procedure will close out the Web Page
--
  PROCEDURE build_main_finish IS
--
  BEGIN
--
    htp.line;
--
-- End Section for the Web Page
--
    htp.print('This web page generated by ORACLE PLSQL Stored '||
              'Procedure http://chasm.kgs.ku.edu/ords/iqstrat.co2_events_summary_pkg.build_page');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
  END build_main_finish;
--
--
END co2_events_summary_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON co2_events_summary_pkg TO apex_public_user;