-- * PLSQL:       co2_fluid_levels_csv_pkg.sql Version 1.1 04/06/2016
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the Headers information.
-- * Copyright (c) 2016 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_fluid_levels_csv_pkg AS
  PROCEDURE build_web_page;
  PROCEDURE build_web_page(sKID IN VARCHAR2);
  PROCEDURE build_data_table(sKID IN VARCHAR2, sName IN VARCHAR2, sAPI IN VARCHAR2);
  PROCEDURE build_co2_web_page;
  PROCEDURE build_co2_web_page(sKID IN VARCHAR2);
  PROCEDURE build_co2_data_table(sKID IN VARCHAR2, sName IN VARCHAR2, sAPI IN VARCHAR2);
  PROCEDURE build_inj_web_page;
  PROCEDURE build_inj_web_page(sKID IN VARCHAR2);
  PROCEDURE build_inj_data_table(sKID IN VARCHAR2, sName IN VARCHAR2, sAPI IN VARCHAR2);
  PROCEDURE build_inj_data_table( sKID   IN VARCHAR2, 
                                  sName  IN VARCHAR2, 
                                  sAPI   IN VARCHAR2,
                                  trs    IN VARCHAR2,
				  dlat   IN NUMBER,
				  dlong  IN NUMBER,
				  kb     IN NUMBER,
				  gl     IN NUMBER,
				  df     IN NUMBER,
				  td     IN NUMBER,
				  form   IN VARCHAR2,
				  status IN VARCHAR2);
END co2_fluid_levels_csv_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_fluid_levels_csv_pkg AS
--
--
-- PROCEDURE    build_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Output:    Summary Web Page for Monitoring wells
--
  PROCEDURE build_web_page IS
--  
    l_cnt    NUMBER;
--
    o_kid    iqstrat.co2_brine_well.kid%TYPE;                -- Sample KID
    o_well   iqstrat.co2_brine_well.well_name%TYPE;          -- Well Number
    o_name   VARCHAR2(100);                                  -- Well Name
    o_api    iqstrat.co2_brine_well.api_number%TYPE;         -- API-Number
    o_trs    VARCHAR2(20);                                   -- Location - TRS
    o_lat    iqstrat.co2_brine_well.nad27_latitude%TYPE;     -- Location - Latitude
    o_long   iqstrat.co2_brine_well.nad27_longitude%TYPE;    -- Location - Longitude
    o_kb     iqstrat.co2_brine_well.elevation_kb%TYPE;       -- Elevation - KB
    o_gl     iqstrat.co2_brine_well.elevation_gl%TYPE;       -- Elevation - GL
    o_df     iqstrat.co2_brine_well.elevation_df%TYPE;       -- Elevation - DF
    o_td     iqstrat.co2_brine_well.rotary_total_depth%TYPE; -- Total Depth
    o_status iqstrat.co2_brine_well.status%TYPE;             -- Well Status
--
    CURSOR crsr IS
      SELECT kid,
             NVL(lease_name||' '||well_name, '&nbsp') AS NAME,
             well_name,
             NVL(api_number, '&nbsp') AS API,
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp'),  
             nad27_latitude,
             nad27_longitude,
             elevation_kb,
             elevation_gl,
             elevation_df,
             rotary_total_depth,
             status     
        FROM co2_brine_well CBW
       WHERE kid IN (SELECT UNIQUE(well_kid)
                       FROM CO2_Producer_Test_Data)
          OR kid = 1044998939
     ORDER BY NAME;
--
    CURSOR crsr_append IS
      SELECT kid,
             NVL(name, '&nbsp') AS NAME,
             name,
             NVL(api_number, '&nbsp') AS API,
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp'),  
             nad27_latitude,
             nad27_longitude,
             elevation_kb,
             elevation_gl,
             elevation_df,
             rotary_total_depth,
             status     
        FROM co2_brine_wells
       WHERE kid = 1045642922; --1024492641;
--
  BEGIN
--  
    htp.print('<HTML><HEAD><TITLE>DOE_CO2_Wells-Fluid_Levels</TITLE></HEAD><BODY>');
--    
    htp.print('Well Name,API-Number,Date,Total Fluid,Oil Cut,BOPD,Fluid Level,Joints in Well,BHP,</br>');
    htp.print(' , , ,bbl,%,bbl,ft, ,psig,</br>');
--
    OPEN crsr;
    LOOP
      FETCH crsr
       INTO o_kid,    -- Well Header Primary Key
            o_name,   -- Well Name
            o_well,   -- Well Number
            o_api,    -- API-Number
            o_trs,    -- Location - TRS
            o_lat,    -- Location - Latitude
            o_long,   -- Location - Longitude
            o_kb,     -- Elevation - KB
            o_gl,     -- Elevation - GL
            o_df,     -- Elevation - DF
            o_td,     -- Total Depth
            o_status; -- Well Status
      EXIT WHEN crsr%NOTFOUND;
--
        build_data_table(o_kid, o_name, o_api);
--
    END LOOP;
    CLOSE crsr;
--
    OPEN crsr_append;
    LOOP
      FETCH crsr_append
       INTO o_kid,    -- Well Header Primary Key
            o_name,   -- Well Name
            o_well,   -- Well Number
            o_api,    -- API-Number
            o_trs,    -- Location - TRS
            o_lat,    -- Location - Latitude
            o_long,   -- Location - Longitude
            o_kb,     -- Elevation - KB
            o_gl,     -- Elevation - GL
            o_df,     -- Elevation - DF
            o_td,     -- Total Depth
            o_status; -- Well Status
      EXIT WHEN crsr_append%NOTFOUND;
--
        build_data_table(o_kid, o_name, o_api);
--
    END LOOP;
    CLOSE crsr_append;
-- 
    htp.print('</BODY></HTML>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('ERROR: '||SQLERRM);
    htp.print('</BODY></HTML>');
--
  END build_web_page;
--
--
-- PROCEDURE    build_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Output:    Summary Web Page for Monitoring wells
--
  PROCEDURE build_web_page(sKID IN VARCHAR2) IS
--  
    l_cnt    NUMBER;
--
    o_kid    iqstrat.co2_brine_well.kid%TYPE;                -- Sample KID
    o_well   iqstrat.co2_brine_well.well_name%TYPE;          -- Well Number
    o_name   VARCHAR2(100);                                  -- Well Name
    o_api    iqstrat.co2_brine_well.api_number%TYPE;         -- API-Number
    o_trs    VARCHAR2(20);                                   -- Location - TRS
    o_lat    iqstrat.co2_brine_well.nad27_latitude%TYPE;     -- Location - Latitude
    o_long   iqstrat.co2_brine_well.nad27_longitude%TYPE;    -- Location - Longitude
    o_kb     iqstrat.co2_brine_well.elevation_kb%TYPE;       -- Elevation - KB
    o_gl     iqstrat.co2_brine_well.elevation_gl%TYPE;       -- Elevation - GL
    o_df     iqstrat.co2_brine_well.elevation_df%TYPE;       -- Elevation - DF
    o_td     iqstrat.co2_brine_well.rotary_total_depth%TYPE; -- Total Depth
    o_status iqstrat.co2_brine_well.status%TYPE;             -- Well Status
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT kid,
             NVL(lease_name||' '||well_name, '&nbsp') AS NAME,
             well_name,
             NVL(api_number, '&nbsp') AS API,
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp'),  
             nad27_latitude,
             nad27_longitude,
             elevation_kb,
             elevation_gl,
             elevation_df,
             rotary_total_depth,
             status     
        FROM co2_brine_well CBW
       WHERE kid = sKID;
--
    CURSOR crsr_append IS
      SELECT kid,
             NVL(name, '&nbsp') AS NAME,
             name,
             NVL(api_number, '&nbsp') AS API,
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp'),  
             nad27_latitude,
             nad27_longitude,
             elevation_kb,
             elevation_gl,
             elevation_df,
             rotary_total_depth,
             status     
        FROM co2_brine_wells
       WHERE kid = 1045642922; --1024492641;
--
  BEGIN
--  
    htp.print('<HTML><HEAD><TITLE>DOE_CO2_Wells-Fluid_Levels</TITLE></HEAD><BODY>');
--    
    htp.print('Well Name,API-Number,Date,Total Fluid,Oil Cut,BOPD,Fluid Level,Joints in Well,BHP,</br>');
    htp.print(' , , ,bbl,%,bbl,ft, ,psig,</br>');
--
    SELECT COUNT(kid)
      INTO l_cnt
      FROM co2_brine_well
     WHERE kid = sKID;
--
    IF (l_cnt > 0) THEN
      OPEN crsr(sKID);
      LOOP
        FETCH crsr
         INTO o_kid,    -- Well Header Primary Key
              o_name,   -- Well Name
              o_well,   -- Well Number
              o_api,    -- API-Number
              o_trs,    -- Location - TRS
              o_lat,    -- Location - Latitude
              o_long,   -- Location - Longitude
              o_kb,     -- Elevation - KB
              o_gl,     -- Elevation - GL
              o_df,     -- Elevation - DF
              o_td,     -- Total Depth
              o_status; -- Well Status
        EXIT WHEN crsr%NOTFOUND;
--
          build_data_table(o_kid, o_name, o_api);
--
      END LOOP;
      CLOSE crsr;
    END IF;
--
    SELECT COUNT(kid)
      INTO l_cnt
      FROM co2_brine_wells
     WHERE kid = sKID;
--
    IF (l_cnt > 0) THEN
      OPEN crsr_append;
      LOOP
        FETCH crsr_append
         INTO o_kid,    -- Well Header Primary Key
              o_name,   -- Well Name
              o_well,   -- Well Number
              o_api,    -- API-Number
              o_trs,    -- Location - TRS
              o_lat,    -- Location - Latitude
              o_long,   -- Location - Longitude
              o_kb,     -- Elevation - KB
              o_gl,     -- Elevation - GL
              o_df,     -- Elevation - DF
              o_td,     -- Total Depth
              o_status; -- Well Status
        EXIT WHEN crsr_append%NOTFOUND;
--
          build_data_table(o_kid, o_name, o_api);
--
      END LOOP;
      CLOSE crsr_append;
    END IF;
-- 
    htp.print('</BODY></HTML>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('ERROR: '||SQLERRM);
    htp.print('</BODY></HTML>');
--
  END build_web_page;
--
--
-- PROCEDURE    build_data_table()
-- Description: This procedure will add the table row for sample
-- * Input:     sKID = Sample KID
-- * Output:    The sample data row
--
  PROCEDURE build_data_table(sKID IN VARCHAR2, sName IN VARCHAR2, sAPI IN VARCHAR2) IS
--
    o_test   VARCHAR2(20);
    o_order  VARCHAR2(20);
    o_total  iqstrat.co2_producer_test_data.total_fluid_bbl%TYPE;
    o_cut    iqstrat.co2_producer_test_data.oil_cut_perc%TYPE;
    o_level  iqstrat.co2_producer_test_data.fluid_levels_ft%TYPE;
    o_joints iqstrat.co2_producer_test_data.joints_in_well%TYPE;
    o_BOPD   iqstrat.co2_producer_test_data.barrels_of_oil_per_day%TYPE;
    o_BHP    iqstrat.co2_producer_test_data.est_bottom_hole_pressure_psig%TYPE;
--
    o_id     iqstrat.co2_producer_test_data.group_id%TYPE;
    o_no     iqstrat.co2_producer_test_data.group_no%TYPE;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT TO_CHAR(test_date, 'DD Month YYYY'),
             TO_CHAR(test_date, 'YYYYMMDD') AS TEST,
             group_id,
             group_no,
             total_fluid_bbl,
             oil_cut_perc,
             fluid_levels_ft,
             joints_in_well,
             barrels_of_oil_per_day,
             est_bottom_hole_pressure_psig
        FROM co2_producer_test_data
       WHERE well_kid = sKID
      ORDER BY TEST;                  
--
  BEGIN
--
    htp.print('</br>');
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_test,   -- Test Date
            o_order,  -- ORDER BY variable
            o_id,     -- Group ID
            o_no,     -- Group Number
            o_total,  -- Total Fluid (BBLS)
            o_cut,    -- Oil Cut (%)
            o_level,  -- Fluid Levels (ft)
            o_joints, -- Joints in Well
            o_BOPD,   -- Barrels of Oil Per Day
            o_BHP;    -- Bottom Hole Pressure
      EXIT WHEN crsr%NOTFOUND;
--  
      htp.print(INITCAP(sName)||','||sAPI||','||o_test||','||o_total||','||o_cut||','||o_BOPD||
                ','||o_level||','||o_joints||','||o_BHP||',</br>');
--    
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('ERROR: '||SQLERRM);
    htp.print('</BODY></HTML>');
--
  END build_data_table;
--
--
-- PROCEDURE    build_co2_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Output:    Summary Web Page for Monitoring wells
--
  PROCEDURE build_co2_web_page IS
--  
    l_cnt    NUMBER;
--
    o_kid    iqstrat.co2_brine_well.kid%TYPE;                -- Sample KID
    o_well   iqstrat.co2_brine_well.well_name%TYPE;          -- Well Number
    o_name   VARCHAR2(100);                                  -- Well Name
    o_api    iqstrat.co2_brine_well.api_number%TYPE;         -- API-Number
    o_trs    VARCHAR2(20);                                   -- Location - TRS
    o_lat    iqstrat.co2_brine_well.nad27_latitude%TYPE;     -- Location - Latitude
    o_long   iqstrat.co2_brine_well.nad27_longitude%TYPE;    -- Location - Longitude
    o_kb     iqstrat.co2_brine_well.elevation_kb%TYPE;       -- Elevation - KB
    o_gl     iqstrat.co2_brine_well.elevation_gl%TYPE;       -- Elevation - GL
    o_df     iqstrat.co2_brine_well.elevation_df%TYPE;       -- Elevation - DF
    o_td     iqstrat.co2_brine_well.rotary_total_depth%TYPE; -- Total Depth
    o_status iqstrat.co2_brine_well.status%TYPE;             -- Well Status
--
    CURSOR crsr IS
      SELECT kid,
             NVL(lease_name||' '||well_name, '&nbsp') AS NAME,
             well_name,
             NVL(api_number, '&nbsp') AS API,
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp'),  
             nad27_latitude,
             nad27_longitude,
             elevation_kb,
             elevation_gl,
             elevation_df,
             rotary_total_depth,
             status     
        FROM co2_brine_well CBW
       WHERE kid IN (SELECT UNIQUE(well_kid)
                       FROM co2_and_offset_gas)
     ORDER BY NAME;
--
    CURSOR crsr_append IS
      SELECT kid,
             NVL(name, '&nbsp') AS NAME,
             name,
             NVL(api_number, '&nbsp') AS API,
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp'),  
             nad27_latitude,
             nad27_longitude,
             elevation_kb,
             elevation_gl,
             elevation_df,
             rotary_total_depth,
             status     
        FROM co2_brine_wells
       WHERE kid = 1045642922; --1024492641;
--
  BEGIN
--  
    htp.print('<HTML><HEAD><TITLE>DOE_CO2_Wells-CO2_OFFSET_GAS</TITLE></HEAD><BODY>');
--    
    htp.print('Well Name,API-Number,Date,CO2,MCFD,</br>');
    htp.print(' , , ,%,mcf,</br>');
--
    OPEN crsr;
    LOOP
      FETCH crsr
       INTO o_kid,    -- Well Header Primary Key
            o_name,   -- Well Name
            o_well,   -- Well Number
            o_api,    -- API-Number
            o_trs,    -- Location - TRS
            o_lat,    -- Location - Latitude
            o_long,   -- Location - Longitude
            o_kb,     -- Elevation - KB
            o_gl,     -- Elevation - GL
            o_df,     -- Elevation - DF
            o_td,     -- Total Depth
            o_status; -- Well Status
      EXIT WHEN crsr%NOTFOUND;
--
        build_co2_data_table(o_kid, o_name, o_api);
--
    END LOOP;
    CLOSE crsr;
--
    OPEN crsr_append;
    LOOP
      FETCH crsr_append
       INTO o_kid,    -- Well Header Primary Key
            o_name,   -- Well Name
            o_well,   -- Well Number
            o_api,    -- API-Number
            o_trs,    -- Location - TRS
            o_lat,    -- Location - Latitude
            o_long,   -- Location - Longitude
            o_kb,     -- Elevation - KB
            o_gl,     -- Elevation - GL
            o_df,     -- Elevation - DF
            o_td,     -- Total Depth
            o_status; -- Well Status
      EXIT WHEN crsr_append%NOTFOUND;
--
        build_co2_data_table(o_kid, o_name, o_api);
--
    END LOOP;
    CLOSE crsr_append;
-- 
    htp.print('</BODY></HTML>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('ERROR: '||SQLERRM);
    htp.print('</BODY></HTML>');
--
  END build_co2_web_page;
--
--
-- PROCEDURE    build_co2_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Output:    Summary Web Page for Monitoring wells
--
  PROCEDURE build_co2_web_page(sKID IN VARCHAR2) IS
--  
    l_cnt    NUMBER;
--
    o_kid    iqstrat.co2_brine_well.kid%TYPE;                -- Sample KID
    o_well   iqstrat.co2_brine_well.well_name%TYPE;          -- Well Number
    o_name   VARCHAR2(100);                                  -- Well Name
    o_api    iqstrat.co2_brine_well.api_number%TYPE;         -- API-Number
    o_trs    VARCHAR2(20);                                   -- Location - TRS
    o_lat    iqstrat.co2_brine_well.nad27_latitude%TYPE;     -- Location - Latitude
    o_long   iqstrat.co2_brine_well.nad27_longitude%TYPE;    -- Location - Longitude
    o_kb     iqstrat.co2_brine_well.elevation_kb%TYPE;       -- Elevation - KB
    o_gl     iqstrat.co2_brine_well.elevation_gl%TYPE;       -- Elevation - GL
    o_df     iqstrat.co2_brine_well.elevation_df%TYPE;       -- Elevation - DF
    o_td     iqstrat.co2_brine_well.rotary_total_depth%TYPE; -- Total Depth
    o_status iqstrat.co2_brine_well.status%TYPE;             -- Well Status
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT kid,
             NVL(lease_name||' '||well_name, '&nbsp') AS NAME,
             well_name,
             NVL(api_number, '&nbsp') AS API,
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp'),  
             nad27_latitude,
             nad27_longitude,
             elevation_kb,
             elevation_gl,
             elevation_df,
             rotary_total_depth,
             status     
        FROM co2_brine_well CBW
       WHERE kid = sKID;
--
    CURSOR crsr_append IS
      SELECT kid,
             NVL(name, '&nbsp') AS NAME,
             name,
             NVL(api_number, '&nbsp') AS API,
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp'),  
             nad27_latitude,
             nad27_longitude,
             elevation_kb,
             elevation_gl,
             elevation_df,
             rotary_total_depth,
             status     
        FROM co2_brine_wells
       WHERE kid = 1045642922; --1024492641;
--
  BEGIN
--  
    htp.print('<HTML><HEAD><TITLE>DOE_CO2_Wells-CO2_OFFSET_GAS</TITLE></HEAD><BODY>');
--    
    htp.print('Well Name,API-Number,Date,CO2,MCFD,</br>');
    htp.print(' , , ,%,mcf,</br>');
--
    SELECT COUNT(kid)
      INTO l_cnt
      FROM co2_brine_well
     WHERE kid = sKID;
--
    IF (l_cnt > 0) THEN
      OPEN crsr(sKID);
      LOOP
        FETCH crsr
         INTO o_kid,    -- Well Header Primary Key
              o_name,   -- Well Name
              o_well,   -- Well Number
              o_api,    -- API-Number
              o_trs,    -- Location - TRS
              o_lat,    -- Location - Latitude
              o_long,   -- Location - Longitude
              o_kb,     -- Elevation - KB
              o_gl,     -- Elevation - GL
              o_df,     -- Elevation - DF
              o_td,     -- Total Depth
              o_status; -- Well Status
        EXIT WHEN crsr%NOTFOUND;
--
          build_co2_data_table(o_kid, o_name, o_api);
--
      END LOOP;
      CLOSE crsr;
    END IF;
--
    SELECT COUNT(kid)
      INTO l_cnt
      FROM co2_brine_wells
     WHERE kid = sKID;
--
    IF (l_cnt > 0) THEN
      OPEN crsr_append;
      LOOP
        FETCH crsr_append
         INTO o_kid,    -- Well Header Primary Key
              o_name,   -- Well Name
              o_well,   -- Well Number
              o_api,    -- API-Number
              o_trs,    -- Location - TRS
              o_lat,    -- Location - Latitude
              o_long,   -- Location - Longitude
              o_kb,     -- Elevation - KB
              o_gl,     -- Elevation - GL
              o_df,     -- Elevation - DF
              o_td,     -- Total Depth
              o_status; -- Well Status
        EXIT WHEN crsr_append%NOTFOUND;
--
          build_co2_data_table(o_kid, o_name, o_api);
--
      END LOOP;
      CLOSE crsr_append;
    END IF;
-- 
    htp.print('</BODY></HTML>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('ERROR: '||SQLERRM);
    htp.print('</BODY></HTML>');
--
  END build_co2_web_page;
--
--
-- PROCEDURE    build_co2_data_table()
-- Description: This procedure will add the table row for sample
-- * Input:     sKID = Sample KID
-- * Output:    The sample data row
--
  PROCEDURE build_co2_data_table(sKID IN VARCHAR2, sName IN VARCHAR2, sAPI IN VARCHAR2) IS
--
    o_cnt    NUMBER;
--
    o_test   VARCHAR2(20);
    o_order  VARCHAR2(20);
    o_CO2    iqstrat.co2_and_offset_gas.co2_percent%TYPE;
    o_MCFD   iqstrat.co2_and_offset_gas.gas_mcf_per_day%TYPE;
--
    o_id     iqstrat.co2_and_offset_gas.group_id%TYPE;
    o_no     iqstrat.co2_and_offset_gas.group_no%TYPE;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT TO_CHAR(measured_date, 'DD Month YYYY'),
             TO_CHAR(measured_date, 'YYYYMMDD') AS TEST,
             group_id,
             group_no,
             co2_percent,
             gas_mcf_per_day
        FROM co2_and_offset_gas
       WHERE well_kid = sKID
      ORDER BY TEST;                  
--
  BEGIN
--
    htp.print('</br>');
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_test,   -- Test Date
            o_order,  -- ORDER BY Variable
            o_id,     -- Group ID
            o_no,     -- Group Number
            o_CO2,    -- % CO2
            o_MCFD;   -- Offset Gas MCF/D
      EXIT WHEN crsr%NOTFOUND;
--   
      htp.print(INITCAP(sName)||','||sAPI||','||o_test||','||o_CO2||','||o_MCFD||',</br>');
--    
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('ERROR: '||SQLERRM);
    htp.print('</BODY></HTML>');
--
  END build_co2_data_table;
--
--
-- PROCEDURE    build_inj_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Output:    Summary Web Page for Monitoring wells
--
  PROCEDURE build_inj_web_page IS
--  
    l_cnt    NUMBER;
--
    o_kid    iqstrat.co2_brine_well.kid%TYPE;                -- Sample KID
    o_well   iqstrat.co2_brine_well.well_name%TYPE;          -- Well Number
    o_name   VARCHAR2(100);                                  -- Well Name
    o_api    iqstrat.co2_brine_well.api_number%TYPE;         -- API-Number
    o_trs    VARCHAR2(20);                                   -- Location - TRS
    o_lat    iqstrat.co2_brine_well.nad27_latitude%TYPE;     -- Location - Latitude
    o_long   iqstrat.co2_brine_well.nad27_longitude%TYPE;    -- Location - Longitude
    o_kb     iqstrat.co2_brine_well.elevation_kb%TYPE;       -- Elevation - KB
    o_gl     iqstrat.co2_brine_well.elevation_gl%TYPE;       -- Elevation - GL
    o_df     iqstrat.co2_brine_well.elevation_df%TYPE;       -- Elevation - DF
    o_td     iqstrat.co2_brine_well.rotary_total_depth%TYPE; -- Total Depth
    o_form   qualified.well_headers.rotary_total_depth_formation%TYPE;
    o_status iqstrat.co2_brine_well.status%TYPE;             -- Well Status
--
    CURSOR crsrI IS
      SELECT kid,
             NVL(lease_name||' '||well_name, '&nbsp') AS NAME,
             well_name,
             NVL(api_number, '&nbsp') AS API,
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp'),  
             nad27_latitude,
             nad27_longitude,
             elevation_kb,
             elevation_gl,
             elevation_df,
             rotary_total_depth,
             rotary_total_depth_formation,
             status     
        FROM qualified.well_headers 
       WHERE kid IN (SELECT UNIQUE(well_kid)
                       FROM CO2_Injection_Data)
     ORDER BY NAME;
--
  BEGIN
--  
    htp.print('<HTML><HEAD><TITLE>DOE_CO2_Wells-Injection_Data</TITLE></HEAD><BODY>');
--    
    htp.print('Well Name,API-Number,T-R-S,Latitude,Longitude,'||
              'KB,GL,DF,TD,Formation,Status,'||
              'Date,BWPD,BCO2PD,CO2 Tons/day,Tubing Pressure,Comments,'||
              'depth,zone,# of Days,max injection pressure</br>');
    htp.print(' , , ,deg,deg,ft,ft,ft,ft, , , ,bbl,bbl,tons,psig, ,</br>');
--
    OPEN crsrI;
    LOOP
      FETCH crsrI
       INTO o_kid,    -- Well Header Primary Key
            o_name,   -- Well Name
            o_well,   -- Well Number
            o_api,    -- API-Number
            o_trs,    -- Location - TRS
            o_lat,    -- Location - Latitude
            o_long,   -- Location - Longitude
            o_kb,     -- Elevation - KB
            o_gl,     -- Elevation - GL
            o_df,     -- Elevation - DF
            o_td,     -- Total Depth
            o_form,   -- Formation at TD
            o_status; -- Well Status
      EXIT WHEN crsrI%NOTFOUND;
--
--        build_inj_data_table(o_kid, o_name, o_api);
        build_inj_data_table(o_kid, o_name, o_api, o_trs, o_lat, o_long, o_kb, o_gl, o_df, 
                             o_td, o_form, o_status);
--
    END LOOP;
    CLOSE crsrI;
-- 
    htp.print('</BODY></HTML>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('ERROR: '||SQLERRM);
    htp.print('</BODY></HTML>');
--
  END build_inj_web_page;
--
--
-- PROCEDURE    build_inj_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Output:    Summary Web Page for Monitoring wells
--
  PROCEDURE build_inj_web_page(sKID IN VARCHAR2) IS
--  
    l_cnt    NUMBER;
--
    o_kid    iqstrat.co2_brine_well.kid%TYPE;                -- Sample KID
    o_well   iqstrat.co2_brine_well.well_name%TYPE;          -- Well Number
    o_name   VARCHAR2(100);                                  -- Well Name
    o_api    iqstrat.co2_brine_well.api_number%TYPE;         -- API-Number
    o_trs    VARCHAR2(20);                                   -- Location - TRS
    o_lat    iqstrat.co2_brine_well.nad27_latitude%TYPE;     -- Location - Latitude
    o_long   iqstrat.co2_brine_well.nad27_longitude%TYPE;    -- Location - Longitude
    o_kb     iqstrat.co2_brine_well.elevation_kb%TYPE;       -- Elevation - KB
    o_gl     iqstrat.co2_brine_well.elevation_gl%TYPE;       -- Elevation - GL
    o_df     iqstrat.co2_brine_well.elevation_df%TYPE;       -- Elevation - DF
    o_td     iqstrat.co2_brine_well.rotary_total_depth%TYPE; -- Total Depth
    o_form   qualified.well_headers.rotary_total_depth_formation%TYPE;
    o_status iqstrat.co2_brine_well.status%TYPE;             -- Well Status
--
    CURSOR crsrI(sKID IN VARCHAR2) IS
      SELECT kid,
             NVL(lease_name||' '||well_name, '&nbsp') AS NAME,
             well_name,
             NVL(api_number, '&nbsp') AS API,
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp'),  
             nad27_latitude,
             nad27_longitude,
             elevation_kb,
             elevation_gl,
             elevation_df,
             rotary_total_depth,
             rotary_total_depth_formation,
             status     
        FROM qualified.well_headers 
       WHERE kid = sKID;
--
  BEGIN
--  
    htp.print('<HTML><HEAD><TITLE>DOE_CO2_Wells-Injection_Data</TITLE></HEAD><BODY>');
--    
    htp.print('Well Name,API-Number,T-R-S,Latitude,Longitude,'||
              'KB,GL,DF,TD,Formation,Status,'||
              'Date,BOW,BCO2D,CO2 Tons/day,Tubing Pressure,Comments,'||
              'depth,zone,# of Days,max injection pressure</br>');
    htp.print(' , , ,deg,deg,ft,ft,ft,ft, , , ,bbl,bbl,tons,psig, ,ft, , ,psi</br>');
--
    OPEN crsrI(sKID);
    LOOP
      FETCH crsrI
       INTO o_kid,    -- Well Header Primary Key
            o_name,   -- Well Name
            o_well,   -- Well Number
            o_api,    -- API-Number
            o_trs,    -- Location - TRS
            o_lat,    -- Location - Latitude
            o_long,   -- Location - Longitude
            o_kb,     -- Elevation - KB
            o_gl,     -- Elevation - GL
            o_df,     -- Elevation - DF
            o_td,     -- Total Depth
            o_form,   -- Formation at TD
            o_status; -- Well Status
      EXIT WHEN crsrI%NOTFOUND;
--
--        build_inj_data_table(o_kid, o_name, o_api);
        build_inj_data_table(o_kid, o_name, o_api, o_trs, o_lat, o_long, o_kb, o_gl, o_df, 
                             o_td, o_form, o_status);
--
    END LOOP;
    CLOSE crsrI;
-- 
    htp.print('</BODY></HTML>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('ERROR: '||SQLERRM);
    htp.print('</BODY></HTML>');
--
  END build_inj_web_page;
--
--
-- PROCEDURE    build_inj_data_table()
-- Description: This procedure will add the table row for sample
-- * Input:     sKID = Sample KID
-- * Output:    The sample data row
--
  PROCEDURE build_inj_data_table(sKID IN VARCHAR2, sName IN VARCHAR2, sAPI IN VARCHAR2) IS
--
    o_cnt    NUMBER;
--
    o_DATE     VARCHAR2(20);
    o_inj      VARCHAR2(20);
    o_BWPD     iqstrat.co2_injection_data.barrels_of_water_per_day%TYPE;
    o_BCO2PD   iqstrat.co2_injection_data.barrels_of_CO2_per_day%TYPE;
    o_TCO2PD   iqstrat.co2_injection_data.tons_of_CO2_per_day%TYPE;
    o_TP       iqstrat.co2_injection_data.tubing_pressure_psig%TYPE;
    o_comments iqstrat.co2_injection_data.comments%TYPE;
    o_depth    iqstrat.co2_injection_data.depth%TYPE;
    o_zone     iqstrat.co2_injection_data.injection_zone%TYPE;
    o_days     iqstrat.co2_injection_data.days_of_injection%TYPE;
    o_max      iqstrat.co2_injection_data.max_inj_pressure_psi%TYPE;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT TO_CHAR(inj_date, 'YYYYMMDD') AS THE_DATE,
             TO_CHAR(inj_date, 'DD Month YYYY') AS TEST,
             barrels_of_water_per_day,
             barrels_of_CO2_per_day,
             tons_of_CO2_per_day,
             tubing_pressure_psig,
             comments,
             depth,
             injection_zone,
             days_of_injection,
             max_inj_pressure_psi
        FROM co2_injection_data
       WHERE well_kid = sKID
      ORDER BY THE_DATE;                  
--
  BEGIN
--
    htp.print('</br>');
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_DATE,
            o_inj,      -- Injection Date
            o_BWPD,     -- Barrels of Water Per Day
            o_BCO2PD,   -- Barrels of CO2 Per Day
            o_TCO2PD,   -- Tons of CO2 Per Day
            o_TP,       -- Tubing Pressure (psig)
            o_comments, -- Comments
            o_depth,    -- Depth of injection
            o_zone,     -- Injection Zone
            o_days,     -- days of injection
            o_max;      -- Maximum Injection_pressure
      EXIT WHEN crsr%NOTFOUND;
--   
      htp.print(INITCAP(sName)||','||sAPI||
      ','||o_inj||','||o_BWPD||','||o_BCO2PD||','||o_TCO2PD||','||o_TP||',"'||o_comments||
      '",'||o_depth||','||o_zone||','||o_days||','||o_max||',</br>');
--    
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('ERROR: '||SQLERRM);
    htp.print('</BODY></HTML>');
--
  END build_inj_data_table;
--
--
-- PROCEDURE    build_inj_data_table()
-- Description: This procedure will add the table row for sample
-- * Input:     sKID = Sample KID
-- * Output:    The sample data row
--
  PROCEDURE build_inj_data_table( sKID   IN VARCHAR2, 
                                  sName  IN VARCHAR2, 
                                  sAPI   IN VARCHAR2,
                                  trs    IN VARCHAR2,
				  dlat   IN NUMBER,
				  dlong  IN NUMBER,
				  kb     IN NUMBER,
				  gl     IN NUMBER,
				  df     IN NUMBER,
				  td     IN NUMBER,
				  form   IN VARCHAR2,
				  status IN VARCHAR2)IS
--
    o_cnt    NUMBER;
--
    o_DATE     VARCHAR2(20);
    o_inj      VARCHAR2(20);
    o_BWPD     iqstrat.co2_injection_data.barrels_of_water_per_day%TYPE;
    o_BCO2PD   iqstrat.co2_injection_data.barrels_of_CO2_per_day%TYPE;
    o_TCO2PD   iqstrat.co2_injection_data.tons_of_CO2_per_day%TYPE;
    o_TP       iqstrat.co2_injection_data.tubing_pressure_psig%TYPE;
    o_comments iqstrat.co2_injection_data.comments%TYPE;
    o_depth    iqstrat.co2_injection_data.depth%TYPE;
    o_zone     iqstrat.co2_injection_data.injection_zone%TYPE;
    o_days     iqstrat.co2_injection_data.days_of_injection%TYPE;
    o_max      iqstrat.co2_injection_data.max_inj_pressure_psi%TYPE;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT TO_CHAR(inj_date, 'YYYYMMDD') AS THE_DATE,
             TO_CHAR(inj_date, 'DD Month YYYY') AS TEST,
             barrels_of_water_per_day,
             barrels_of_CO2_per_day,
             tons_of_CO2_per_day,
             tubing_pressure_psig,
             comments,
             depth,
             injection_zone,
             days_of_injection,
             max_inj_pressure_psi
        FROM co2_injection_data
       WHERE well_kid = sKID
      ORDER BY THE_DATE;                  
--
  BEGIN
--
    htp.print('</br>');
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_DATE,
            o_inj,      -- Injection Date
            o_BWPD,     -- Barrels of Water Per Day
            o_BCO2PD,   -- Barrels of CO2 Per Day
            o_TCO2PD,   -- Tons of CO2 Per Day
            o_TP,       -- Tubing Pressure (psig)
            o_comments, -- Comments
            o_depth,    -- Depth of injection
            o_zone,     -- Injection Zone
            o_days,     -- days of injection
            o_max;      -- Maximum Injection_pressure
      EXIT WHEN crsr%NOTFOUND;
--   
      htp.print(INITCAP(sName)||','||sAPI||','||trs||','||dlat||','||dlong||
      ','||kb||','||gl||','||df||','||td||','||form||','||status||
      ','||o_inj||','||o_BWPD||','||o_BCO2PD||','||o_TCO2PD||','||o_TP||',"'||o_comments||
      '",'||o_depth||','||o_zone||','||o_days||','||o_max||',</br>');
--    
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('ERROR: '||SQLERRM);
    htp.print('</BODY></HTML>');
--
  END build_inj_data_table;
--
--
END co2_fluid_levels_csv_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON co2_fluid_levels_csv_pkg TO apex_public_user;