-- * PLSQL:       co2_fluid_levels_pkg.sql Version 1.1 05/01/2015
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the Headers information.
-- * Copyright (c) 2015 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_fluid_levels_pkg AS
  PROCEDURE build_web_page;
  PROCEDURE build_web_page (well IN VARCHAR2);
  PROCEDURE build_data_table(sKID IN VARCHAR2);
  PROCEDURE build_gas_table(sKID IN VARCHAR2);
  PROCEDURE build_static_table(sKID IN VARCHAR2);
  PROCEDURE build_web_page (key IN VARCHAR2);
  PROCEDURE build_inj_table(sKID IN VARCHAR2);
--
  PROCEDURE build_title_icons(sTitle IN VARCHAR2);
END co2_fluid_levels_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_fluid_levels_pkg AS
--
-- PROCEDURE    build_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Output:    Summary Web Page for Monitoring wells
--
  PROCEDURE build_web_page IS
--  
    l_cnt    NUMBER;
--
    o_kid    iqstrat.co2_brine_well.kid%TYPE;                -- Sample KID
    o_well   iqstrat.co2_brine_well.well_name%TYPE;          -- Well Number
    o_name   VARCHAR2(100);                                  -- Well Name
    o_api    iqstrat.co2_brine_well.api_number%TYPE;         -- API-Number
    o_trs    VARCHAR2(20);                                   -- Location - TRS
    o_lat    iqstrat.co2_brine_well.nad27_latitude%TYPE;     -- Location - Latitude
    o_long   iqstrat.co2_brine_well.nad27_longitude%TYPE;    -- Location - Longitude
    o_kb     iqstrat.co2_brine_well.elevation_kb%TYPE;       -- Elevation - KB
    o_gl     iqstrat.co2_brine_well.elevation_gl%TYPE;       -- Elevation - GL
    o_df     iqstrat.co2_brine_well.elevation_df%TYPE;       -- Elevation - DF
    o_td     iqstrat.co2_brine_well.rotary_total_depth%TYPE; -- Total Depth
    o_status iqstrat.co2_brine_well.status%TYPE;             -- Well Status
--
    CURSOR crsr IS
      SELECT kid,
             NVL(lease_name||' '||well_name, '&nbsp') AS NAME,
             well_name,
             NVL(api_number, '&nbsp') AS API,
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp'),  
             nad27_latitude,
             nad27_longitude,
             elevation_kb,
             elevation_gl,
             elevation_df,
             rotary_total_depth,
             status     
        FROM co2_brine_well CBW
       WHERE kid IN (SELECT UNIQUE(well_kid)
                       FROM CO2_Producer_Test_Data)
          OR kid = 1044998939
     ORDER BY NAME;
--
    CURSOR crsr_append IS
      SELECT kid,
             NVL(name, '&nbsp') AS NAME,
             name,
             NVL(api_number, '&nbsp') AS API,
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp'),  
             nad27_latitude,
             nad27_longitude,
             elevation_kb,
             elevation_gl,
             elevation_df,
             rotary_total_depth,
             status     
        FROM co2_brine_wells
       WHERE kid = 1045642922; --1024492641;
--
    CURSOR crsrI IS
      SELECT kid,
             NVL(lease_name||' '||well_name, '&nbsp') AS NAME,
             well_name,
             NVL(api_number, '&nbsp') AS API,
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp'),  
             nad27_latitude,
             nad27_longitude,
             elevation_kb,
             elevation_gl,
             elevation_df,
             rotary_total_depth,
             status     
        FROM qualified.well_headers 
       WHERE kid IN (SELECT UNIQUE(well_kid)
                       FROM CO2_Injection_Data)
     ORDER BY NAME;
--
  BEGIN
--  
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('CO2 Fluid Level Data Summary Page');
    htp.headClose;
--
    htp.print('<BODY>');
    build_title_icons( 'Fluid Level Data' );
--
    htp.print('<p>');
    htp.print('<b>Create a Comma Separated Values (CSV) Web Page for Fluid Level: </b>');
    htp.print('  <a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_fluid_levels_csv_pkg.build_web_page"'||
              ' target="body">Fluid_Level.csv</a>'); 
    htp.print('<br>');
    htp.print('<b>Create a Comma Separated Values (CSV) Web Page for CO2 Offset Gas: </b>');
    htp.print('  <a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_fluid_levels_csv_pkg.build_co2_web_page"'||
              ' target="body">CO2_Offset_Gas.csv</a>'); 
--
--  Create Data Table Header
--
    htp.print('<P>');
    htp.p('<table cellpadding="1" cellspacing="1" border="1" width="100%">');
    htp.print('<tr class=header>');
    htp.print('  <th colspan="11">Producers Test Data</th>');
    htp.print('</tr>');
--
    htp.print('<tr class=header>');
    htp.print('  <th>Well</th>');
    htp.print('  <th>&nbsp</th>');
    htp.print('  <th colspan="3">Location</th>');
    htp.print('  <th colspan="3">Elevation</th>');
    htp.print('  <th>Total</th>');
    htp.print('  <th>Well</th>');
    htp.print('  <th>Production</th>');
    htp.print('</tr>');
--
    htp.print('<tr class=header>');
    htp.print('  <th>Name</th>');
    htp.print('  <th>API-Number</th>');
    htp.print('  <th>TRS</th>');
    htp.print('  <th>Latitude</th>');
    htp.print('  <th>Longitude</th>');
    htp.print('  <th>GL</th>');
    htp.print('  <th>KB</th>');
    htp.print('  <th>DF</th>');
    htp.print('  <th>Depth</th>');
    htp.print('  <th>Status</th>');
    htp.print('  <th>Plot</th>');
    htp.print('</tr>');
--
    SELECT COUNT(UNIQUE(well_kid))
      INTO l_cnt
      FROM CO2_Producer_Test_Data;
--
--  Build Data Table
--
    IF (l_cnt > 0) THEN
--
      OPEN crsr;
      LOOP
        FETCH crsr
         INTO o_kid,    -- Well Header Primary Key
              o_name,   -- Well Name
              o_well,   -- Well Number
              o_api,    -- API-Number
              o_trs,    -- Location - TRS
              o_lat,    -- Location - Latitude
              o_long,   -- Location - Longitude
              o_kb,     -- Elevation - KB
              o_gl,     -- Elevation - GL
              o_df,     -- Elevation - DF
              o_td,     -- Total Depth
              o_status; -- Well Status
        EXIT WHEN crsr%NOTFOUND;
--
        SELECT COUNT(gas_mcf_per_day)
          INTO l_cnt
          FROM co2_and_offset_gas
         WHERE well_kid = o_kid
           AND gas_mcf_per_day > 0.0;
--
        IF (l_cnt < 2) THEN      
          SELECT COUNT(barrels_of_oil_per_day)
            INTO l_cnt
            FROM co2_producer_test_data
           WHERE well_kid = o_kid
             AND barrels_of_oil_per_day > 0;
        END IF;
--
        htp.print('<tr>');
        htp.print('  <td>'||
        '<a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_fluid_levels_pkg.build_web_page?well='||o_kid||'">'||INITCAP(o_name)||'</a>');
        htp.print('  <td>'||o_api||'</td>');
        htp.print('  <td>'||o_trs||'</td>');
        htp.print('  <td>'||o_lat||'</td>');
        htp.print('  <td>'||o_long||'</td>');
        htp.print('  <td>'||o_gl||'</td>');
        htp.print('  <td>'||o_kb||'</td>');
        htp.print('  <td>'||o_df||'</td>');
        htp.print('  <td>'||o_td||'</td>');
        htp.print('  <td>'||o_status||'</td>');
        IF (l_cnt > 1) THEN
        htp.print('  <td>'||
        '<a href="http://www.kgs.ku.edu/PRS/Ozark/Software/production/Production.html?sType=FLUID&sKID='||o_kid||'">'||
          ' <img src="http://www.kgs.ku.edu/PRS/Ozark/Software/production/images/production.png"'||
          ' border="0" align="left"></a>');
        ELSE
          htp.print('  <td>&nbsp</td>');
        END IF;
        htp.print('</td></tr>');
--
      END LOOP;
      CLOSE crsr;
--    
      OPEN crsr_append;
      LOOP
        FETCH crsr_append
         INTO o_kid,    -- Well Header Primary Key
              o_name,   -- Well Name
              o_well,   -- Well Number
              o_api,    -- API-Number
              o_trs,    -- Location - TRS
              o_lat,    -- Location - Latitude
              o_long,   -- Location - Longitude
              o_kb,     -- Elevation - KB
              o_gl,     -- Elevation - GL
              o_df,     -- Elevation - DF
              o_td,     -- Total Depth
              o_status; -- Well Status
        EXIT WHEN crsr_append%NOTFOUND;
--
      SELECT COUNT(gas_mcf_per_day)
        INTO l_cnt
        FROM co2_and_offset_gas
       WHERE well_kid = o_kid
         AND gas_mcf_per_day > 0.0;
--
        htp.print('<tr>');
        htp.print('  <td>'||
        '<a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_fluid_levels_pkg.build_web_page?well='||o_kid||'">'||INITCAP(o_name)||'</a>');
        htp.print('  <td>'||o_api||'</td>');
        htp.print('  <td>'||o_trs||'</td>');
        htp.print('  <td>'||o_lat||'</td>');
        htp.print('  <td>'||o_long||'</td>');
        htp.print('  <td>'||o_gl||'</td>');
        htp.print('  <td>'||o_kb||'</td>');
        htp.print('  <td>'||o_df||'</td>');
        htp.print('  <td>'||o_td||'</td>');
        htp.print('  <td>'||o_status||'</td>');
        IF (l_cnt > 1) THEN
          htp.print('  <td>'||
        '<a href="http://www.kgs.ku.edu/PRS/Ozark/Software/production/Production.html?sType=FLUID&sKID='||o_kid||'">'||
          ' <img src="http://www.kgs.ku.edu/PRS/Ozark/Software/production/images/production.png"'||
          ' border="0" align="left"></a>');
        ELSE
          htp.print('  <td>&nbsp</td>');
        END IF;
        htp.print('</td></tr>');
--
      END LOOP;
      CLOSE crsr_append;
--    
    END IF;
--    
    htp.tableClose;
--
    htp.print('<br>');
    htp.print('<b>Create a Comma Separated Values (CSV) Web Page for Injection Data: </b>');
    htp.print('  <a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_fluid_levels_csv_pkg.build_inj_web_page"'||
              ' target="body">Injection_Data.csv</a>'); 
--
--  Create Data Table Header
--
    htp.print('<P>');
    htp.p('<table cellpadding="1" cellspacing="1" border="1" width="100%">');
    htp.print('<tr class=header>');
    htp.print('  <th colspan="11">Injections Data</th>');
    htp.print('</tr>');
--
    htp.print('<tr class=header>');
    htp.print('  <th>Well</th>');
    htp.print('  <th>&nbsp</th>');
    htp.print('  <th colspan="3">Location</th>');
    htp.print('  <th colspan="3">Elevation</th>');
    htp.print('  <th>Total</th>');
    htp.print('  <th>Well</th>');
    htp.print('  <th>Production</th>');
    htp.print('</tr>');
--
    htp.print('<tr class=header>');
    htp.print('  <th>Name</th>');
    htp.print('  <th>API-Number</th>');
    htp.print('  <th>TRS</th>');
    htp.print('  <th>Latitude</th>');
    htp.print('  <th>Longitude</th>');
    htp.print('  <th>GL</th>');
    htp.print('  <th>KB</th>');
    htp.print('  <th>DF</th>');
    htp.print('  <th>Depth</th>');
    htp.print('  <th>Status</th>');
    htp.print('  <th>Plot</th>');
    htp.print('</tr>');
--
    OPEN crsrI;
    LOOP
      FETCH crsrI
       INTO o_kid,    -- Well Header Primary Key
            o_name,   -- Well Name
            o_well,   -- Well Number
            o_api,    -- API-Number
            o_trs,    -- Location - TRS
            o_lat,    -- Location - Latitude
            o_long,   -- Location - Longitude
            o_kb,     -- Elevation - KB
            o_gl,     -- Elevation - GL
            o_df,     -- Elevation - DF
            o_td,     -- Total Depth
            o_status; -- Well Status
      EXIT WHEN crsrI%NOTFOUND;
--
        SELECT COUNT(barrels_of_water_per_day)
          INTO l_cnt
          FROM co2_injection_data
         WHERE well_kid = o_kid
           AND barrels_of_water_per_day > 0;
--
        IF (l_cnt < 2) THEN      
          SELECT COUNT(barrels_of_CO2_per_day)
            INTO l_cnt
            FROM co2_injection_data
           WHERE well_kid = o_kid
             AND barrels_of_CO2_per_day > 0;
        END IF;
--
      htp.print('<tr>');
      htp.print('  <td>'||
      '<a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_fluid_levels_pkg.build_web_page?key='||o_kid||'">'||INITCAP(o_name)||'</a>');
      htp.print('  <td>'||o_api||'</td>');
      htp.print('  <td>'||o_trs||'</td>');
      htp.print('  <td>'||o_lat||'</td>');
      htp.print('  <td>'||o_long||'</td>');
      htp.print('  <td>'||o_gl||'</td>');
      htp.print('  <td>'||o_kb||'</td>');
      htp.print('  <td>'||o_df||'</td>');
      htp.print('  <td>'||o_td||'</td>');
      htp.print('  <td>'||o_status||'</td>');
        IF (l_cnt > 1) THEN
        htp.print('  <td>'||
        '<a href="http://www.kgs.ku.edu/PRS/Ozark/Software/production/Production.html?sType=INJECTION&sKID='||o_kid||'">'||
          ' <img src="http://www.kgs.ku.edu/PRS/Ozark/Software/production/images/production.png"'||
          ' border="0" align="left"></a>');
        ELSE
          htp.print('  <td>&nbsp</td>');
        END IF;
      htp.print('</td></tr>');
--
    END LOOP;
    CLOSE crsrI;
--
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_web_page;
--
--
-- PROCEDURE    build_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     well = the Well Header KID
-- * Output:    Summary Web Page for Monitoring wells
--
  PROCEDURE build_web_page (well IN VARCHAR2) IS
--
    l_cnt   NUMBER;
--    
    o_WELL  iqstrat.CO2_brine_wells.name%TYPE; -- well name
    o_API   iqstrat.CO2_brine_wells.api_number%TYPE; -- api-number
    o_TRS   VARCHAR2(60); 
    o_TITLE VARCHAR2(200);
--
    CURSOR crsrw(sKID IN VARCHAR2) IS
      SELECT NVL(lease_name||' '||well_name, '&nbsp'),
             NVL(api_number, '&nbsp'),
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp')
        FROM co2_brine_well
       WHERE kid = sKID;
--
  BEGIN
--  
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('CO2 Brine Data Summary Page');
    htp.headClose;
--
    OPEN crsrw(well);
    LOOP
      FETCH crsrw
       INTO o_WELL,   -- Well Name
            o_API,
            o_TRS;    -- TRS Location of Well
      EXIT WHEN crsrw%NOTFOUND;
    END LOOP;
    CLOSE crsrw;
--
    IF (LENGTH(o_API) > 6) THEN
      o_TITLE := o_WELL||' ('||o_API||')';
    ELSE
      o_TITLE := o_WELL;
    END IF;
--    
    htp.print('<BODY>');
    build_title_icons( 'Fluid Level Data <br> Producers Test Data Summary Page <br>'||o_TITLE||' ['||o_TRS||']');
--
    htp.print('<h3>Brine Summary Data for ');
    htp.print('<a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_brine_summary_pkg.build_web_page?key='||well||'">'||INITCAP(o_TITLE)||'</a></h3>');
--
    htp.print('<p>');
    htp.print('<b>Create a Comma Separated Values (CSV) Web Page for Fluid Level: </b>');
    htp.print('  <a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_fluid_levels_csv_pkg.build_web_page?sKID='||well||
              '" target="body">Fluid_Level.csv</a>'); 
    htp.print('<br>');
    htp.print('<b>Create a Comma Separated Values (CSV) Web Page for CO2 Offset Gas: </b>');
    htp.print('  <a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_fluid_levels_csv_pkg.build_co2_web_page?sKID='||well||
              '" target="body">CO2_Offset_Gas.csv</a>'); 
--
    htp.print('<p>');
    build_data_table(well);
--
    htp.print('<p>');
    build_gas_table(well);
--
    SELECT COUNT(well_kid)
      INTO l_cnt
      FROM co2_well_static_data
     WHERE well_kid = well;
--
    IF (l_cnt > 0) THEN    
      build_static_table(well);
    END IF;
--
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_web_page;
--
--  
-- PROCEDURE    build_data_table()
-- Description: This procedure will add the table row for sample
-- * Input:     sKID = Sample KID
-- * Output:    The sample data row
--
  PROCEDURE build_data_table(sKID IN VARCHAR2) IS
--
    o_test   VARCHAR2(20);
    o_order  VARCHAR2(20);
    o_total  iqstrat.co2_producer_test_data.total_fluid_bbl%TYPE;
    o_cut    iqstrat.co2_producer_test_data.oil_cut_perc%TYPE;
    o_level  iqstrat.co2_producer_test_data.fluid_levels_ft%TYPE;
    o_joints iqstrat.co2_producer_test_data.joints_in_well%TYPE;
    o_BOPD   iqstrat.co2_producer_test_data.barrels_of_oil_per_day%TYPE;
    o_BHP    iqstrat.co2_producer_test_data.est_bottom_hole_pressure_psig%TYPE;
--
    o_id     iqstrat.co2_producer_test_data.group_id%TYPE;
    o_no     iqstrat.co2_producer_test_data.group_no%TYPE;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT TO_CHAR(test_date, 'DD Month YYYY'),
             TO_CHAR(test_date, 'YYYYMMDD') AS TEST,
             group_id,
             group_no,
             total_fluid_bbl,
             oil_cut_perc,
             fluid_levels_ft,
             joints_in_well,
             barrels_of_oil_per_day,
             est_bottom_hole_pressure_psig
        FROM co2_producer_test_data
       WHERE well_kid = sKID
      ORDER BY TEST;                  
--
  BEGIN
--
    htp.p('<table cellpadding="1" cellspacing="1" border="1" width="100%">');
    htp.print('<tr class=header>');
    htp.print('  <th>Test Date</th>');
    htp.print('  <th>Group ID</th>');
    htp.print('  <th>Group No</th>');   
    htp.print('  <th>Total Fluid (bbl)</th>');
    htp.print('  <th>Oil Cut (%)</th>');
    htp.print('  <th>Barrels of Oil Per Day</th>');
    htp.print('  <th>Fluid Level (ft)</th>');
    htp.print('  <th>Joints in Well</th>');
    htp.print('  <th>Bottom Hole Pressure (psig)</th>');
    htp.print('</tr>');
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_test,   -- Test Date
            o_order,  -- ORDER BY variable
            o_id,     -- Group ID
            o_no,     -- Group Number
            o_total,  -- Total Fluid (BBLS)
            o_cut,    -- Oil Cut (%)
            o_level,  -- Fluid Levels (ft)
            o_joints, -- Joints in Well
            o_BOPD,   -- Barrels of Oil Per Day
            o_BHP;    -- Bottom Hole Pressure
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('<tr>');
      htp.print('  <td>'||o_test||'</td>');
      htp.print('  <td>'||o_id||'</td>');
      htp.print('  <td>'||o_no||'</td>');
      htp.print('  <td>'||o_total||'</td>');
      htp.print('  <td>'||o_cut||'</td>');
      htp.print('  <td>'||o_BOPD||'</td>');
      htp.print('  <td>'||o_level||'</td>');
      htp.print('  <td>'||o_joints||'</td>');
      htp.print('  <td>'||o_BHP||'</td>');
      htp.print('</tr>');
--
    END LOOP;
    CLOSE crsr;
--
    htp.tableClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_data_table;
--
--
-- PROCEDURE    build_gas_table()
-- Description: This procedure will add the table row for sample
-- * Input:     sKID = Sample KID
-- * Output:    The sample data row
--
  PROCEDURE build_gas_table(sKID IN VARCHAR2) IS
--
    o_cnt    NUMBER;
--
    o_test   VARCHAR2(20);
    o_order  VARCHAR2(20);
    o_CO2    iqstrat.co2_and_offset_gas.co2_percent%TYPE;
    o_MCFD   iqstrat.co2_and_offset_gas.gas_mcf_per_day%TYPE;
--
    o_id     iqstrat.co2_and_offset_gas.group_id%TYPE;
    o_no     iqstrat.co2_and_offset_gas.group_no%TYPE;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT TO_CHAR(measured_date, 'DD Month YYYY'),
             TO_CHAR(measured_date, 'YYYYMMDD') AS TEST,
             group_id,
             group_no,
             co2_percent,
             gas_mcf_per_day
        FROM co2_and_offset_gas
       WHERE well_kid = sKID
      ORDER BY TEST;                  
--
  BEGIN
--
    SELECT COUNT(*)
      INTO o_cnt
      FROM co2_and_offset_gas
     WHERE well_kid = sKID;
--
    IF (o_cnt > 0) THEN
--
    htp.p('<table cellpadding="1" cellspacing="1" border="1" width="40%">');
    htp.print('<tr class=header>');
    htp.print('  <th colspan="5">Offset Gas and CO2 Data</th>');
    htp.print('</tr>');
--    
    htp.print('<tr class=header>');
    htp.print('  <th>Measured Date</th>');
    htp.print('  <th>Group ID</th>');
    htp.print('  <th>Group No</th>');   
    htp.print('  <th>% CO2</th>');
    htp.print('  <th>MCF/D</th>');
    htp.print('</tr>');
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_test,   -- Test Date
            o_order,  -- ORDER BY Variable
            o_id,     -- Group ID
            o_no,     -- Group Number
            o_CO2,    -- % CO2
            o_MCFD;   -- Offset Gas MCF/D
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('<tr>');
      htp.print('  <td>'||o_test||'</td>');
      htp.print('  <td>'||o_id||'</td>');
      htp.print('  <td>'||o_no||'</td>');
      htp.print('  <td>'||o_CO2||'</td>');
      htp.print('  <td>'||o_MCFD||'</td>');
      htp.print('</tr>');
--
    END LOOP;
    CLOSE crsr;
--
    htp.tableClose;
--
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_gas_table;
--
--
-- PROCEDURE    build_static_table()
-- Description: This procedure will add the table row for sample
-- * Input:     sKID = Sample KID
-- * Output:    The sample data row
--
  PROCEDURE build_static_table(sKID IN VARCHAR2) IS
--
    o_joints iqstrat.co2_well_static_data.joints_in_well%TYPE;
    o_start  iqstrat.co2_well_static_data.open_hole_start_depth_ft%TYPE;
    o_end    iqstrat.co2_well_static_data.open_hole_end_depth_ft%TYPE;
    o_mid    iqstrat.co2_well_static_data.open_hole_mid_depth_ft%TYPE;
    o_sn     iqstrat.co2_well_static_data.SN_depth_ft%TYPE;
    o_length iqstrat.co2_well_static_data.Avg_Joint_Length_ft%TYPE;
    o_sg     iqstrat.co2_well_static_data.specific_gravity_water%TYPE;
--
    o_meas   VARCHAR2(20);
    o_order  VARCHAR2(20);
    o_jts    iqstrat.co2_static_by_dates.joints_to_fluid%TYPE;
    o_BHP    iqstrat.co2_static_by_dates.bottom_hole_pressure_psig%TYPE;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT joints_in_well,
             open_hole_start_depth_ft,
             open_hole_end_depth_ft,
             open_hole_mid_depth_ft,
             sn_depth_ft,
             avg_joint_length_ft,
             specific_gravity_water
        FROM co2_well_static_data
       WHERE well_kid = sKID;                  
--
    CURSOR crsr2(sKID IN VARCHAR2) IS
      SELECT TO_CHAR(measured_date, 'DD Month YYYY'),
             TO_CHAR(measured_date, 'YYYYMMDD') AS TEST,
             joints_to_fluid,
             bottom_hole_pressure_psig
        FROM co2_static_by_dates
       WHERE well_kid = sKID
      ORDER BY TEST;                  
--
  BEGIN
--
    htp.print('<p>');
    htp.p('<table cellpadding="1" cellspacing="1" border="1" width="100%">');
    htp.print('<tr class=header>');
    htp.print('  <th colspan="7">Static Data</th>');
    htp.print('</tr>');
--
    htp.print('<tr class=header>');
    htp.print('  <th>Joints</th>');
    htp.print('  <th colspan="3">Open Hole Depth</th>');
    htp.print('  <th>SN</th>');
    htp.print('  <th>Avg Joint</th>');
    htp.print('  <th>Specific Gravity</th>');
    htp.print('</tr>');
--
    htp.print('<tr class=header>');
    htp.print('  <th>in Well</th>');
    htp.print('  <th>Start (ft)</th>');
    htp.print('  <th>End (ft)</th>');
    htp.print('  <th>Mid (ft)</th>');
    htp.print('  <th>Depth (ft)</th>');
    htp.print('  <th>Length (ft)</th>');
    htp.print('  <th>Water</th>');
    htp.print('</tr>');
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_joints, -- Joints in well
            o_start,  -- Open Hole - Start Depth (ft)
            o_end,    -- Open Hole - End Depth (ft)
            o_mid,    -- Open Hole - Mid Depth (ft)
            o_sn,     -- (ft)
            o_length, -- Average Jount Length (ft)
            o_sg;     -- Specific Gravity of Water
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('<tr>');
      htp.print('  <td>'||o_joints||'</td>');
      htp.print('  <td>'||o_start||'</td>');
      htp.print('  <td>'||o_end||'</td>');
      htp.print('  <td>'||o_mid||'</td>');
      htp.print('  <td>'||o_sn||'</td>');
      htp.print('  <td>'||o_length||'</td>');
      htp.print('  <td>'||o_sg||'</td>');
      htp.print('</tr>');
--
    END LOOP;
    CLOSE crsr;
--
    htp.tableClose;
--
    htp.print('<p>');
    htp.p('<table cellpadding="1" cellspacing="1" border="1" width="100%">');
    htp.print('<tr class=header>');
    htp.print('  <th>Date</th>');
    htp.print('  <th>Joints to Fluid</th>');
    htp.print('  <th>Bottom Hole Pressure (psig)</th>');
    htp.print('</tr>');
--
    OPEN crsr2(sKID);
    LOOP
      FETCH crsr2
       INTO o_meas, -- Measured Date
            o_order, -- ORDER BY Variable
            o_jts,  -- Joints to Fluid
            o_BHP;  -- Bottom Hole Pressure (psig)
      EXIT WHEN crsr2%NOTFOUND;
--
      htp.print('<tr>');
      htp.print('  <td>'||o_meas||'</td>');
      htp.print('  <td>'||o_jts||'</td>');
      htp.print('  <td>'||o_BHP||'</td>');
      htp.print('</tr>');
--
    END LOOP;
    CLOSE crsr2;
--
    htp.tableClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_static_table;
--
--
-- PROCEDURE    build_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     key = the Well Header KID
-- * Output:    Summary Web Page for Monitoring wells
--
  PROCEDURE build_web_page (key IN VARCHAR2) IS
--
    l_cnt   NUMBER;
--    
    o_WELL  iqstrat.CO2_brine_wells.name%TYPE; -- well name
    o_API   iqstrat.CO2_brine_wells.api_number%TYPE; -- api-number
    o_TRS   VARCHAR2(60); 
    o_TITLE VARCHAR2(200);
--
    CURSOR crsrw(sKID IN VARCHAR2) IS
      SELECT NVL(lease_name||' '||well_name, '&nbsp'),
             NVL(api_number, '&nbsp'),
             NVL('T'||township||township_direction||' '||
                 'R'||range||range_direction||' '||
                 'S'||section, '&nbsp')
        FROM qualified.well_headers
       WHERE kid = sKID;
--
  BEGIN
--  
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('CO2 Brine Data Summary Page');
    htp.headClose;
--
    OPEN crsrw(key);
    LOOP
      FETCH crsrw
       INTO o_WELL,   -- Well Name
            o_API,
            o_TRS;    -- TRS Location of Well
      EXIT WHEN crsrw%NOTFOUND;
    END LOOP;
    CLOSE crsrw;
--
    IF (LENGTH(o_API) > 6) THEN
      o_TITLE := o_WELL||' ('||o_API||')';
    ELSE
      o_TITLE := o_WELL;
    END IF;
--    
    htp.print('<BODY>');
    build_title_icons( 'Fluid Level Data <br> Injection Data Summary Page <br>'||o_TITLE||' ['||o_TRS||']');
--
    htp.print('<p>');
    htp.print('<b>Create a Comma Separated Values (CSV) Web Page for Injection Data: </b>');
    htp.print('  <a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_fluid_levels_csv_pkg.build_inj_web_page?sKID='||key||
              '" target="body">Injection_Data.csv</a>'); 
--
    htp.print('<p>');
    htp.p('<table cellpadding="1" cellspacing="1" border="1" width="100%">');
--
    htp.print('<tr class=header>');
    htp.print('  <th>Injection Date</th>');
    htp.print('  <th>Barrels of Water</th>');
    htp.print('  <th>Barrels of CO2 per Day</th>');
    htp.print('  <th>Tons of CO2 per Day</th>');
    htp.print('  <th>Tubing Pressure (psig)</th>');
    htp.print('  <th>Comments</th>');
    htp.print('  <th>Depth (ft)</th>');
    htp.print('  <th>Injection Zone</th>');
    htp.print('  <th># of Injection Days</th>');
    htp.print('  <th>Max Injection Pressure (psig)</th>');
    htp.print('</tr>');
--
    build_inj_table(key);
--
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_web_page;
--
--  
-- PROCEDURE    build_inj_table()
-- Description: This procedure will add the table row for sample
-- * Input:     sKID = Sample KID
-- * Output:    The sample data row
--
  PROCEDURE build_inj_table(sKID IN VARCHAR2) IS
--
    o_inj      VARCHAR2(20);
    o_DATE     VARCHAR2(20);  
    o_BWPD     iqstrat.co2_injection_data.barrels_of_water_per_day%TYPE;
    o_BCO2PD   iqstrat.co2_injection_data.barrels_of_CO2_per_day%TYPE;
    o_TCO2PD   iqstrat.co2_injection_data.tons_of_CO2_per_day%TYPE;
    o_TP       iqstrat.co2_injection_data.tubing_pressure_psig%TYPE;
    o_comments iqstrat.co2_injection_data.comments%TYPE;
--
    o_depth    iqstrat.co2_injection_data.depth%TYPE;
    o_zone     iqstrat.co2_injection_data.injection_zone%TYPE;
    o_days     iqstrat.co2_injection_data.days_of_injection%TYPE;
    o_max      iqstrat.co2_injection_data.max_inj_pressure_psi%TYPE;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT TO_CHAR(inj_date, 'DD Month YYYY') AS TEST,
             TO_CHAR(inj_date, 'YYYYMMDD') AS TEST_DATE,
             barrels_of_water_per_day,
             NVL(barrels_of_CO2_per_day, -999),
             NVL(tons_of_CO2_per_day, -999),
             tubing_pressure_psig,
             NVL(comments, '&nbsp;'),
             NVL(depth, -999),
             NVL(injection_zone, '&nbsp;'),
             NVL(days_of_injection, -999),
             NVL(max_inj_pressure_psi, -999)
        FROM co2_injection_data
       WHERE well_kid = sKID
      ORDER BY TEST_DATE;                  
--
  BEGIN
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_inj,      -- Injection Date
            o_DATE,     -- ORDER BY DATE
            o_BWPD,     -- Barrels of Water Per Day
            o_BCO2PD,   -- Barrels of CO2 Per Day
            o_TCO2PD,   -- Tons of CO2 Per Day
            o_TP,       -- Tubing Pressure (psig)
            o_comments, -- Comments
            o_depth,    -- Depth of injection
            o_zone,     -- Injection Zone
            o_days,     -- days of injection
            o_max;      -- Maximum Injection_pressure
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('<tr>');
      htp.print('  <td>'||o_inj||'</td>');
      htp.print('  <td>'||o_BWPD||'</td>');
      IF (o_BCO2PD != -999) THEN
        htp.print('  <td>'||o_BCO2PD||'</td>');
      ELSE
        htp.print('  <td>&nbsp;</td>');
      END IF;
      IF (o_TCO2PD != -999) THEN
        htp.print('  <td>'||o_TCO2PD||'</td>');
      ELSE
        htp.print('  <td>&nbsp;</td>');
      END IF;
      htp.print('  <td>'||o_TP||'</td>');
      htp.print('  <td>'||o_comments||'</td>');
      IF (o_depth != -999) THEN
        htp.print('  <td>'||o_depth||'</td>');
      ELSE
        htp.print('  <td>&nbsp;</td>');
      END IF;
      htp.print('  <td>'||o_zone||'</td>');
      IF (o_days != -999) THEN
        htp.print('  <td>'||o_days||'</td>');
      ELSE
        htp.print('  <td>&nbsp;</td>');
      END IF;
      IF (o_max != -999) THEN
        htp.print('  <td>'||o_max||'</td>');
      ELSE
        htp.print('  <td>&nbsp;</td>');
      END IF;
      htp.print('</tr>');
--
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_inj_table;
--
--
-- PROCEDURE    build_title_icons
-- Description: This procedure will add the Title icons to the Web Page
--
  PROCEDURE build_title_icons(sTitle IN VARCHAR2) IS
--
  BEGIN
--
    htp.print('<table class=header cellpadding="2" cellspacing="2" border="0" width="100%">');
    htp.print('  <tr>');
    htp.print('    <td width=108>');
    htp.print('      <a href="http://www.kgs.ku.edu/"');
    htp.print('         target="body">');
    htp.print('         <img src="http://www.kgs.ku.edu/PRS/Ozark/Summary/images/kgsSmB.png"');
    htp.print('              border="0"');
    htp.print('              align="left"></a>');
    htp.print('    </td>');
    htp.print('    <td><center><h1>South-central Kansas CO<sub>2</sub> Project<br>'||sTitle||'</h1></center></td>');
    htp.print('  </tr>');
    htp.print('</table>');
--
    htp.line;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
  END build_title_icons;
--
--
END co2_fluid_levels_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON co2_fluid_levels_pkg TO apex_public_user;