-- * PLSQL:       co2_grid_brine_data_pkg.sql Version 1.1 06/24/2015
-- * Author:      John R. Victorine
-- * Description: This Package will build the Brine Data XML data stream
-- *              for gridding and mapping.
-- * Copyright (c) 2015 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_grid_brine_data_pkg AS
  PROCEDURE getDateListXML(iDate IN NUMBER);
  PROCEDURE getDateListXML(iDate IN NUMBER, field IN VARCHAR2);
  PROCEDURE getTopsListXML;
  PROCEDURE getTopsXML(sForm IN VARCHAR2);
  PROCEDURE getDateXML(iDate IN NUMBER, sTime IN VARCHAR2);
  PROCEDURE getDateXML(iDate IN NUMBER, sTime IN VARCHAR2, field IN VARCHAR2);
  PROCEDURE getDateXML(sID IN VARCHAR2);
  PROCEDURE dtd_and_columns;
END co2_grid_brine_data_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_grid_brine_data_pkg AS
--
-- PROCEDURE    getDateListXML
-- Description: This procedure will get list of possible formations.  
-- Input:       iDate = 0 for sampled date
--                      1 for received date
--                      2 for reported date
--
  PROCEDURE getDateListXML(iDate IN NUMBER) IS
--
    l_count    NUMBER;
    o_value    VARCHAR2(20);   -- Date Value
--
   CURSOR crsr IS
     SELECT UNIQUE(TO_CHAR(sampled_date, 'YYYY-MM-DD')) AS STR
       FROM co2_brine_sample
      WHERE LENGTH(TO_CHAR(sampled_date, 'YYYY-MM-DD')) > 0
     ORDER BY STR;
--
   CURSOR crsr1 IS
     SELECT UNIQUE(TO_CHAR(recieved_date, 'YYYY-MM-DD')) AS STR
       FROM co2_brine_sample
      WHERE LENGTH(TO_CHAR(recieved_date, 'YYYY-MM-DD')) > 0
     ORDER BY STR;
--
   CURSOR crsr2 IS
     SELECT UNIQUE(TO_CHAR(reported_date, 'YYYY-MM-DD')) AS STR
       FROM co2_brine_sample
      WHERE LENGTH(TO_CHAR(reported_date, 'YYYY-MM-DD')) > 0
     ORDER BY STR;
--
  BEGIN
--
--  ADD DTD to XML
--
    dtd_and_columns;
--
    IF (iDate = 0) THEN
      SELECT COUNT(UNIQUE(TO_CHAR(sampled_date, 'YYYY-MM-DD')))
        INTO l_count
        FROM co2_brine_sample;
    ELSIF (iDate = 1) THEN
      SELECT COUNT(UNIQUE(TO_CHAR(recieved_date, 'YYYY-MM-DD')))
        INTO l_count
        FROM co2_brine_sample;
    ELSE
      SELECT COUNT(UNIQUE(TO_CHAR(reported_date, 'YYYY-MM-DD')))
        INTO l_count
        FROM co2_brine_sample;
    END IF;
--
    htp.print('<grid_data>');
    htp.print('  <data records="'||l_count||'">');
--
--  GET Total list of unique formations in the brine data table
--
    IF (iDate = 0) THEN
      OPEN crsr;
      LOOP
        FETCH crsr
         INTO o_value; -- Tops Value
        EXIT WHEN crsr%NOTFOUND;
--
         IF (LENGTH(o_value) < 2) THEN
           o_value := '0';
         END IF;
--
        SELECT COUNT(UNIQUE(well_kid))
          INTO l_count
          FROM co2_brine_sample
         WHERE TO_CHAR(sampled_date, 'YYYY-MM-DD') = o_value;
--
         htp.print('    <row value="'||o_value||'" count="'||l_count||'" />');      
--
      END LOOP;
      CLOSE crsr;
    ELSIF (iDate = 1) THEN
      OPEN crsr1;
      LOOP
        FETCH crsr1
         INTO o_value; -- Tops Value
        EXIT WHEN crsr1%NOTFOUND;
--
         IF (LENGTH(o_value) < 2) THEN
           o_value := '0';
         END IF;
--
        SELECT COUNT(UNIQUE(well_kid))
          INTO l_count
          FROM co2_brine_sample
         WHERE TO_CHAR(recieved_date, 'YYYY-MM-DD') = o_value;
--
         htp.print('    <row value="'||o_value||'" count="'||l_count||'" />');      
--
      END LOOP;
      CLOSE crsr1;
    ELSE
      OPEN crsr2;
      LOOP
        FETCH crsr2
         INTO o_value; -- Tops Value
        EXIT WHEN crsr2%NOTFOUND;
--
         IF (LENGTH(o_value) < 2) THEN
           o_value := '0';
         END IF;
--
        SELECT COUNT(UNIQUE(well_kid))
          INTO l_count
          FROM co2_brine_sample
         WHERE TO_CHAR(reported_date, 'YYYY-MM-DD') = o_value;
--
         htp.print('    <row value="'||o_value||'" count="'||l_count||'" />');      
--
      END LOOP;
      CLOSE crsr2;
    END IF; 
--    
    htp.print('  </data>');
    htp.print('</grid_data>');
--       
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END getDateListXML;
--
--
-- PROCEDURE    getDateListXML
-- Description: This procedure will get list of possible formations.  
-- Input:       iDate = 0 for sampled date
--                      1 for received date
--                      2 for reported date
--              field = Field Name
--
  PROCEDURE getDateListXML(iDate IN NUMBER, field IN VARCHAR2) IS
--
    l_count    NUMBER;
    o_value    VARCHAR2(20);   -- Date Value
--
   CURSOR crsr(sField IN VARCHAR2) IS
     SELECT UNIQUE(TO_CHAR(sampled_date, 'YYYY-MM-DD')) AS STR
       FROM co2_brine_sample CBS
      WHERE LENGTH(TO_CHAR(sampled_date, 'YYYY-MM-DD')) > 0
        AND UPPER(field_name) = UPPER(sField)
        AND 1 = (SELECT COUNT(value)
                   FROM co2_brine_data
                  WHERE sample_kid = CBS.kid
                    AND data_type_kid = 4)
     ORDER BY STR;
--
   CURSOR crsr1(sField IN VARCHAR2) IS
     SELECT UNIQUE(TO_CHAR(recieved_date, 'YYYY-MM-DD')) AS STR
       FROM co2_brine_sample CBS
      WHERE LENGTH(TO_CHAR(recieved_date, 'YYYY-MM-DD')) > 0
        AND UPPER(field_name) = UPPER(sField)
        AND 1 = (SELECT COUNT(value)
                   FROM co2_brine_data
                  WHERE sample_kid = CBS.kid
                    AND data_type_kid = 4)
     ORDER BY STR;
--
   CURSOR crsr2(sField IN VARCHAR2) IS
     SELECT UNIQUE(TO_CHAR(reported_date, 'YYYY-MM-DD')) AS STR
       FROM co2_brine_sample CBS
      WHERE LENGTH(TO_CHAR(reported_date, 'YYYY-MM-DD')) > 0
        AND UPPER(field_name) = UPPER(sField)
        AND 1 = (SELECT COUNT(value)
                   FROM co2_brine_data
                  WHERE sample_kid = CBS.kid
                    AND data_type_kid = 4)        
     ORDER BY STR;
--
  BEGIN
--
--  ADD DTD to XML
--
    dtd_and_columns;
--
    IF (iDate = 0) THEN
      SELECT COUNT(UNIQUE(TO_CHAR(sampled_date, 'YYYY-MM-DD')))
        INTO l_count
        FROM co2_brine_sample CBS
       WHERE UPPER(field_name) = UPPER(field)
         AND 1 = (SELECT COUNT(value)
                    FROM co2_brine_data
                   WHERE sample_kid = CBS.kid
                     AND data_type_kid = 4);
    ELSIF (iDate = 1) THEN
      SELECT COUNT(UNIQUE(TO_CHAR(recieved_date, 'YYYY-MM-DD')))
        INTO l_count
        FROM co2_brine_sample CBS
       WHERE UPPER(field_name) = UPPER(field)
         AND 1 = (SELECT COUNT(value)
                    FROM co2_brine_data
                   WHERE sample_kid = CBS.kid
                     AND data_type_kid = 4);
    ELSE
      SELECT COUNT(UNIQUE(TO_CHAR(reported_date, 'YYYY-MM-DD')))
        INTO l_count
        FROM co2_brine_sample CBS
       WHERE UPPER(field_name) = UPPER(field)
         AND 1 = (SELECT COUNT(value)
                    FROM co2_brine_data
                   WHERE sample_kid = CBS.kid
                     AND data_type_kid = 4);
    END IF;
--
    htp.print('<grid_data>');
    htp.print('  <data records="'||l_count||'">');
--
--  GET Total list of unique formations in the brine data table
--
    IF (iDate = 0) THEN
      OPEN crsr(field);
      LOOP
        FETCH crsr
         INTO o_value; -- Tops Value
        EXIT WHEN crsr%NOTFOUND;
--
         IF (LENGTH(o_value) < 2) THEN
           o_value := '0';
         END IF;
--
        SELECT COUNT(UNIQUE(well_kid))
          INTO l_count
          FROM co2_brine_sample
         WHERE TO_CHAR(sampled_date, 'YYYY-MM-DD') = o_value;
--
         htp.print('    <row value="'||o_value||'" count="'||l_count||'" />');      
--
      END LOOP;
      CLOSE crsr;
    ELSIF (iDate = 1) THEN
      OPEN crsr1(field);
      LOOP
        FETCH crsr1
         INTO o_value; -- Tops Value
        EXIT WHEN crsr1%NOTFOUND;
--
         IF (LENGTH(o_value) < 2) THEN
           o_value := '0';
         END IF;
--
        SELECT COUNT(UNIQUE(well_kid))
          INTO l_count
          FROM co2_brine_sample
         WHERE TO_CHAR(recieved_date, 'YYYY-MM-DD') = o_value;
--
         htp.print('    <row value="'||o_value||'" count="'||l_count||'" />');      
--
      END LOOP;
      CLOSE crsr1;
    ELSE
      OPEN crsr2(field);
      LOOP
        FETCH crsr2
         INTO o_value; -- Tops Value
        EXIT WHEN crsr2%NOTFOUND;
--
         IF (LENGTH(o_value) < 2) THEN
           o_value := '0';
         END IF;
--
        SELECT COUNT(UNIQUE(well_kid))
          INTO l_count
          FROM co2_brine_sample
         WHERE TO_CHAR(reported_date, 'YYYY-MM-DD') = o_value;
--
         htp.print('    <row value="'||o_value||'" count="'||l_count||'" />');      
--
      END LOOP;
      CLOSE crsr2;
    END IF; 
--    
    htp.print('  </data>');
    htp.print('</grid_data>');
--       
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END getDateListXML;
--
--
-- PROCEDURE    getTopsListXML
-- Description: This procedure will get list of possible formations.  
--
  PROCEDURE getTopsListXML IS
--
    l_count    NUMBER;
    o_value    iqstrat.co2_brine_data.value%TYPE;   -- brine data value
--
   CURSOR crsr IS
     SELECT UNIQUE(UPPER(value))
       FROM co2_brine_data
      WHERE data_type_kid = 300;
--
  BEGIN
--
--  ADD DTD to XML
--
    dtd_and_columns;
--
    SELECT COUNT(UNIQUE(UPPER(value)))
      INTO l_count
      FROM co2_brine_data
     WHERE data_type_kid = 300;
--
    htp.print('<grid_data>');
    htp.print('  <data records="'||l_count||'">');
--
--  GET Total list of unique formations in the brine data table
--
    OPEN crsr;
    LOOP
      FETCH crsr
       INTO o_value; -- Tops Value
      EXIT WHEN crsr%NOTFOUND;
--    
--    Count the number of wells that have a specific formation name
--
      SELECT COUNT(UNIQUE(well_kid))
        INTO l_count
        FROM co2_brine_sample CBS,
             co2_brine_data CBD
       WHERE CBS.kid = CBD.sample_kid
         AND CBD.data_type_kid = 300
         AND UPPER(CBD.value) = o_value;
--
       htp.print('    <row value="'||o_value||'" count="'||l_count||'" />');      
--
    END LOOP;
    CLOSE crsr;
--    
    htp.print('  </data>');
    htp.print('</grid_data>');
--       
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END getTopsListXML;
--
--
-- PROCEDURE    getTopsXML
-- Description: This procedure will get brine data as xml by formation.  
-- Input:       sForm = Formation Name
--
  PROCEDURE getTopsXML(sForm IN VARCHAR2) IS
--
    l_count    NUMBER;
    o_kid      iqstrat.co2_brine_sample.kid%TYPE;        -- Sample KID
    o_wkid     iqstrat.co2_brine_sample.well_kid%TYPE;   -- Well KID
--
   CURSOR crsr(sForm IN VARCHAR2) IS
     SELECT CBS.kid
       FROM co2_brine_sample CBS,
            co2_brine_data CBD
      WHERE CBS.kid = CBD.sample_kid
        AND CBD.data_type_kid = 300
        AND UPPER(CBD.value) = UPPER(sForm)
      ORDER BY well_kid;
--
  BEGIN
--
--  ADD DTD and Fluid Data Columns to XML
--
    iqstrat.co2_brine_data_pkg.dtd_and_columns;
--
    SELECT COUNT(CBS.kid)
      INTO l_count
      FROM co2_brine_sample CBS,
           co2_brine_data CBD
     WHERE CBS.kid = CBD.sample_kid
       AND CBD.data_type_kid = 300
       AND UPPER(CBD.value) = UPPER(sForm);
--
    htp.print('<fluid_data>');
    htp.print('<data records="'||l_count||'">');
--
--  GET Fluid Data Record by Brine Data Primary Key
--
    OPEN crsr(sForm);
    LOOP
      FETCH crsr
       INTO o_kid; -- Well header KID
      EXIT WHEN crsr%NOTFOUND;
--      
      iqstrat.co2_brine_data_pkg.add_fluid_data(o_kid);     
--
    END LOOP;
    CLOSE crsr;
--    
    htp.print('</data>');
    htp.print('</fluid_data>');
--       
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END getTopsXML;
--
--
-- PROCEDURE    getDateXML
-- Description: This procedure will get brine data as xml by formation.  
-- Input:       iDate = the date to filter on
--              sTime = Formation Name
--
  PROCEDURE getDateXML(iDate IN NUMBER, sTime IN VARCHAR2) IS
--
    l_count    NUMBER;
    o_kid      iqstrat.co2_brine_sample.kid%TYPE;        -- Sample KID
    o_wkid     iqstrat.co2_brine_sample.well_kid%TYPE;   -- Well KID
--
   CURSOR crsr(sTime IN VARCHAR2) IS
     SELECT kid
       FROM co2_brine_sample
      WHERE TO_CHAR(sampled_date, 'YYYY-MM-DD') = sTime
      ORDER BY well_kid;
--
   CURSOR crsr1(sTime IN VARCHAR2) IS
     SELECT kid
       FROM co2_brine_sample
      WHERE TO_CHAR(recieved_date, 'YYYY-MM-DD') = sTime
      ORDER BY well_kid;
--
   CURSOR crsr2(sTime IN VARCHAR2) IS
     SELECT kid
       FROM co2_brine_sample
      WHERE TO_CHAR(reported_date, 'YYYY-MM-DD') = sTime
      ORDER BY well_kid;
--
  BEGIN
--
--  ADD DTD and Fluid Data Columns to XML
--
    iqstrat.co2_brine_data_pkg.dtd_and_columns;
--
    IF (iDate = 0) THEN
      SELECT COUNT(kid)
        INTO l_count
        FROM co2_brine_sample
       WHERE TO_CHAR(sampled_date, 'YYYY-MM-DD') = sTime;
    ELSIF (iDate = 1) THEN
      SELECT COUNT(kid)
        INTO l_count
        FROM co2_brine_sample
       WHERE TO_CHAR(recieved_date, 'YYYY-MM-DD') = sTime;
    ELSE
      SELECT COUNT(kid)
        INTO l_count
        FROM co2_brine_sample
        WHERE TO_CHAR(reported_date, 'YYYY-MM-DD') = sTime;
    END IF;
--
    htp.print('<fluid_data>');
    htp.print('<data records="'||l_count||'">');
--
--  GET Fluid Data Record by Brine Data Primary Key
--
    IF (iDate = 0) THEN
      OPEN crsr(sTime);
      LOOP
        FETCH crsr
         INTO o_kid; -- Well header KID
        EXIT WHEN crsr%NOTFOUND;
--      
        iqstrat.co2_brine_data_pkg.add_fluid_data(o_kid);     
--
      END LOOP;
      CLOSE crsr;
    ELSIF (iDate = 1) THEN
      OPEN crsr1(sTime);
      LOOP
        FETCH crsr1
         INTO o_kid; -- Well header KID
        EXIT WHEN crsr1%NOTFOUND;
--      
        iqstrat.co2_brine_data_pkg.add_fluid_data(o_kid);     
--
      END LOOP;
      CLOSE crsr1;
    ELSE
      OPEN crsr2(sTime);
      LOOP
        FETCH crsr2
         INTO o_kid; -- Well header KID
        EXIT WHEN crsr2%NOTFOUND;
--      
        iqstrat.co2_brine_data_pkg.add_fluid_data(o_kid);     
--
      END LOOP;
      CLOSE crsr2;
    END IF;
--    
    htp.print('</data>');
    htp.print('</fluid_data>');
--       
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END getDateXML;
--
--
-- PROCEDURE    getDateXML
-- Description: This procedure will get brine data as xml by formation.  
-- Input:       iDate = the date to filter on
--              sTime = Formation Name
--              field = Field Name
--
  PROCEDURE getDateXML(iDate IN NUMBER, sTime IN VARCHAR2, field IN VARCHAR2) IS
--
    l_count    NUMBER;
    o_kid      iqstrat.co2_brine_sample.kid%TYPE;        -- Sample KID
    o_wkid     iqstrat.co2_brine_sample.well_kid%TYPE;   -- Well KID
--
   CURSOR crsr(sTime IN VARCHAR2, sField IN VARCHAR2) IS
     SELECT kid
       FROM co2_brine_sample CBS
      WHERE TO_CHAR(sampled_date, 'YYYY-MM-DD') = sTime
        AND UPPER(field_name) = UPPER(sField)
        AND 1 = (SELECT COUNT(value)
                   FROM co2_brine_data
                  WHERE sample_kid = CBS.kid
                    AND data_type_kid = 4)
      ORDER BY well_kid;
--
   CURSOR crsr1(sTime IN VARCHAR2, sField IN VARCHAR2) IS
     SELECT kid
       FROM co2_brine_sample CBS
      WHERE TO_CHAR(recieved_date, 'YYYY-MM-DD') = sTime
        AND UPPER(field_name) = UPPER(sField)
        AND 1 = (SELECT COUNT(value)
                   FROM co2_brine_data
                  WHERE sample_kid = CBS.kid
                    AND data_type_kid = 4)
      ORDER BY well_kid;
--
   CURSOR crsr2(sTime IN VARCHAR2, sField IN VARCHAR2) IS
     SELECT kid
       FROM co2_brine_sample CBS
      WHERE TO_CHAR(reported_date, 'YYYY-MM-DD') = sTime
        AND UPPER(field_name) = UPPER(sField)
        AND 1 = (SELECT COUNT(value)
                   FROM co2_brine_data
                  WHERE sample_kid = CBS.kid
                    AND data_type_kid = 4)
      ORDER BY well_kid;
--
  BEGIN
--
--  ADD DTD and Fluid Data Columns to XML
--
    iqstrat.co2_brine_data_pkg.dtd_and_columns;
--
    IF (iDate = 0) THEN
      SELECT COUNT(kid)
        INTO l_count
        FROM co2_brine_sample CBS
       WHERE TO_CHAR(sampled_date, 'YYYY-MM-DD') = sTime
         AND UPPER(field_name) = UPPER(field)
         AND 1 = (SELECT COUNT(value)
                    FROM co2_brine_data
                   WHERE sample_kid = CBS.kid
                     AND data_type_kid = 4);
    ELSIF (iDate = 1) THEN
      SELECT COUNT(kid)
        INTO l_count
        FROM co2_brine_sample CBS
       WHERE TO_CHAR(recieved_date, 'YYYY-MM-DD') = sTime
         AND UPPER(field_name) = UPPER(field)
         AND 1 = (SELECT COUNT(value)
                    FROM co2_brine_data
                   WHERE sample_kid = CBS.kid
                     AND data_type_kid = 4);
    ELSE
      SELECT COUNT(kid)
        INTO l_count
        FROM co2_brine_sample CBS
        WHERE TO_CHAR(reported_date, 'YYYY-MM-DD') = sTime
         AND UPPER(field_name) = UPPER(field)
         AND 1 = (SELECT COUNT(value)
                    FROM co2_brine_data
                   WHERE sample_kid = CBS.kid
                     AND data_type_kid = 4);
    END IF;
--
    htp.print('<fluid_data>');
    htp.print('<data records="'||l_count||'">');
--
--  GET Fluid Data Record by Brine Data Primary Key
--
    IF (iDate = 0) THEN
      OPEN crsr(sTime, field);
      LOOP
        FETCH crsr
         INTO o_kid; -- Well header KID
        EXIT WHEN crsr%NOTFOUND;
--      
        iqstrat.co2_brine_data_pkg.add_fluid_data(o_kid);     
--
      END LOOP;
      CLOSE crsr;
    ELSIF (iDate = 1) THEN
      OPEN crsr1(sTime, field);
      LOOP
        FETCH crsr1
         INTO o_kid; -- Well header KID
        EXIT WHEN crsr1%NOTFOUND;
--      
        iqstrat.co2_brine_data_pkg.add_fluid_data(o_kid);     
--
      END LOOP;
      CLOSE crsr1;
    ELSE
      OPEN crsr2(sTime, field);
      LOOP
        FETCH crsr2
         INTO o_kid; -- Well header KID
        EXIT WHEN crsr2%NOTFOUND;
--      
        iqstrat.co2_brine_data_pkg.add_fluid_data(o_kid);     
--
      END LOOP;
      CLOSE crsr2;
    END IF;
--    
    htp.print('</data>');
    htp.print('</fluid_data>');
--       
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END getDateXML;
--
--
-- PROCEDURE    getDateXML
-- Description: This procedure will get brine data as xml by formation.  
-- Input:       iDate = the date to filter on
--              sTime = Formation Name
--              field = Field Name
--
  PROCEDURE getDateXML(sID IN VARCHAR2) IS
--
    l_count    NUMBER;
    o_kid      iqstrat.co2_brine_sample.kid%TYPE;        -- Sample KID
    o_wkid     iqstrat.co2_brine_sample.well_kid%TYPE;   -- Well KID
    o_group    iqstrat.co2_brine_sample.group_no%TYPE;   -- Group Number
--
   CURSOR crsr(sID IN VARCHAR2) IS
     SELECT kid, group_no
       FROM co2_brine_sample
      WHERE group_id = sID
     ORDER BY group_no, sampled_date, well_kid;
--
  BEGIN
--
--  ADD DTD and Fluid Data Columns to XML
--
    iqstrat.co2_brine_data_pkg.dtd_and_columns;
--
    SELECT COUNT(kid)
      INTO l_count
      FROM co2_brine_sample
     WHERE group_id = sID
    ORDER BY group_no, sampled_date, well_kid;
--
    htp.print('<fluid_data>');
    htp.print('<data records="'||l_count||'">');
--
--  GET Fluid Data Record by Brine Data Primary Key
--
    OPEN crsr(sID);
    LOOP
      FETCH crsr
       INTO o_kid,   -- Sample KID
            o_group; -- Group Number
      EXIT WHEN crsr%NOTFOUND;
--      
      iqstrat.co2_brine_data_pkg.add_fluid_data(o_kid);     
--
    END LOOP;
    CLOSE crsr;
--    
    htp.print('</data>');
    htp.print('</fluid_data>');
--       
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END getDateXML;
--
--
-- PROCEDURE    dtd_and_columns
-- Description: This procedure will build the DTD and the Columns in the 
--              fluid data table.
--
  PROCEDURE dtd_and_columns IS
--
--
  BEGIN
--
  htp.print('<?xml version="1.0"?>');
  htp.print('<!DOCTYPE grid_data [');
  htp.print('<!ELEMENT grid_data (data*)+>');
  htp.print('<!ELEMENT data (row*)>');
  htp.print('<!ATTLIST data records CDATA #REQUIRED>');
  htp.print('<!ELEMENT row EMPTY>');
  htp.print('<!ATTLIST row  value   CDATA #REQUIRED');     -- Data Value
  htp.print('               count   CDATA #REQUIRED>]>');  -- Total Wells 
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END dtd_and_columns;
--
--
END co2_grid_brine_data_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON  co2_grid_brine_data_pkg to apex_public_user;