-- * PLSQL:       co2_gridding_fluid_pkg.sql Version 1.1 03/21/2016
-- * Author:      John R. Victorine
-- * Description: This Package will build the Brine Data XML data stream
-- *              for gridding and mapping.
-- * Copyright (c) 2016 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_gridding_fluid_pkg AS
  PROCEDURE getDateXML;
  PROCEDURE add_fluid_data(sKID IN VARCHAR2);
  PROCEDURE dtd_and_columns;
--
  PROCEDURE getWellXML;
  PROCEDURE getDataKGS(sKID IN VARCHAR2);
END co2_gridding_fluid_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_gridding_fluid_pkg AS
--
-- PROCEDURE    getDateXML
-- Description: This procedure will get brine data as xml by formation.  
--
  PROCEDURE getDateXML IS
--
    l_count    NUMBER;
    l_count1   NUMBER;
    l_count2   NUMBER;
    l_count3   NUMBER;
    o_kid      iqstrat.co2_brine_sample.well_kid%TYPE;        -- Sample KID
--
   CURSOR crsr IS
     SELECT UNIQUE(well_kid)
       FROM co2_brine_sample
      WHERE group_id = 'FIELD';
--
  BEGIN
--
--  ADD DTD and Fluid Data Columns to XML
--
    dtd_and_columns;
--
    SELECT COUNT(well_kid)
      INTO l_count1
      FROM CO2_Producer_Test_Data
     WHERE group_id = 'FLUID';
--
    SELECT COUNT(well_kid)
      INTO l_count2
      FROM CO2_and_Offset_Gas COG
     WHERE group_id = 'FLUID'
       AND well_kid NOT IN(SELECT UNIQUE(well_kid) 
                             FROM CO2_Producer_Test_Data
                            WHERE well_kid = COG.well_kid);
--
    SELECT COUNT(well_kid)
      INTO l_count3
     FROM co2_and_offset_gas COG
    WHERE group_id = 'FLUID'
      AND group_no > 0
      AND group_no NOT IN (SELECT group_no
                             FROM CO2_Producer_Test_Data
                            WHERE group_no > 0
                              AND well_kid = COG.well_kid);

--
    l_count := l_count1 + l_count2 + l_count3;
--
    htp.print('<fluid_data>');
    htp.print('<data records="'||l_count||'">');
--
--  GET Fluid Data Record by Brine Data Primary Key
--
    OPEN crsr;
    LOOP
      FETCH crsr
       INTO o_kid;   -- Sample KID
      EXIT WHEN crsr%NOTFOUND;
--      
      add_fluid_data(o_kid);     
--
    END LOOP;
    CLOSE crsr;
--    
    htp.print('</data>');
    htp.print('</fluid_data>');
--       
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END getDateXML;
--
--
-- PROCEDURE    add_fluid_data
-- Description: This procedure will build the DTD and the Columns in the 
--              brine data table.
  PROCEDURE add_fluid_data(sKID IN VARCHAR2) IS
--
  o_count         NUMBER;
--
-- LOCATION Variables
  o_kid           brine.samples.kid%TYPE;
  o_well_kid      co2_brine_well.kid%TYPE;
  o_api           co2_brine_well.api_number%TYPE;
  o_lease         brine.samples.lease_name%TYPE;
  o_well          brine.samples.well_name%TYPE;
  o_state_code    brine.samples.state_code%TYPE;                     
  o_state         global.states.name%TYPE;
  o_county_code   brine.samples.county_code%TYPE; 
  o_county        global.counties.name%TYPE;
  o_field_code    brine.samples.field_code%TYPE;
  o_field         nomenclature.fields.field_name%TYPE;
  o_latitude      brine.samples.latitude%TYPE;
  o_longitude     brine.samples.longitude%TYPE;
  o_utm_x         co2_brine_wells.nad27_utm_x%TYPE; 
  o_utm_y         co2_brine_wells.nad27_utm_y%TYPE; 
  o_utm_zone      co2_brine_wells.nad27_utm_zone%TYPE; 
  o_location      VARCHAR2(255); 
-- Elevation Data  
  o_kb            brine.samples.elevation_kb%TYPE;
  o_gl            brine.samples.elevation_gl%TYPE;
  o_df            brine.samples.elevation_df%TYPE;
  o_tgt           brine.samples.elevation_tgt%TYPE; 
-- DEPTH Variables
  o_depth_top     brine.samples.depth_top%TYPE;                      
  o_depth_base    brine.samples.depth_base%TYPE;                     
--
  o_test_date     VARCHAR2(40);
  o_total         iqstrat.co2_producer_test_data.total_fluid_bbl%TYPE; 
  o_cut           iqstrat.co2_producer_test_data.oil_cut_perc%TYPE; 
  o_level         iqstrat.co2_producer_test_data.fluid_levels_ft%TYPE; 
  o_joints        iqstrat.co2_producer_test_data.joints_in_well%TYPE; 
  o_bopd          iqstrat.co2_producer_test_data.barrels_of_oil_per_day%TYPE; 
  o_bhp           iqstrat.co2_producer_test_data.est_bottom_hole_pressure_psig%TYPE; 
-- 
  o_meas_date     VARCHAR2(40);
  o_co2           iqstrat.co2_and_offset_gas.co2_percent%TYPE; 
  o_mcfd          iqstrat.co2_and_offset_gas.gas_mcf_per_day%TYPE; 
--
  o_mnem          VARCHAR2(60);
  o_value         iqstrat.co2_brine_data.value%TYPE;
  o_units         iqstrat.co2_brine_data.units%TYPE;
--
  o_temp          VARCHAR(4096);
--
  o_group_id      co2_brine_sample.group_id%TYPE;
  o_group_no      co2_brine_sample.group_no%TYPE;
--
  o_date          VARCHAR2(40);
--  
  o_name          iqstrat.CO2_brine_laboratory.name%TYPE;
  o_address       iqstrat.CO2_brine_laboratory.address%TYPE;
  o_city          iqstrat.CO2_brine_laboratory.city%TYPE;
  o_state_lab     VARCHAR2(60);
  o_zipcode       iqstrat.CO2_brine_laboratory.zipcode%TYPE; 
--
  CURSOR crsrh(sKID IN VARCHAR2) IS
    SELECT well_kid,
           TO_CHAR(test_date, 'MM/DD/YYYY'),
           NVL(total_fluid_bbl, -99), 
           NVL(oil_cut_perc, -99), 
           NVL(fluid_levels_ft, -99), 
           NVL(joints_in_well, -99), 
           NVL(barrels_of_oil_per_day, -99), 
           NVL(est_bottom_hole_pressure_psig, -99),            
           NVL(group_id, '-99'),
           NVL(group_no, -99)
      FROM co2_producer_test_data        
     WHERE well_kid  = sKID;
--  
  CURSOR crsrh1(sKID IN VARCHAR2) IS
    SELECT TO_CHAR(measured_date, 'MM/DD/YYYY'),
           NVL(co2_percent, -99),
           NVL(gas_mcf_per_day, -99),
           NVL(group_id, '-99'),
           NVL(group_no, -99)
     FROM co2_and_offset_gas COG
    WHERE well_kid = sKID
      AND group_no > 0
      AND group_id = 'FLUID'
      AND group_no NOT IN (SELECT group_no
                             FROM CO2_Producer_Test_Data
                            WHERE well_kid = sKID
                              AND group_no > 0);
--
  CURSOR crsr(sKID IN VARCHAR2) IS
    SELECT TO_CHAR(measured_date, 'MM/DD/YYYY'),
           NVL(co2_percent, -99),
           NVL(gas_mcf_per_day, -99),
           NVL(group_id, '-99'),
           NVL(group_no, -99)
      FROM co2_and_offset_gas COG
     WHERE well_kid = sKID
       AND well_kid NOT IN(SELECT UNIQUE(well_kid) 
                             FROM CO2_Producer_Test_Data
                            WHERE well_kid = COG.well_kid);    
--
  BEGIN
--
    SELECT COUNT(kid)
      INTO o_count
      FROM co2_brine_well
     WHERE kid = sKID;  
--
    IF (o_count > 0) THEN
      SELECT REPLACE(lease_name||' '||well_name,', ',' '),
             api_number,
             NVL(elevation_kb, -99),
             NVL(elevation_gl, -99),
             NVL(elevation_df, -99),
             NVL(rotary_total_depth, -99),
             nad27_latitude,
             nad27_longitude,
             nad27_utm_x,
	     nad27_utm_y,
	     nad27_utm_zone
        INTO o_lease,
             o_api,
             o_kb,
             o_gl,
             o_df,
             o_tgt,
             o_latitude,
             o_longitude,
             o_utm_x, 
             o_utm_y, 
             o_utm_zone
        FROM co2_brine_well
       WHERE kid = sKID;  
--       
      SELECT COUNT(well_kid)
        INTO o_count
        FROM co2_producer_test_data
       WHERE well_kid = sKID;  
--    
      o_total  := -99; 
      o_cut    := -99; 
      o_level  := -99; 
      o_joints := -99; 
      o_bopd   := -99; 
      o_bhp    := -99;  
-- 
      o_co2    := -99; 
      o_mcfd   := -99; 
--
      IF (o_count > 0) THEN
        OPEN crsrh(sKID);
        LOOP
--
          FETCH crsrh
           INTO o_well_kid,  -- Well header kid
                o_test_date, -- Test Date
                o_total,     -- Total Fluid
                o_cut,       -- Oil Cut (%)
                o_level,     -- Fluid Levels (ft)
                o_joints,    -- Joints in Well
                o_bopd,      -- Barrels of Oil per Day
                o_bhp,       -- Est. Bottom Hole Pressure           
                o_group_id,  -- Group ID
                o_group_no;  -- Group Number
          EXIT WHEN crsrh%NOTFOUND;
--
          SELECT COUNT(well_kid)
            INTO o_count
            FROM co2_and_offset_gas
           WHERE well_kid = sKID
             AND group_id = 'FLUID'
             AND group_no = o_group_no;
--
          o_co2    := -99; 
          o_mcfd   := -99; 
--          
          IF (o_count > 0) THEN
            SELECT NVL(co2_percent, -99),
                   NVL(gas_mcf_per_day, -99)
              INTO o_co2,
                   o_mcfd
              FROM co2_and_offset_gas
             WHERE well_kid = sKID
               AND group_id = 'FLUID'
               AND group_no = o_group_no;
          END IF;
--
          o_temp := '<row KEY="'||sKID||'" ';
          o_temp := o_temp||' '||'API="'||o_api||'" NAME="'||o_lease||'" ';
          o_temp := o_temp||' '||'WELL_KID="'||sKID||'" ';
--
          IF (o_kb != -99) THEN
            o_temp := o_temp||'KB="'||o_kb||'" ';
          END IF;
--
          IF (o_gl != -99) THEN
            o_temp := o_temp||'GL="'||o_gl||'" ';
          END IF;
--
          IF (o_df != -99) THEN
            o_temp := o_temp||'DF="'||o_df||'" ';
          END IF;
--
          IF (o_tgt != -99) THEN
            o_temp := o_temp||'TGT="'||o_tgt||'" ';
          END IF;
--
          o_temp := o_temp||' '||'LAT="'||o_latitude||'" LONG="'||o_longitude||'" ';
          o_temp := o_temp||' '||'UTM_X="'||o_utm_x||'" UTM_Y="'||o_utm_y||'" UTM_Z="'||o_utm_zone||'" ';
--
          o_temp := o_temp||'ID="'||o_group_id||'" ';
          o_temp := o_temp||'NO="'||o_group_no||'" ';
          o_temp := o_temp||'DATE="'||o_test_date||'" ';
--
          IF (o_total != -99) THEN
            o_temp := o_temp||'TOTAL="'||o_total||'" ';
          END IF;
--
          IF (o_cut != -99) THEN
            o_temp := o_temp||'CUT="'||o_cut||'" ';
          END IF;
--
          IF (o_level != -99) THEN
            o_temp := o_temp||'LEVEL="'||o_level||'" ';
          END IF;
--
          IF (o_joints != -99) THEN
            o_temp := o_temp||'JOINTS="'||o_joints||'" ';
          END IF;
--
          IF (o_bopd != -99) THEN
            o_temp := o_temp||'BOPD="'||o_bopd||'" ';
          END IF;
--
          IF (o_bhp != -99) THEN
            o_temp := o_temp||'BHP="'||o_bhp||'" ';
          END IF;
--
          IF (o_co2 != -99) THEN
            o_temp := o_temp||'CO2="'||o_co2||'" ';
          END IF;
--
          IF (o_mcfd != -99) THEN
            o_temp := o_temp||'MCF="'||o_mcfd||'" ';
          END IF;
--
          htp.print(o_temp||'/>');
--
        END LOOP;
        CLOSE crsrh;
--
      END IF;
--
      o_total  := -99; 
      o_cut    := -99; 
      o_level  := -99; 
      o_joints := -99; 
      o_bopd   := -99; 
      o_bhp    := -99;  
-- 
      o_co2    := -99; 
      o_mcfd   := -99; 
--
      SELECT COUNT(well_kid)
        INTO o_count
	FROM co2_and_offset_gas COG
       WHERE well_kid = sKID
         AND group_no > 0
         AND group_id = 'FLUID'
         AND group_no NOT IN (SELECT group_no
                                FROM CO2_Producer_Test_Data
                               WHERE well_kid = sKID
                                 AND group_no > 0);
--
      IF (o_count > 0) THEN
        OPEN crsrh1(sKID);
        LOOP
--
          FETCH crsrh1
           INTO o_test_date,
                o_co2,
                o_mcfd,
                o_group_id, 
                o_group_no;  -- Group Number
          EXIT WHEN crsrh1%NOTFOUND;
--
            o_temp := '<row KEY="'||sKID||'" ';
            o_temp := o_temp||' '||'API="'||o_api||'" NAME="'||o_lease||'" ';
            o_temp := o_temp||' '||'WELL_KID="'||sKID||'" ';
--
            IF (o_kb != -99) THEN
              o_temp := o_temp||'KB="'||o_kb||'" ';
            END IF;
--
            IF (o_gl != -99) THEN
              o_temp := o_temp||'GL="'||o_gl||'" ';
            END IF;
--
            IF (o_df != -99) THEN
              o_temp := o_temp||'DF="'||o_df||'" ';
            END IF;
--
            IF (o_tgt != -99) THEN
              o_temp := o_temp||'TGT="'||o_tgt||'" ';
            END IF;
--
            o_temp := o_temp||' '||'LAT="'||o_latitude||'" LONG="'||o_longitude||'" ';
            o_temp := o_temp||' '||'UTM_X="'||o_utm_x||'" UTM_Y="'||o_utm_y||'" UTM_Z="'||o_utm_zone||'" ';
--
            o_temp := o_temp||'ID="'||o_group_id||'" ';
            o_temp := o_temp||'NO="'||o_group_no||'" ';
            o_temp := o_temp||'DATE="'||o_test_date||'" ';
--
            IF (o_co2 != -99) THEN
              o_temp := o_temp||'CO2="'||o_co2||'" ';
            END IF;
--
            IF (o_mcfd != -99) THEN
              o_temp := o_temp||'MCF="'||o_mcfd||'" ';
            END IF;
--
            htp.print(o_temp||'/>');
--          
        END LOOP;
        CLOSE crsrh1;
      END IF;
--
      o_total  := -99; 
      o_cut    := -99; 
      o_level  := -99; 
      o_joints := -99; 
      o_bopd   := -99; 
      o_bhp    := -99;  
-- 
      o_co2    := -99; 
      o_mcfd   := -99; 
--
      SELECT COUNT(well_kid)
        INTO o_count
        FROM co2_and_offset_gas COG
       WHERE well_kid = sKID
         AND well_kid NOT IN(SELECT UNIQUE(well_kid) 
                               FROM CO2_Producer_Test_Data
                              WHERE well_kid = COG.well_kid);   
      IF (o_count > 0) THEN
--
        OPEN crsr(sKID);
        LOOP
--
          FETCH crsr
          INTO o_test_date, -- measured date
               o_co2,       -- co2 (%)
               o_mcfd,      -- MCF/D
               o_group_id,  -- Group ID
               o_group_no;  -- Group Number
          EXIT WHEN crsr%NOTFOUND;
--
          o_temp := '<row KEY="'||sKID||'" ';
          o_temp := o_temp||' '||'API="'||o_api||'" NAME="'||o_lease||'" ';
          o_temp := o_temp||' '||'WELL_KID="'||sKID||'" ';
--
          IF (o_kb != -99) THEN
            o_temp := o_temp||'KB="'||o_kb||'" ';
          END IF;
--
          IF (o_gl != -99) THEN
            o_temp := o_temp||'GL="'||o_gl||'" ';
          END IF;
--
          IF (o_df != -99) THEN
            o_temp := o_temp||'DF="'||o_df||'" ';
          END IF;
--
          IF (o_tgt != -99) THEN
            o_temp := o_temp||'TGT="'||o_tgt||'" ';
          END IF;
--
          o_temp := o_temp||' '||'LAT="'||o_latitude||'" LONG="'||o_longitude||'" ';
          o_temp := o_temp||' '||'UTM_X="'||o_utm_x||'" UTM_Y="'||o_utm_y||'" UTM_Z="'||o_utm_zone||'" ';
--
          o_temp := o_temp||'ID="'||o_group_id||'" ';
          o_temp := o_temp||'NO="'||o_group_no||'" ';
          o_temp := o_temp||'DATE="'||o_test_date||'" ';
--
          IF (o_co2 != -99) THEN
            o_temp := o_temp||'CO2="'||o_co2||'" ';
          END IF;
--
          IF (o_mcfd != -99) THEN
            o_temp := o_temp||'MCF="'||o_mcfd||'" ';
          END IF;
--
          htp.print(o_temp||'/>');
--
        END LOOP;
        CLOSE crsr;
--
      END IF;      
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later. '||sKID);
  END add_fluid_data;
--
--
-- PROCEDURE    dtd_and_columns
-- Description: This procedure will build the DTD and the Columns in the 
--              fluid data table.
  PROCEDURE dtd_and_columns IS
--
  o_kid  iqstrat.co2_brine_data_type.id%TYPE;
  o_mnem iqstrat.co2_brine_data_type.mnemonic%TYPE;
--
    CURSOR crsr IS
      SELECT UNIQUE(cbdt.id)
        FROM co2_brine_data_type cbdt,
             co2_brine_data CBD
       WHERE CBD.data_type_kid  = cbdt.id
       ORDER BY cbdt.id;
--
  BEGIN
--
  htp.print('<?xml version="1.0"?>');
  htp.print('<!DOCTYPE fluid_data [');
  htp.print('<!ELEMENT fluid_data (data*)+>');
  htp.print('<!ELEMENT data (row*)>');
  htp.print('<!ATTLIST data records CDATA #REQUIRED>');
  htp.print('<!ELEMENT row EMPTY>');
-- Primary Keys
  htp.print('<!ATTLIST row  KEY     CDATA #REQUIRED'); -- Fluid Primary Key
  htp.print('               STATE   CDATA #IMPLIED');  -- State 
  htp.print('               COUNTY  CDATA #IMPLIED');  -- County 
  htp.print('               FIELD   CDATA #IMPLIED');  -- Field  
  htp.print('               LOC     CDATA #IMPLIED');  -- Location - TRS  
  htp.print('               API     CDATA #IMPLIED');  -- Well API-Number
  htp.print('               NAME    CDATA #IMPLIED');  -- Well Name
  htp.print('               WELL_KID CDATA #IMPLIED'); -- Well KID
-- Elevation
  htp.print('               KB      CDATA #IMPLIED');  -- Kelly Bushing
  htp.print('               GL      CDATA #IMPLIED');  -- Ground Level
  htp.print('               DF      CDATA #IMPLIED');  -- Derrick Floor
  htp.print('               TGT     CDATA #IMPLIED');  -- TGT  
-- Location Information
  htp.print('               LAT     CDATA #IMPLIED');  -- Latitude
  htp.print('               LONG    CDATA #IMPLIED');  -- Longitude
  htp.print('               UTM_X   CDATA #IMPLIED');  -- UTM X
  htp.print('               UTM_Y   CDATA #IMPLIED');  -- UTM Y
  htp.print('               UTM_Z   CDATA #IMPLIED');  -- UTM Zone
-- Formation Information
  htp.print('               SRC     CDATA #IMPLIED');  -- Sample Source  
--  
  htp.print('               DATE    CDATA #IMPLIED');  -- Measured Date  
  htp.print('               ID      CDATA #IMPLIED');  -- Group ID 
  htp.print('               NO      CDATA #IMPLIED');  -- GROUP Number 
--
  htp.print('               TOTAL   CDATA #IMPLIED');  -- Total Fluid 
  htp.print('               CUT     CDATA #IMPLIED');  -- Oil Cut (%)
  htp.print('               LEVEL   CDATA #IMPLIED');  -- Fluid Level (ft)  
  htp.print('               JOINTS  CDATA #IMPLIED');  -- Joints in Well  
  htp.print('               BOPD    CDATA #IMPLIED');  -- Barrels of Oil ber day 
  htp.print('               BHP     CDATA #IMPLIED');  -- Estimated Bottom Hole Pressure (psig)  
  htp.print('               CO2     CDATA #IMPLIED');  -- CO2 (%)  
  htp.print('               MCF     CDATA #IMPLIED>]>');  -- GAS (mdf/d)  
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
  END dtd_and_columns;
--
--
-- PROCEDURE    getWellXML()
-- Description: This procedure will retrieve well_headers information from the
--              well_headers table and construct a XML.
--
  PROCEDURE getWellXML IS
--
    l_count  NUMBER;
    l_count1 NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
--
    CURSOR crsr IS
      SELECT UNIQUE(well_kid)
        FROM co2_brine_sample cbs,
             co2_brine_well qwh
       WHERE cbs.well_kid = qwh.kid
         AND cbs.group_id = 'FIELD';
--
  BEGIN
--
    SELECT COUNT(UNIQUE(well_kid))
      INTO l_count1
      FROM co2_brine_sample cbs,
           co2_brine_well qwh
     WHERE cbs.well_kid = qwh.kid
       AND cbs.group_id = 'FIELD';
--
    l_count := l_count1;
--
--  ADD Headers DTD 
--
    kgs_well_headers_pkg.dtd_and_columns;
--
    IF (l_count > 0) THEN
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr;
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        getDataKGS(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE"/>');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getWellXML;
--
--
-- PROCEDURE    getDataKGS()
-- Description: This procedure will retrieve headers information from the
--              headers table and construct a XML.
-- Input:       sKID = Headers Primary Key of the header information data 
--              sKEY    = User Created Primary Key
--              sUser   = User Primary Key
--              iAccess = User Access to data
--
  PROCEDURE getDataKGS(sKID IN VARCHAR2) IS
--
    l_count      NUMBER;
--    
    o_kid        co2_brine_well.kid%TYPE;        -- Primary Key for table
    o_type       headers.type%TYPE;                      -- Type of header
    o_api        co2_brine_well.api_number%TYPE; -- Well API-Number or UWI 
    o_name       VARCHAR(200);                           -- Well Name or Outcrop Name
    o_status     co2_brine_well.status%TYPE;     -- well status or Outcrop Type  
-- Location Columns
    o_location   headers.location%TYPE;                    -- Location 
    o_township   co2_brine_well.township%TYPE;           -- Township
    o_town_dir   co2_brine_well.township_direction%TYPE; -- Township direction
    o_range      co2_brine_well.range%TYPE;              -- Range
    o_range_dir  co2_brine_well.range_direction%TYPE;    -- Range direction
    o_section    co2_brine_well.section%TYPE;            -- Section
-- XY Position of Columns
    o_latitude   co2_brine_well.nad27_latitude%TYPE;     -- Latitude in decimal degrees
    o_longitude  co2_brine_well.nad27_longitude%TYPE;    -- Longitude in decimal degrees
    o_utm_x      co2_brine_well.nad27_utm_x%TYPE;        -- UTM X-Coordinate
    o_utm_y      co2_brine_well.nad27_utm_y%TYPE;        -- UTM Y-Coordinate
    o_utm_zone   co2_brine_well.nad27_utm_zone%TYPE;     -- UTM Zone
-- Z Position - Depth, Elevation Columns
    o_depth      co2_brine_well.rotary_total_depth%TYPE;  -- depth of well or height of outcrop
    o_kb         co2_brine_well.elevation_kb%TYPE;    -- elevation kelly bushing (well)
    o_gl         co2_brine_well.elevation_gl%TYPE;    -- elevation ground level
    o_df         co2_brine_well.elevation_df%TYPE;    -- elevation derrick floor (well)
--
    l_cnt        NUMBER(6);  -- Number of LAS Files
    t_cnt        NUMBER(6);  -- Number of tops
    c_cnt        NUMBER(6);  -- Number of Core Data
    i_cnt        NUMBER(6);  -- Number of Image Data
--
    CURSOR crsr (sKID VARCHAR2) IS
      SELECT kid,                    
             'WELL',       
             NVL(api_number, '-99'), 
             NVL(REPLACE((lease_name||' '||well_name),'&','&amp;'), '-99'),
             NVL(REPLACE(status,'&','&amp;'), '-99'),  
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(nad27_latitude, -99), 
             NVL(nad27_longitude, -99), 
             NVL(nad27_utm_x, -99), 
             NVL(nad27_utm_y, -99), 
             NVL(nad27_utm_zone, -99), 
             NVL(rotary_total_depth, -99),    
             NVL(elevation_kb, -99),
             NVL(elevation_gl, -99), 
             NVL(elevation_df, -99) 
        FROM co2_brine_well A
       WHERE kid = sKID;
--
  BEGIN
--
    o_kid       := '-99';
    o_type      := '-99';  -- Type of header - WELL or OUTCROP
    o_api       := '-99';  -- Well API-Number or UWI 
    o_name      := '-99';  -- Well Name or Outcrop Name
    o_status    := '-99';  -- well status or Outcrop Type  
-- Location Columns
    o_location  := '-99';  -- Location 
    o_township  := -99;    -- Township
    o_town_dir  := 'X';    -- Township direction
    o_range     := -99;    -- Range
    o_range_dir := 'X';    -- Range direction
    o_section   := -9;     -- Section
-- XY Position of Columns
    o_latitude  := -99;    -- Latitude in decimal degrees
    o_longitude := -99;    -- Longitude in decimal degrees
    o_utm_x     := -99;    -- UTM X-Coordinate
    o_utm_y     := -99;    -- UTM Y-Coordinate
    o_utm_zone  := -99;    -- UTM Zone
-- Z Position - Depth, Elevation Columns
    o_depth     := -99;    -- depth of well or height of outcrop
    o_kb        := -99;    -- elevation kelly bushing (well)
    o_gl        := -99;    -- elevation ground level
    o_df        := -99;    -- elevation derrick floor (well)
--  
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_kid,       -- Primary Key for table
            o_type,      -- Type of header - WELL or OUTCROP
            o_api,       -- Well API-Number or UWI 
            o_name,      -- Well Name or Outcrop Name
            o_status,    -- well status or Outcrop Type  
            -- Location Columns
            o_township,  -- Township
            o_town_dir,  -- Township direction
            o_range,     -- Range
            o_range_dir, -- Range direction
            o_section,   -- Section
            -- XY Position of Columns
            o_latitude,  -- Latitude in decimal degrees
            o_longitude, -- Longitude in decimal degrees
            o_utm_x,     -- UTM X-Coordinate
            o_utm_y,     -- UTM Y-Coordinate
            o_utm_zone,  -- UTM Zone
            -- Z Position - Depth, Elevation Columns
            o_depth,     -- depth of well or height of outcrop
            o_kb,        -- elevation kelly bushing (well)
            o_gl,        -- elevation ground level
            o_df;        -- elevation derrick floor (well)
      EXIT WHEN crsr%NOTFOUND;
--
--      Identification Information
--
        htp.print('  <data>');
        htp.print('    <info kid="'||o_kid||'" '||
                            'well_kid="'||o_kid||'" ');
--        
        IF (o_type != '-99') THEN
          htp.print('type="'||o_type||'" ');
        END IF;
--        
        IF (o_api != '-99') THEN
          htp.print('api="'||o_api||'" ');
        END IF;
--        
        IF (o_name != '-99') THEN
          SELECT REPLACE(o_name,', ',' ')
            INTO o_name
            FROM DUAL;
          htp.print('name="'||o_name||'" ');
        END IF;
--        
        IF (o_status != '-99') THEN
          htp.print('status="'||o_status||'" ');
        END IF;
--
        htp.print('/>');
--
--    Location Information
--
      IF  ((o_township != -99)   OR (o_town_dir != 'X')  OR 
          (o_range != -99)      OR (o_range_dir != 'X') OR 
          (o_section != -9)) THEN
--           
        htp.print('    <loc ');
--          
        IF (o_township != -99) THEN
          htp.print('town="'||o_township||'" ');
        END IF;       
--          
        IF (o_town_dir != 'X') THEN
          htp.print('town_dir="'||o_town_dir||'" ');
        END IF;       
--          
        IF (o_range != -99) THEN
          htp.print('range="'||o_range||'" ');
        END IF;       
--          
        IF (o_range_dir != 'X') THEN
          htp.print('range_dir="'||o_range_dir||'" ');
        END IF;       
--          
        IF (o_section != -9) THEN
          htp.print('section="'||o_section||'" ');
        END IF;       
--
        htp.print('/>');
      END IF;
--
--    XY Position Information
--
      IF ((o_latitude != -99) OR (o_longitude != -99) OR 
          (o_utm_x != -99) OR (o_utm_y != -99)  OR (o_utm_zone != -99)) THEN
--            
        htp.print('    <xy ');
--          
        IF (o_latitude != -99) THEN
          htp.print('latitude="'||o_latitude||'" ');
        END IF;       
--          
        IF (o_longitude != -99) THEN
          htp.print('longitude="'||o_longitude||'" ');
        END IF;       
--          
        IF (o_utm_zone != -99) THEN
          htp.print('zone="'||o_utm_zone||'" ');
        END IF;       
--          
        IF (o_utm_x != -99) THEN
          htp.print('utm_x="'||o_utm_x||'" ');
        END IF;       
--          
        IF (o_utm_y != -99) THEN
          htp.print('utm_y="'||o_utm_y||'" ');
        END IF;       
--
        htp.print('/>');
      END IF;
--
--    Z Position - Depth, Elevation
--
      IF ((o_depth != -99) OR (o_kb != -99) OR (o_gl != -99) OR (o_df != -99)) THEN
--            
        htp.print('    <z ');
--          
        IF (o_depth != -99) THEN
          htp.print('depth="'||o_depth||'" ');
        END IF;       
--          
        IF (o_gl != -99) THEN
          htp.print('gl="'||o_gl||'" ');
        END IF;       
--          
        IF (o_kb != -99) THEN
          htp.print('kb="'||o_kb||'" ');
        END IF;       
--          
        IF (o_df != -99) THEN
          htp.print('df="'||o_df||'" ');
        END IF;       
--
        htp.print('/>');
      END IF;
--      
      l_cnt := 0;
      SELECT COUNT(*)
        INTO l_cnt
        FROM las.well_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM co2_brine_well
                                  WHERE kid = o_kid);
--
      t_cnt := 0;
      SELECT COUNT(*)
        INTO t_cnt
        FROM qualified.well_tops
       WHERE well_header_kid IN (SELECT kid
                                   FROM co2_brine_well
                                  WHERE kid = o_kid);
--
      c_cnt := 0;
      SELECT COUNT(*)
        INTO c_cnt
        FROM core_library.core_data_and_descriptions
       WHERE well_header_kid IN (SELECT kid
                                   FROM co2_brine_well
                                  WHERE kid = o_kid)
         AND depth_top_core_ft IS NOT NULL;
--
      i_cnt := 0;
      SELECT COUNT(*)
        INTO i_cnt
        FROM qualified.images
       WHERE well_header_kid IN (SELECT kid
                                   FROM co2_brine_well
                                  WHERE kid = o_kid)
         AND file_url IS NOT NULL;
--
      htp.print('    <cnt  las="'||l_cnt||'" '||
                          'tops="'||t_cnt||'" '||
                          'core="'||c_cnt||'" '||
                          'images="'||i_cnt||'"/>');
--        
      htp.print('  </data>');
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
--
  END getDataKGS;
--
--
END co2_gridding_fluid_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON  co2_gridding_fluid_pkg to apex_public_user;
