-- * PLSQL:       co2_miniseed_files_pkg.sql Version 1.1 05/25/2016
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the pressure File information for
-- *              a specific well.
-- * Copyright (c) 2016 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_miniseed_files_pkg AS
  PROCEDURE getXML;
  PROCEDURE dtd_and_columns;
END co2_miniseed_files_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_miniseed_files_pkg AS
--
  PROCEDURE getXML IS
--
  l_count         NUMBER(6);     -- Total Number of LAS Files
-- Pressure File Information
  o_year  iqstrat.miniseed_files.file_year%TYPE;     
  o_day   iqstrat.miniseed_files.file_day%TYPE;     
  o_type  iqstrat.miniseed_files.file_type%TYPE; 
  o_url   iqstrat.miniseed_files.file_url%TYPE; 
  o_path  iqstrat.miniseed_files.file_path%TYPE; 
  o_start VARCHAR2(40);
  o_wk01  iqstrat.miniseed_files.wk01%TYPE; 
  o_wk02  iqstrat.miniseed_files.wk02%TYPE; 
  o_wk03  iqstrat.miniseed_files.wk03%TYPE; 
  o_wk04  iqstrat.miniseed_files.wk04%TYPE; 
  o_wk05  iqstrat.miniseed_files.wk05%TYPE; 
  o_wk06  iqstrat.miniseed_files.wk06%TYPE; 
  o_wk07  iqstrat.miniseed_files.wk07%TYPE; 
  o_wk08  iqstrat.miniseed_files.wk08%TYPE; 
  o_wk09  iqstrat.miniseed_files.wk09%TYPE; 
  o_wk10  iqstrat.miniseed_files.wk10%TYPE; 
  o_wk11  iqstrat.miniseed_files.wk11%TYPE; 
  o_wk12  iqstrat.miniseed_files.wk12%TYPE; 
  o_wk13  iqstrat.miniseed_files.wk13%TYPE; 
  o_wk14  iqstrat.miniseed_files.wk14%TYPE; 
  o_wk15  iqstrat.miniseed_files.wk15%TYPE; 
--
-- File Cursor to retrieve all the Files for miniseed data
--
  CURSOR crsr IS
    SELECT file_year,             -- Year of File data
           file_day,              -- day of the year for file data
           file_url,              -- URL File Path
           file_path,             -- Unix File Path for URL Ref
           TO_CHAR(equiv_date, 'YYYY-MM-DD HH24:MI:SS'),  -- Equivalent Date/Time
           wk01,
           wk02,
           wk03,
           wk04,
           wk05,
           wk06,
           wk07,
           wk08,
           wk09,
           wk10,
           wk11,
           wk12,
           wk13,
           wk14,
           wk15
      FROM miniseed_files;
--
  BEGIN
--
--  Count the total number of LAS Files for a specific well.
--
    SELECT COUNT(*)
      INTO l_count                   -- Total Number of Digital LAS Files
      FROM miniseed_files;
--
--  Build XML File
--
    dtd_and_columns;
--
    OPEN crsr;
--
    htp.print('<files records="'||l_count||'">');
--
    LOOP
      FETCH crsr
       INTO o_year,
            o_day,
            o_url,
            o_path,
            o_start,
            o_wk01,
            o_wk02,
            o_wk03,
            o_wk04,
            o_wk05,
            o_wk06,
            o_wk07,
            o_wk08,
            o_wk09,
            o_wk10,
            o_wk11,
            o_wk12,
            o_wk13,
            o_wk14,
            o_wk15;
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('  <data year="'||o_year||'" '||
                        'day="'||o_day||'" '||
                        'url="'||o_url||'" '||
                        'path="'||o_path||'" '||
                        'start="'||o_start||'" '||
                        'wk01="'||o_wk01||'" '||
                        'wk02="'||o_wk02||'" '||
                        'wk03="'||o_wk03||'" '||
                        'wk04="'||o_wk04||'" '||
                        'wk05="'||o_wk05||'" '||
                        'wk06="'||o_wk06||'" '||
                        'wk07="'||o_wk07||'" '||
                        'wk08="'||o_wk08||'" '||
                        'wk09="'||o_wk09||'" '||
                        'wk10="'||o_wk10||'" '||
                        'wk11="'||o_wk11||'" '||
                        'wk12="'||o_wk12||'" '||
                        'wk13="'||o_wk13||'" '||
                        'wk14="'||o_wk14||'" '||
                        'wk15="'||o_wk15||'"/>');
--
    END LOOP;
    htp.print('</files>');
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END getXML;
--
--
-- PROCEDURE    dtd_and_columns
-- Description: This procedure will build the DTD and the Columns in the core
--              data table.
  PROCEDURE dtd_and_columns IS
--
  BEGIN
--
    htp.print('<?xml version="1.0"?>');
    htp.print('<!DOCTYPE files [');
    htp.print('<!ELEMENT files (data*)+>');
    htp.print('<!ATTLIST files records CDATA #REQUIRED>');
    htp.print('<!ELEMENT data  EMPTY>');
    htp.print('<!ATTLIST data year     CDATA #REQUIRED');
    htp.print('               day      CDATA #REQUIRED');
    htp.print('               url      CDATA #IMPLIED');
    htp.print('               path     CDATA #IMPLIED');
    htp.print('               start    CDATA #IMPLIED');
    htp.print('               wk01     CDATA #IMPLIED');
    htp.print('               wk02     CDATA #IMPLIED');
    htp.print('               wk03     CDATA #IMPLIED');
    htp.print('               wk04     CDATA #IMPLIED');
    htp.print('               wk05     CDATA #IMPLIED');
    htp.print('               wk06     CDATA #IMPLIED');
    htp.print('               wk07     CDATA #IMPLIED');
    htp.print('               wk08     CDATA #IMPLIED');
    htp.print('               wk09     CDATA #IMPLIED');
    htp.print('               wk10     CDATA #IMPLIED');
    htp.print('               wk11     CDATA #IMPLIED');
    htp.print('               wk12     CDATA #IMPLIED');
    htp.print('               wk13     CDATA #IMPLIED');
    htp.print('               wk14     CDATA #IMPLIED');
    htp.print('               wk15     CDATA #IMPLIED>]>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END dtd_and_columns;
END co2_miniseed_files_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON co2_miniseed_files_pkg to apex_public_user;
