-- * PLSQL:       co2_pressure_catalog_pkg.sql Version 1.1 08/16/2016
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the Headers information.
-- * Copyright (c) 2016 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_pressure_catalog_pkg AS
  PROCEDURE build_web_page;
  PROCEDURE add_data(sKID IN VARCHAR2);
-----  
  PROCEDURE build_image_page(sKID IN VARCHAR2, sDateStart IN VARCHAR2, sDateEnd IN VARCHAR2);
  PROCEDURE build_image_page(sKID IN VARCHAR2, sDay IN VARCHAR2);
  PROCEDURE build_event_image_page(sKID IN VARCHAR2, sDateStart IN VARCHAR2, sDateEnd IN VARCHAR2);
-----
  PROCEDURE build_title_icons(sTitle IN VARCHAR2);
  PROCEDURE build_finish(sTitle IN VARCHAR2);
END co2_pressure_catalog_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_pressure_catalog_pkg AS
--
-- PROCEDURE    build_web_page()
-- Description: This procedure generate a summary web page to reflect the 
--              pressure catalog.
-- * Output:    Summary Web Page for Pressure Catalog.
--
  PROCEDURE build_web_page IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    iqstrat.doe_co2_wells.well_header_kid%TYPE; -- headers table primary key
    o_date   VARCHAR(16);  -- Date String for sorting by date
--
    CURSOR crsr IS
      SELECT kid, 
             TO_CHAR(start_date, 'YYYYMMDDHH24MI') AS ORDER_BY_DATE
        FROM pressure_files
      ORDER BY ORDER_BY_DATE;
--
  BEGIN
--
--  Start HTML
--
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('Pressure Catalog Summary Page');
    htp.headClose;
--    
    htp.print('<BODY>');
--
    build_title_icons( 'Pressure Catalog Summary Page' );
--
    htp.print('<table class=header border=1 cellSpacing=2 cellPadding=0 width="100%" align=center');
    htp.print('       summary="This table holds the menu options.">');
    htp.print('  <tbody>');
    htp.print('    <tr>');
    htp.print('      <td class=menu align=middle>');
    htp.print('        <A class=selected href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_pressure_catalog_pkg.build_web_page">');
    htp.print('           This Page</A> |');
    htp.print('        <A class=menu     href="http://www.kgs.ku.edu/PRS/Ozark/Pressure_Data/Lunar_Solar_Tidal_Pressure.html"');
    htp.print('           target="_blank"> Description</A> |');
    htp.print('        <A class=menu     href="http://www.kgs.ku.edu/PRS/Ozark/Pressure_Data/Wellington_KGS_1-28_PressureData.html"');
    htp.print('           target="_blank"> Display Complete Raw Pressure Data Plot</A> |');
    htp.print('        <A class=menu     href="http://www.kgs.ku.edu/General/copyright.html"');
    htp.print('           target="_blank">Copyright & Disclaimer</A> |');
    htp.print('      </td>');
    htp.print('    </tr>');
    htp.print('  </tbody>');
    htp.print('</table>');
    htp.line;
--
--    htp.p('<td><a href="http://www.kgs.ku.edu/PRS/Ozark/Pressure_Data/Wellington_KGS_1-28_PressureData.html'||'"'||
--          ' target="body">Display Complete Raw Pressure Data Plot</a></td>');
--
--    htp.p('<p>&#9737; and &#9789;  <sub>&#9737;</sub> and <sub>&#9789;</sub>  <p>');
--    'Air = &#128769; Earth = &#128771;  Water = &#128772; Fire = &#128770;');
--
--    htp.tableOpen('BORDER=1 ALIGN="CENTER" CELLPADDING=1');
--
--    htp.tableRowOpen('CENTER');
    htp.print('<table cellpadding="2" cellspacing="2" border="1" width="100%">');
    htp.p('<TR>');
    htp.p(' <TH bgColor=#b0c4de colspan="2">Pressure Measured: Date Time (Central)</TH>');
    htp.p(' <TH bgColor=#b0c4de colspan="3">Aquifer for Wellington KGS 1-28</TH>');
    htp.p(' <TH bgColor=#b0c4de colspan="2">Pressure Slope</TH>');
    htp.p(' <TH bgColor=#b0c4de colspan="1">Correction</TH>');
    htp.p(' <TH bgColor=#b0c4de colspan="1">Barometric</TH>');
    htp.p(' <TH bgColor=#b0c4de colspan="3">&nbsp;</TH>');
    htp.p(' <TH bgColor=#b0c4de colspan="1">&nbsp;</TH>');
    htp.p(' <TH bgColor=#b0c4de colspan="1">Display</TH>');
    htp.tableRowClose;
--
    htp.p('<TR>');
    htp.p(' <TH bgColor=#b0c4de>Start</TH>');
    htp.p(' <TH bgColor=#b0c4de>End</TH>');

    htp.p(' <TH bgColor=#b0c4de>Porosity [PU]</TH>');
    htp.p(' <TH bgColor=#b0c4de>Temp [deg F]</TH>');
    htp.p(' <TH bgColor=#b0c4de>Cw [1/GPa]</TH>');

    htp.p(' <TH bgColor=#b0c4de>Start [psig]</TH>');
    htp.p(' <TH bgColor=#b0c4de>End [psig]</TH>');

    htp.p(' <TH bgColor=#b0c4de>Phase [deg]</TH>');

    htp.p(' <TH bgColor=#b0c4de>Efficiency</TH>');

    htp.p(' <TH bgColor=#b0c4de>Earth</TH>');
    htp.p(' <TH bgColor=#b0c4de>Air</TH>');
    htp.p(' <TH bgColor=#b0c4de>Water</TH>');

    htp.p(' <TH bgColor=#b0c4de>&nbsp;</TH>');
    htp.p(' <TH bgColor=#b0c4de>Plot</TH>');
    htp.tableRowClose;
--
    OPEN crsr;
    LOOP
      FETCH crsr
       INTO o_kid,    -- headers table primary key
            o_date;
      EXIT WHEN crsr%NOTFOUND;
--
      add_data(o_kid);
--
    END LOOP;
    CLOSE crsr;
--
    htp.tableClose;
--
--    'Air = &#128769; Earth = &#128771;  Water = &#128772; Fire = &#128770;');
    htp.print('<p> Air = Pressure due to the barometric pressures');
    htp.print('<br> Earth = Pressure due to the earth, i.e. Earthquakes');
    htp.print('<br> Water = Pressure due to the water, i.e. Brine injections from other Wells');  
    
    htp.print('<p>');

    htp.print('<p><h3>Location of Source Data</h3>');
    htp.print('<p>Pressure data measured - Wellington KGS 1-28 at ~5020 feet depth (log depth) - Arbuckle Formation'||
              '<br>Barometric pressure measured - Strother Field Airport, Hackney, Kansas');
    htp.print('<p><img src="http://www.kgs.ku.edu/PRS/Ozark/Pressure_Data/images/DistanceMap-WellingtonKGS1-28-StrotherFieldAirport.png"</p>');
    htp.print('<br><i>Image Reference: ' ||
                  'Calculate distance, bearing and more between Latitude/Longitude points' ||
                  ' <a href="http://www.movable-type.co.uk/scripts/latlong.html"' ||
                  ' target="body">http://www.movable-type.co.uk/scripts/latlong.html</a></i>');
--
    htp.p('<p><p> Data Sources:');
    htp.p('<ul>');
    htp.p('<li>Pressure Data: Trilobite Testing Inc.' ||
          '    <a href="http://www.trilobitetesting.com"' ||
          '    target="body">www.trilobitetesting.com</a> <br>' ||
          '    Paul Simpson, President <br>1515 Commerce Parkway, <br>Hays, Kansas 67601</li>');
    htp.p('<li>NOAA National Centers for Environmental Information <br>' || 
          '    National Oceanic and Atmospheric Administration <br>' || 
          '    Quality Controlled Local Climatological Data (QCLCD)' || 
          '    <a href="http://www.ncdc.noaa.gov/qclcd/QCLCD"' ||
          '    target="body">http://www.ncdc.noaa.gov/qclcd/QCLCD</a> <br>' ||
          '    Hourly Data downloaded for the Winfield/Arkansas City: Strother Field Airport (13932/WLD)</li>');
    htp.p('</ul>');
--
    build_finish(' ');
--    
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_web_page;
--
--
-- PROCEDURE    add_data()
-- Description: This procedure will retrieve the pressure plot data by row.
-- Input:       sKID = pressure data file KID 
--
  PROCEDURE add_data(sKID IN VARCHAR2) IS
--
    l_count      NUMBER;
    l_earth      NUMBER;
    l_air        NUMBER;
    l_water      NUMBER;
--    
    o_date_start VARCHAR(40);  -- Start Date of Pressure Reading
    o_date_end   VARCHAR(40);  -- End Date of Pressure Reading
    o_phi        iqstrat.pressure_plot_info.aquifer_porosity%TYPE;    -- Porosity of Aquifer
    o_degF       iqstrat.pressure_plot_info.aquifer_temperature%TYPE; -- Temperature of Aquifer
    o_Cw         iqstrat.pressure_plot_info.compressibility%TYPE;     -- Compressibility of fluid
    o_psi_start  iqstrat.pressure_plot_info.psi_slope_start%TYPE;     -- Pressure Slope Start
    o_psi_end    iqstrat.pressure_plot_info.psi_slope_end%TYPE;       -- Pressure Slope End
    o_corr       iqstrat.pressure_plot_info.correction%TYPE;          -- Correction due to file start
    o_min        iqstrat.pressure_plot_info.scale_minimum%TYPE;       -- Plot Scale Minimum
    o_max        iqstrat.pressure_plot_info.scale_maximum%TYPE;       -- Plot Scale Maximum
    o_w          iqstrat.pressure_plot_info.baro_eff%TYPE;            -- Barometric Efficiency
--    
    CURSOR crsr (sKID IN VARCHAR2) IS
      SELECT TO_CHAR(pf.start_date, 'DD MONTH YYYY HH24:MI:SS'),
             TO_CHAR(pf.end_date, 'DD MONTH YYYY HH24:MI:SS'),
             ppi.aquifer_porosity,
             ppi.aquifer_temperature,
             ppi.compressibility,
             ppi.psi_slope_start,
             ppi.psi_slope_end,
             ppi.correction,
             ppi.scale_minimum,
             ppi.scale_maximum,
             ppi.baro_eff
        FROM pressure_files pf,
             pressure_plot_info ppi
       WHERE pf.kid = ppi.kid
         AND pf.kid = sKID;
--
  BEGIN
--
    SELECT COUNT(*)
      INTO l_count
      FROM pressure_files pf,
           pressure_plot_info ppi
     WHERE pf.kid = ppi.kid
       AND pf.kid = sKID;      
--
    IF (l_count > 0) THEN
      OPEN crsr(sKID);
      LOOP
        FETCH crsr
         INTO o_date_start,    -- Start Date of Pressure File
              o_date_end,      -- End Date of Pressure File
              o_phi,           -- Porosity of Aquifer
              o_degF,          -- Temperature of Aquifer
              o_Cw,            -- Compressibility of fluid
              o_psi_start,     -- Pressure Slope Start
              o_psi_end,       -- Pressure Slope End
              o_corr,          -- Correction due to file start
              o_min,           -- Plot Scale Minimum
              o_max,           -- Plot Scale Maximum
              o_w;             -- Barometric Efficiency
        EXIT WHEN crsr%NOTFOUND;
--
        SELECT COUNT(type_no)
          INTO l_earth
          FROM events_by_day
         WHERE pressure_files_kid = sKID
           AND type_no = 1;
--
        SELECT COUNT(type_no)
          INTO l_air
          FROM events_by_day
         WHERE pressure_files_kid = sKID
           AND type_no = 2;
--
        SELECT COUNT(type_no)
          INTO l_water
          FROM events_by_day
         WHERE pressure_files_kid = sKID
           AND type_no = 3;
--
        htp.tableRowOpen('LEFT');
          htp.tableData(o_date_start);
          htp.tableData(o_date_end);
          htp.tableData(o_phi);
          htp.tableData(o_degF);
          htp.tableData(o_Cw);
          htp.tableData(o_psi_start);
          htp.tableData(o_psi_end);
          htp.tableData(o_corr);
          htp.tableData(o_w);
          IF (l_earth > 0) THEN
--            htp.tableData(l_earth);
            htp.p('<td class=good>'||l_earth||'</td>');
          ELSE
            htp.tableData('&nbsp;');
          END IF;
          IF (l_air > 0) THEN
--            htp.tableData(l_air);
            htp.p('<td class=fair>'||l_air||'</td>');
          ELSE
            htp.tableData('&nbsp;');
          END IF;
          IF (l_water > 0) THEN
--            htp.tableData(l_water);
            htp.p('<td class=excellent>'||l_water||'</td>');
          ELSE
            htp.tableData('&nbsp;');
          END IF;
          htp.tableData('&nbsp;');
          htp.p('<td><a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_pressure_catalog_pkg.build_image_page'||
          '?sKID='||sKID||'&sDateStart='||o_date_start||'&sDateEnd='||o_date_end||'"'||
          ' target="body">Plot</a></td>');
--          '">Plot</a></td>');
        htp.tableRowClose;
--
      END LOOP;
      CLOSE crsr;
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.tableRowOpen('CENTER');
        htp.tableData(SQLERRM);
      htp.tableRowClose;
--
  END add_data;
--
--
-- PROCEDURE    build_image_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sKID = Pressure File Primary KID
-- * Output:    Summary Web Page for LAS 3.0 File Image Plot.
--
  PROCEDURE build_image_page(sKID IN VARCHAR2, sDateStart IN VARCHAR2, sDateEnd IN VARCHAR2) IS
--
    l_count      NUMBER;
    l_count_day  NUMBER;
    l_earth      NUMBER;
    l_air        NUMBER;
    l_water      NUMBER;
--    
    o_url_zip    iqstrat.pressure_data_files.file_URL%TYPE;         -- URL 
    o_file_zip   iqstrat.pressure_data_files.file_name%TYPE;   -- File Name to LAS 3.0 file
    o_url_pdf    iqstrat.pressure_data_files.file_URL%TYPE;         -- URL 
    o_file_pdf   iqstrat.pressure_data_files.file_name%TYPE;   -- File Name to LAS 3.0 file
    o_url_png    iqstrat.pressure_data_files.file_URL%TYPE;         -- URL 
    o_file_png   iqstrat.pressure_data_files.file_name%TYPE;   -- File Name to LAS 3.0 file
    o_type       iqstrat.pressure_data_files.file_type%TYPE;   -- Image File Type  
    o_day        VARCHAR2(60);
    o_day_end    VARCHAR2(60);
    o_kid        iqstrat.events_by_day.kid%TYPE;
    o_temp       VARCHAR2(60);
--
    CURSOR crsr_zip(sKID IN VARCHAR2) IS
      SELECT file_url,
             file_name             
        FROM iqstrat.pressure_data_files
       WHERE kid = sKID
         AND file_type = 'ZIP';
--
    CURSOR crsr_png(sKID IN VARCHAR2) IS
      SELECT file_url,
             file_name             
        FROM iqstrat.pressure_data_files
       WHERE kid = sKID
         AND file_type = 'PNG';
--
    CURSOR crsr_pdf(sKID IN VARCHAR2) IS
      SELECT file_url,
             file_name             
        FROM iqstrat.pressure_data_files
       WHERE kid = sKID
         AND file_type = 'PDF';
--
    CURSOR crsr_day(sKID IN VARCHAR2) IS
      SELECT kid,
             TO_CHAR(start_date, 'YYYYMMDD HH24:MI') AS THIS_DAY,
             TO_CHAR(start_date, 'DD MONTH YYYY HH24:MI'),
             TO_CHAR(end_date, 'DD MONTH YYYY HH24:MI')
        FROM iqstrat.events_by_day
       WHERE pressure_files_kid = sKID
      ORDER BY THIS_DAY;
--
  BEGIN
--
--
--  Start HTML
--
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('Pressure File: '||sDateStart||' to '||sDateEnd||' UTC');
    htp.headClose;
--
    htp.print('<BODY>');
--
    build_title_icons( 'Pressure File: '||sDateStart||' to '||sDateEnd||' UTC' );
--
    SELECT COUNT(kid)
      INTO l_count
      FROM iqstrat.pressure_data_files
     WHERE kid = sKID
       AND file_type = 'ZIP';
--
    IF (l_count > 0) THEN
      OPEN crsr_zip(sKID);
      LOOP
        FETCH crsr_zip
         INTO o_url_zip,    
              o_file_zip;
        EXIT WHEN crsr_zip%NOTFOUND;
--
        htp.print('<p><a href="'||o_url_zip||o_file_zip||'">'|| 
        ' Download pressure file used in creating image.</a> <br><i>'||
        o_url_zip||o_file_zip||' is a ZIP file which contains a Comma Separated Values (CSV) file.</i>');
--
      END LOOP;
      CLOSE crsr_zip;
    END IF;
--    
    SELECT COUNT(kid)
      INTO l_count
      FROM iqstrat.pressure_data_files
     WHERE kid = sKID
       AND file_type = 'PDF';
--
    IF (l_count > 0) THEN
      OPEN crsr_pdf(sKID);
      LOOP
        FETCH crsr_pdf
         INTO o_url_pdf,    
              o_file_pdf;
        EXIT WHEN crsr_pdf%NOTFOUND;
--
        htp.print('<p><a href="'||o_url_pdf||o_file_pdf||'"> '||
        ' Download Portable Document Format (PDF) of displayed image.</a>');
--
      END LOOP;
      CLOSE crsr_pdf;
    END IF;
--    
    SELECT COUNT(kid)
      INTO l_count
      FROM iqstrat.pressure_data_files
     WHERE kid = sKID
       AND file_type = 'PNG';
--
    SELECT COUNT(kid)
      INTO l_count_day
      FROM iqstrat.events_by_day
     WHERE pressure_files_kid = sKID;
--
    IF (l_count > 0) THEN
      OPEN crsr_png(sKID);
      LOOP
        FETCH crsr_png
         INTO o_url_png,    
              o_file_png;
        EXIT WHEN crsr_png%NOTFOUND;
--
          htp.print('<table cellpadding="2" cellspacing="2" border="0" width="100%">');
          htp.p('<TR>');
          htp.print('<td width="30%"><img src="'||o_url_png||o_file_png||'"></td>');
          htp.p('</TR>');
          htp.p('<TR>');
--          
          htp.print('<td width="70%" valign="top" align="left">');
--          
          htp.p('<p>');
--          
          IF (l_count_day > 0) THEN
            htp.print('<hr>');
            htp.print('<p>');
            htp.print('<p><h3>List of Pressure Events</h3>');
--            
            htp.print('<table cellpadding="2" cellspacing="2" border="1" width="50%">');
            htp.p('<TR>');
            htp.p(' <TH bgColor=#b0c4de>Events</TH>');
            htp.p(' <TH bgColor=#b0c4de>Plot</TH>');
            htp.p('</TR>');
--
            OPEN crsr_day(sKID);
            LOOP
              FETCH crsr_day
               INTO o_kid, 
                    o_temp,
                    o_day,
                    o_day_end;
              EXIT WHEN crsr_day%NOTFOUND;
--
                SELECT COUNT(type_no)
                  INTO l_earth
                  FROM events_by_day
                 WHERE pressure_files_kid = sKID
                   AND kid = o_kid
                   AND type_no = 1;
--
                SELECT COUNT(type_no)
                  INTO l_air
                  FROM events_by_day
                 WHERE pressure_files_kid = sKID
                   AND kid = o_kid
                   AND type_no = 2;
--
                SELECT COUNT(type_no)
                  INTO l_water
                  FROM events_by_day
                 WHERE pressure_files_kid = sKID
                   AND kid = o_kid
                   AND type_no = 3;
--
                htp.p('<TR>');
                htp.tableData(o_day||' to '||o_day_end);
                IF (l_earth > 0) THEN
                  htp.p('<td><a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_pressure_catalog_pkg.build_event_image_page'||
                  '?sKID='||o_kid||'&sDateStart='||o_day||'&sDateEnd='||o_day_end||'"'||
                  ' target="body"><img src="http://www.kgs.ku.edu/PRS/Ozark/Pressure_Data/images/Earth-sm.png"'||
                  ' border="0" align="left"></a></td>');
                ELSIF (l_air > 0) THEN
                  htp.p('<td><a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_pressure_catalog_pkg.build_event_image_page'||
                  '?sKID='||o_kid||'&sDateStart='||o_day||'&sDateEnd='||o_day_end||'"'||
                  ' target="body"><img src="http://www.kgs.ku.edu/PRS/Ozark/Pressure_Data/images/Air-sm.png"'||
                  ' border="0" align="left"></a></td>');
                ELSIF (l_water > 0) THEN
                  htp.p('<td><a href="http://chasm.kgs.ku.edu/ords/iqstrat.co2_pressure_catalog_pkg.build_event_image_page'||
                  '?sKID='||o_kid||'&sDateStart='||o_day||'&sDateEnd='||o_day_end||'"'||
                  ' target="body"><img src="http://www.kgs.ku.edu/PRS/Ozark/Pressure_Data/images/Water-sm.png"'||
                  ' border="0" align="left"></a></td>');
                END IF;
                htp.p('</TR>');
--
            END LOOP;
            CLOSE crsr_day;
--            
--            htp.print('</table></td>');
            htp.print('</table>');
--
            htp.print('<table cellpadding="0" cellspacing="0" border="0" width="100%">');
            htp.p('  <tr><td>');
            htp.p('    <img src="http://www.kgs.ku.edu/PRS/Ozark/Pressure_Data/images/Air-sm.png"'||
                  ' border="0" align="left"> Air = Pressure due to the barometric pressures');
            htp.p('  </td></tr>');
            htp.p('  <tr><td>');
            htp.p('    <img src="http://www.kgs.ku.edu/PRS/Ozark/Pressure_Data/images/Earth-sm.png"'||
                  ' border="0" align="left"> Earth = Pressure due to the earth, i.e. Earthquakes ');
            htp.p('  </td></tr>');
            htp.p('  <tr><td>');
            htp.p('    <img src="http://www.kgs.ku.edu/PRS/Ozark/Pressure_Data/images/Water-sm.png"'||
                  ' border="0" align="left"> Water = Pressure due to the water, i.e. Brine injections from other Wells');
            htp.p('  </td></tr>');
            htp.print('</table>');
--
          END IF;
          htp.print('</td>');
--            
          htp.tableRowClose;
          htp.tableClose;
--
      END LOOP;
      CLOSE crsr_png;
    END IF;
--    
    htp.print('<hr>');
    htp.print('<p>');

    htp.print('<p><h3>Location of Source Data</h3>');
    htp.print('<p>Pressure data measured - Wellington KGS 1-28 at ~5020 feet depth (log depth) - Arbuckle Formation'||
              ' Latitude: 37.3194833; Longitude: -97.433378; Elevation (GL): 1257 ft'||
              ' <i>Data is sampled at 1 second interval</i>');
    htp.print('<br>Barometric pressure measured - Strother Field Airport, Hackney, Kansas'||
              ' Latitude: 37.168; Longitude: -97.036; Elevation (GL): 1150 ft' ||
              ' <i>Data is sampled at ~1 hour interval</i>');
--
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_image_page;
--
--
-- PROCEDURE    build_image_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sKID = Pressure File Primary KID
-- * Output:    Summary Web Page for LAS 3.0 File Image Plot.
--
  PROCEDURE build_image_page(sKID IN VARCHAR2, sDay IN VARCHAR2) IS
--
    l_count      NUMBER;
    l_day        NUMBER;
    l_events     NUMBER;
--    
    o_url_png    iqstrat.pressure_data_files.file_URL%TYPE;   -- URL 
    o_file_png   iqstrat.pressure_data_files.file_name%TYPE;  -- File Name to LAS 3.0 file
--
    o_phi        iqstrat.events_by_day.aquifer_porosity%TYPE;    -- Porosity
    o_temp       iqstrat.events_by_day.aquifer_temperature%TYPE; -- Temperature [deg F]
    o_Cw         iqstrat.events_by_day.compressibility%TYPE;     -- Cw [1/GPa]
    o_psi_start  iqstrat.events_by_day.psi_slope_start%TYPE;     -- slope start [psi]
    o_psi_end    iqstrat.events_by_day.psi_slope_end%TYPE;       -- slope end [psi]
    o_corr       iqstrat.events_by_day.correction%TYPE;          -- correction [deg]
--
    o_kid        iqstrat.event_group.event_by_day_kid%TYPE;   -- event kid
    o_group      iqstrat.event_group.group_id%TYPE;           -- group id
    o_no         iqstrat.event_group.event_no%TYPE;           -- event number
    o_desc       iqstrat.event_group.description%TYPE;        -- description
    o_zone       iqstrat.event_group.zone%TYPE;               -- date zone
    o_start      VARCHAR2(20);                                -- start date/time
    o_end        VARCHAR2(20);                                -- end date/time
    o_event      VARCHAR2(20);                                -- event magnitude date/time
    o_mag        iqstrat.event_group.event_magnitude%TYPE;    -- event magnitude
    o_base       iqstrat.event_group.event_base%TYPE;         -- event base
    o_units      iqstrat.event_group.event_units%TYPE;        -- event units
--
    CURSOR crsr_png(sKID IN VARCHAR2) IS
      SELECT file_url,
             file_name             
        FROM iqstrat.pressure_data_files
       WHERE kid = sKID
         AND file_type = 'PNG';
--
   CURSOR crsr_day(sKID IN VARCHAR2) IS
     SELECT aquifer_porosity,
            aquifer_temperature,
            compressibility,
            psi_slope_start,
            psi_slope_end,
            correction
       FROM iqstrat.events_by_day
      WHERE kid = sKID;
--
   CURSOR crsr_event(sKID IN VARCHAR2) IS
     SELECT event_by_day_kid,
            group_id,
            event_no,
            description,
	    zone,
	    TO_CHAR(start_date,'HH24:MI:SS'),
	    TO_CHAR(end_date,'HH24:MI:SS'),
	    TO_CHAR(event_date,'HH24:MI:SS'),
            event_magnitude,
            event_base,
            event_units
       FROM iqstrat.event_group
      WHERE event_by_day_kid = sKID;
--     ORDER BY (event_by_day_kid,group_id,event_no);
  BEGIN
--
--
--  Start HTML
--
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('Pressure File: '||sDay);
    htp.headClose;
--
    htp.print('<BODY>');
--
    build_title_icons( 'Event Day: '||sDay );
--
    SELECT COUNT(kid)
      INTO l_count
      FROM iqstrat.pressure_data_files
     WHERE kid = sKID
       AND file_type = 'PNG';
--
     SELECT COUNT(kid)
       INTO l_day
       FROM iqstrat.events_by_day
      WHERE kid = sKID;
--
     SELECT COUNT(event_by_day_kid)
       INTO l_events
       FROM iqstrat.event_group
      WHERE event_by_day_kid = sKID;
--
    IF (l_count > 0) THEN
      OPEN crsr_png(sKID);
      LOOP
        FETCH crsr_png
         INTO o_url_png,    
              o_file_png;
        EXIT WHEN crsr_png%NOTFOUND;
--
        htp.print('<table cellpadding="2" cellspacing="2" border="0" width="100%">');
        htp.p('<TR>');
        htp.print('<td width="30%"><img src="'||o_url_png||o_file_png||'"></td>');
--
        htp.print('<td width="70%" valign="top">');
--        
        IF (l_day > 0) THEN
          htp.print('<table cellpadding="2" cellspacing="2" border="1" width="100%">');
          htp.p('<TR>');
          htp.p(' <TH bgColor=#b0c4de colspan="3">Aquifer</TH>');
          htp.p(' <TH bgColor=#b0c4de colspan="2">Pressure Slope</TH>');
          htp.p(' <TH bgColor=#b0c4de colspan="1">Correction</TH>');
          htp.p('</TR>');
--          
          htp.p('<TR>');
          htp.p(' <TH bgColor=#b0c4de>Porosity [PU]</TH>');
          htp.p(' <TH bgColor=#b0c4de>Temp [deg F]</TH>');
          htp.p(' <TH bgColor=#b0c4de>Cw [1/GPa]</TH>');  
          htp.p(' <TH bgColor=#b0c4de>Start [psig]</TH>');
          htp.p(' <TH bgColor=#b0c4de>End [psig]</TH>');  
          htp.p(' <TH bgColor=#b0c4de>Phase [deg]</TH>');
          htp.p('</TR>');
--          
          OPEN crsr_day(sKID);
          LOOP
            FETCH crsr_day
             INTO o_phi,       -- Porosity
                  o_temp,      -- Temperature [deg F]
                  o_Cw,        -- Cw [1/GPa]
                  o_psi_start, -- slope start [psi]
                  o_psi_end,   -- slope end [psi]
                  o_corr;      -- Correction [degrees]
            EXIT WHEN crsr_day%NOTFOUND;
--
              htp.p('<TR>');
              htp.tableData(o_phi);
              htp.tableData(o_temp);
              htp.tableData(o_Cw);
              htp.tableData(o_psi_start);
              htp.tableData(o_psi_end);
              htp.tableData(o_corr);
              htp.p('</TR>');
--
          END LOOP;
          CLOSE crsr_day;
--          
          htp.print('</table>');
        END IF;
--
        IF (l_events > 0) THEN
          htp.print('<p><table cellpadding="2" cellspacing="2" border="1" width="100%">');
          htp.p('<TR>');
          htp.p(' <TH bgColor=#b0c4de>&nbsp;</TH>');
          htp.p(' <TH bgColor=#b0c4de>&nbsp;</TH>');
          htp.p(' <TH bgColor=#b0c4de colspan=2>Event Times</TH>');
          htp.p(' <TH bgColor=#b0c4de>&nbsp;</TH>');
          htp.p(' <TH bgColor=#b0c4de colspan=3>Event Max/Min</TH>');
          htp.p('</TR>');
--          
          htp.p('<TR>');
          htp.p(' <TH bgColor=#b0c4de>Group</TH>');
          htp.p(' <TH bgColor=#b0c4de>Description</TH>');
          htp.p(' <TH bgColor=#b0c4de>Start</TH>');
          htp.p(' <TH bgColor=#b0c4de>End</TH>');
          htp.p(' <TH bgColor=#b0c4de>&nbsp;</TH>');
          htp.p(' <TH bgColor=#b0c4de>Time</TH>');
          htp.p(' <TH bgColor=#b0c4de>Mag [psi]</TH>');
          htp.p(' <TH bgColor=#b0c4de>Base [psi]</TH>');
          htp.p('</TR>');
--
          OPEN crsr_event(sKID);
          LOOP
            FETCH crsr_event
             INTO o_kid,    -- event kid
                  o_group,  -- group id
                  o_no,     -- event number
                  o_desc,   -- description
                  o_zone,   -- date zone
                  o_start,  -- start date/time
                  o_end,    -- end date/time
                  o_event,  -- event magnitude date/time
                  o_mag,    -- event magnitude
                  o_base,   -- event base
                  o_units;  -- event units
          EXIT WHEN crsr_event%NOTFOUND;
--
            IF (o_no = 0) THEN
              htp.p('<TR>');
              htp.p(' <td>'||o_group||'</td>');
              htp.p(' <td colspan="7">'||o_desc||'</td>');
              htp.p('</TR>');            
            ELSE
              htp.p('<TR>');
              htp.p(' <td>&nbsp;</td>');
              htp.p(' <td>'||o_desc||'</td>');
              htp.p(' <td>'||o_start||'</td>');
              htp.p(' <td>'||o_end||'</td>');
              htp.p(' <td>&nbsp;</td>');
              htp.p(' <td>'||o_event||'</td>');
              htp.p(' <td>'||o_mag||'</td>');
              htp.p(' <td>'||o_base||'</td>');
              htp.p('</TR>');            
            END IF;
--
          END LOOP;
          CLOSE crsr_event;
--          
          htp.print('</table>');
        END IF;
--
        htp.p('</td>');
        htp.p('</TR>');
        htp.print('</table></td>');
--
      END LOOP;
      CLOSE crsr_png;
    END IF;
--    
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_image_page;
--
--
-- PROCEDURE    build_event_image_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sKID = Pressure File Primary KID
-- * Output:    Summary Web Page for LAS 3.0 File Image Plot.
--
  PROCEDURE build_event_image_page(sKID IN VARCHAR2, sDateStart IN VARCHAR2, sDateEnd IN VARCHAR2) IS
--
    l_count      NUMBER;
    l_day        NUMBER;
    l_events     NUMBER;
--    
    o_type_desc  iqstrat.events_by_day.type_description%TYPE;
--
    o_url_png    iqstrat.pressure_data_files.file_URL%TYPE;   -- URL 
    o_file_png   iqstrat.pressure_data_files.file_name%TYPE;  -- File Name to LAS 3.0 file
--
    o_phi        iqstrat.events_by_day.aquifer_porosity%TYPE;    -- Porosity
    o_temp       iqstrat.events_by_day.aquifer_temperature%TYPE; -- Temperature [deg F]
    o_Cw         iqstrat.events_by_day.compressibility%TYPE;     -- Cw [1/GPa]
    o_psi_start  iqstrat.events_by_day.psi_slope_start%TYPE;     -- slope start [psi]
    o_psi_end    iqstrat.events_by_day.psi_slope_end%TYPE;       -- slope end [psi]
    o_corr       iqstrat.events_by_day.correction%TYPE;          -- correction [deg]
--
    o_kid        iqstrat.event_group.event_by_day_kid%TYPE;   -- event kid
    o_group      iqstrat.event_group.group_id%TYPE;           -- group id
    o_no         iqstrat.event_group.event_no%TYPE;           -- event number
    o_desc       iqstrat.event_group.description%TYPE;        -- description
    o_zone       iqstrat.event_group.zone%TYPE;               -- date zone
    o_date       VARCHAR2(20);                                -- start date
    o_start      VARCHAR2(20);                                -- start time
    o_end        VARCHAR2(20);                                -- end time
    o_event      VARCHAR2(20);                                -- event magnitude time
    o_mag        iqstrat.event_group.event_magnitude%TYPE;    -- event magnitude
    o_base       iqstrat.event_group.event_base%TYPE;         -- event base
    o_units      iqstrat.event_group.event_units%TYPE;        -- event units
--
    CURSOR crsr_png(sKID IN VARCHAR2) IS
      SELECT file_url,
             file_name             
        FROM iqstrat.pressure_data_files
       WHERE kid = sKID
         AND file_type = 'PNG';
--
   CURSOR crsr_day(sKID IN VARCHAR2) IS
     SELECT aquifer_porosity,
            aquifer_temperature,
            compressibility,
            psi_slope_start,
            psi_slope_end,
            correction
       FROM iqstrat.events_by_day
      WHERE kid = sKID;
--
   CURSOR crsr_event(sKID IN VARCHAR2) IS
     SELECT event_by_day_kid,
            group_id,
            event_no,
            description,
	    zone,
	    TO_CHAR(NVL(start_date, event_date),'MM/DD/YYYY'),
	    TO_CHAR(start_date,'HH24:MI:SS'),
	    TO_CHAR(end_date,'HH24:MI:SS'),
	    TO_CHAR(event_date,'HH24:MI:SS'),
            event_magnitude,
            event_base,
            event_units
       FROM iqstrat.event_group
      WHERE event_by_day_kid = sKID;
--     ORDER BY (event_by_day_kid,group_id,event_no);
  BEGIN
--
--
    SELECT COUNT(type_no)
      INTO l_count
      FROM iqstrat.events_by_day
     WHERE kid = sKID;
--
    IF (l_count > 0) THEN    
      SELECT type_description
        INTO o_type_desc
        FROM iqstrat.events_by_day
       WHERE kid = sKID;
    END IF;
--
--  Start HTML
--
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('Events: '||sDateStart||' to '||sDateEnd||' UTC' );
    htp.headClose;
--
    htp.print('<BODY>');
--
    build_title_icons( 'Events from '||sDateStart||' to '||sDateEnd||' UTC <br>'||o_type_desc);
--
    SELECT COUNT(kid)
      INTO l_count
      FROM iqstrat.pressure_data_files
     WHERE kid = sKID
       AND file_type = 'PNG';
--
     SELECT COUNT(kid)
       INTO l_day
       FROM iqstrat.events_by_day
      WHERE kid = sKID;
--
     SELECT COUNT(event_by_day_kid)
       INTO l_events
       FROM iqstrat.event_group
      WHERE event_by_day_kid = sKID;
--
    IF (l_count > 0) THEN
      OPEN crsr_png(sKID);
      LOOP
        FETCH crsr_png
         INTO o_url_png,    
              o_file_png;
        EXIT WHEN crsr_png%NOTFOUND;
--
        htp.print('<table cellpadding="2" cellspacing="2" border="0" width="100%">');
        htp.p('<TR>');
        htp.print('<td width="30%"><img src="'||o_url_png||o_file_png||'"></td>');
--
        htp.print('<td width="70%" valign="top">');
--        
        IF (l_day > 0) THEN
          htp.print('<table cellpadding="2" cellspacing="2" border="1" width="100%">');
          htp.p('<TR>');
          htp.p(' <TH bgColor=#b0c4de colspan="3">Aquifer</TH>');
          htp.p(' <TH bgColor=#b0c4de colspan="2">Pressure Slope</TH>');
          htp.p(' <TH bgColor=#b0c4de colspan="1">Correction</TH>');
          htp.p('</TR>');
--          
          htp.p('<TR>');
          htp.p(' <TH bgColor=#b0c4de>Porosity [PU]</TH>');
          htp.p(' <TH bgColor=#b0c4de>Temp [deg F]</TH>');
          htp.p(' <TH bgColor=#b0c4de>Cw [1/GPa]</TH>');  
          htp.p(' <TH bgColor=#b0c4de>Start [psig]</TH>');
          htp.p(' <TH bgColor=#b0c4de>End [psig]</TH>');  
          htp.p(' <TH bgColor=#b0c4de>Phase [deg]</TH>');
          htp.p('</TR>');
--          
          OPEN crsr_day(sKID);
          LOOP
            FETCH crsr_day
             INTO o_phi,       -- Porosity
                  o_temp,      -- Temperature [deg F]
                  o_Cw,        -- Cw [1/GPa]
                  o_psi_start, -- slope start [psi]
                  o_psi_end,   -- slope end [psi]
                  o_corr;      -- Correction [degrees]
            EXIT WHEN crsr_day%NOTFOUND;
--
              htp.p('<TR>');
              htp.tableData(o_phi);
              htp.tableData(o_temp);
              htp.tableData(o_Cw);
              htp.tableData(o_psi_start);
              htp.tableData(o_psi_end);
              htp.tableData(o_corr);
              htp.p('</TR>');
--
          END LOOP;
          CLOSE crsr_day;
--          
          htp.print('</table>');
        END IF;
--
        IF (l_events > 0) THEN
          htp.print('<p><table cellpadding="2" cellspacing="2" border="1" width="100%">');
          htp.p('<TR>');
          htp.p(' <TH bgColor=#b0c4de>&nbsp;</TH>');
          htp.p(' <TH bgColor=#b0c4de>&nbsp;</TH>');
          htp.p(' <TH bgColor=#b0c4de colspan=3>Event Times</TH>');
          htp.p(' <TH bgColor=#b0c4de>&nbsp;</TH>');
          htp.p(' <TH bgColor=#b0c4de colspan=3>Event Max/Min</TH>');
          htp.p('</TR>');
--          
          htp.p('<TR>');
          htp.p(' <TH bgColor=#b0c4de>Group</TH>');
          htp.p(' <TH bgColor=#b0c4de>Description</TH>');
          htp.p(' <TH bgColor=#b0c4de>Date</TH>');
          htp.p(' <TH bgColor=#b0c4de>Start</TH>');
          htp.p(' <TH bgColor=#b0c4de>End</TH>');
          htp.p(' <TH bgColor=#b0c4de>&nbsp;</TH>');
          htp.p(' <TH bgColor=#b0c4de>Time</TH>');
          htp.p(' <TH bgColor=#b0c4de>Mag [psi]</TH>');
          htp.p(' <TH bgColor=#b0c4de>Base [psi]</TH>');
          htp.p('</TR>');
--
          OPEN crsr_event(sKID);
          LOOP
            FETCH crsr_event
             INTO o_kid,    -- event kid
                  o_group,  -- group id
                  o_no,     -- event number
                  o_desc,   -- description
                  o_zone,   -- date zone
                  o_date,   -- start date
                  o_start,  -- start time
                  o_end,    -- end time
                  o_event,  -- event magnitude time
                  o_mag,    -- event magnitude
                  o_base,   -- event base
                  o_units;  -- event units
          EXIT WHEN crsr_event%NOTFOUND;
--
            IF (o_no = 0) THEN
              htp.p('<TR>');
              htp.p(' <td>'||o_group||'</td>');
              htp.p(' <td colspan="8">'||o_desc||'</td>');
              htp.p('</TR>');            
            ELSE
              htp.p('<TR>');
              htp.p(' <td>&nbsp;</td>');
              htp.p(' <td>'||o_desc||'</td>');
              htp.p(' <td>'||o_date||'</td>');
              htp.p(' <td>'||o_start||'</td>');
              htp.p(' <td>'||o_end||'</td>');
              htp.p(' <td>&nbsp;</td>');
              htp.p(' <td>'||o_event||'</td>');
              htp.p(' <td>'||o_mag||'</td>');
              htp.p(' <td>'||o_base||'</td>');
              htp.p('</TR>');            
            END IF;
--
          END LOOP;
          CLOSE crsr_event;
--          
          htp.print('</table>');
        END IF;
--
        htp.p('</td>');
        htp.p('</TR>');
        htp.print('</table></td>');
--
      END LOOP;
      CLOSE crsr_png;
    END IF;
--    
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_event_image_page;
--
--
-- PROCEDURE    build_title_icons
-- Description: This procedure will add the Title icons to the Web Page
--
  PROCEDURE build_title_icons(sTitle IN VARCHAR2) IS
--
  BEGIN
--
    htp.print('<table class=header cellpadding="2" cellspacing="2" border="0" width="100%">');
    htp.print('  <tr>');
    htp.print('    <td width=108>');
    htp.print('      <a href="http://www.kgs.ku.edu/"');
    htp.print('         target="body">');
    htp.print('         <img src="http://www.kgs.ku.edu/PRS/Ozark/Summary/images/kgsSmB.png"');
    htp.print('              border="0"');
    htp.print('              align="left"></a>');
    htp.print('    </td>');
    htp.print('    <td><center><h1>South-central Kansas CO<sub>2</sub> Project<br>'||
              'CO<sub>2</sub> Sequestration<br>'||sTitle||'</h1></center></td>');
    htp.print('  </tr>');
    htp.print('</table>');
--
--    htp.line;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
  END build_title_icons;
--
--
-- PROCEDURE    build_finish
-- Description: This procedure will close out the Web Page
--
  PROCEDURE build_finish(sTitle IN VARCHAR2) IS
--
  BEGIN
--
    htp.line;
--
-- End Section for the Web Page
--
    htp.print('This web page generated by ORACLE PLSQL Stored '||
              'Procedure http://chasm.kgs.ku.edu/ords/iqstrat.co2_pressure_catalog_pkg.build_web_page;');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
  END build_finish;
--
--
--
END co2_pressure_catalog_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON co2_pressure_catalog_pkg TO apex_public_user;