-- * PLSQL:       co2_events_pkg.sql Version 1.1 08/03/2015
-- * Author:      John R. Victorine
-- * Description: This Package will build the Kansas Earthquake Data XML File.
-- * Copyright (c) 2015 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_events_pkg AS
--
  PROCEDURE getXML;
--
  PROCEDURE dtd_and_columns;
--
END co2_events_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_events_pkg AS
--
-- PROCEDURE    getXML
-- Description: This procedure will get earthquake data as xml by Key.  
-- 
  PROCEDURE getXML IS
--
    l_count NUMBER;
--
    o_kid      iqstrat.co2_event_location.kid%TYPE;  -- Primary Key
    o_date     VARCHAR2(60);                           -- 'YYYY-MM-DD HH24:MI:SS'
    o_date2    VARCHAR2(60);                           -- 'MM/DD/YYYY HH24:MI:SS'
    o_central  VARCHAR2(60);                           -- 'MM/DD/YYYY HH24:MI:SS'
    o_lat      iqstrat.co2_event_location.nad27_latitude%TYPE;  -- latitude
    o_long     iqstrat.co2_event_location.nad27_longitude%TYPE; -- longitude
    o_depth    iqstrat.co2_event_location.depth%TYPE;     -- depth
    o_dunits   iqstrat.co2_event_location.depth_units%TYPE;     -- depth units
    o_mag      iqstrat.co2_event_location.event_magnitude%TYPE;       -- magnitude
--    o_magtype  iqstrat.co2_event_location.magtype%TYPE;   -- magnitude type
--    o_state    iqstrat.co2_event_location.state%TYPE;     -- State
    o_src      VARCHAR2(40);
--    o_src      iqstrat.co2_event_location.source%TYPE;    -- Source
--
    o_temp     VARCHAR(4096);
--
   CURSOR crsr IS
     SELECT kid, 
            TO_CHAR(event_time, 'YYYY-MM-DD HH24:MI:SS') AS str,
            TO_CHAR(event_time, 'MM/DD/YYYY HH24:MI:SS'),
--            TO_CHAR(central_standard_time, 'MM/DD/YYYY HH24:MI:SS'),
            TO_CHAR(event_time, 'MM/DD/YYYY HH24:MI:SS'),
            nad27_latitude,
            nad27_longitude,
            depth,
            depth_units,
            event_magnitude,
--            magtype,
--            state,
            'CO2 Sensor Array'
       FROM iqstrat.co2_event_location
      WHERE event_time is NOT NULL
--        AND state='KS'
     ORDER BY str;
--
  BEGIN
--
--  ADD DTD to XML
--
    dtd_and_columns;
--
--
    SELECT COUNT(kid)
      INTO l_count
      FROM iqstrat.co2_event_location
     WHERE event_time is NOT NULL;
--       AND state='KS';
--
    htp.print('<event>');
    htp.print('  <data records="'||l_count||'">');
--
--  GET Sensor Data 
--
    OPEN crsr;
    LOOP
      FETCH crsr
       INTO o_kid,     -- Unique KEY
            o_date,    -- Date
            o_date2,   -- Date 2
            o_central, -- Date - Central Time Zone
            o_lat,     -- Latitude
            o_long,    -- Longitude
            o_depth,   -- Depth
            o_dunits,  -- Depth Units
            o_mag,     -- Magnitude
--            o_magtype, -- magnitude type
--            o_state,   -- State
            o_src;     -- Source of data
      EXIT WHEN crsr%NOTFOUND;
--      
      o_temp := '    <row KID="'||o_kid||'" ';
      o_temp := o_temp||'utc="'||o_date2||'" ';
      o_temp := o_temp||'central="'||o_central||'" ';
      o_temp := o_temp||'lat="'||o_lat||'" ';
      o_temp := o_temp||'long="'||o_long||'" ';
      o_temp := o_temp||'depth="'||o_depth||'" ';
      o_temp := o_temp||'depth_units="'||o_dunits||'" ';
      o_temp := o_temp||'mag="'||o_mag||'" ';
--      o_temp := o_temp||'magtype="'||o_magtype||'" ';
--      o_temp := o_temp||'state="'||o_state||'" ';
      o_temp := o_temp||'source="'||o_src||'"/>';
--      
      htp.print(o_temp);
--
    END LOOP;
    CLOSE crsr;
--
    htp.print('  </data>');
    htp.print('</event>');
--             
--             
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred in getXML(): '||SQLERRM);
  END getXML;
--
--
-- PROCEDURE    dtd_and_columns
-- Description: This procedure will build the DTD.
--
  PROCEDURE dtd_and_columns IS
--
  BEGIN
--
  htp.print('<?xml version="1.0"?>');
  htp.print('<!DOCTYPE event [');
  htp.print('<!ELEMENT event (data*)+>');
  htp.print('<!ELEMENT data (row*)>');
  htp.print('<!ATTLIST data records  CDATA #REQUIRED>');
  htp.print('<!ELEMENT row EMPTY>');
  htp.print('<!ATTLIST row  KID         CDATA #IMPLIED');    -- Primary KEY
  htp.print('               utc         CDATA #IMPLIED');    -- Date and Time String
  htp.print('               central     CDATA #IMPLIED');    -- Central Date and Time String
  htp.print('               lat         CDATA #IMPLIED');    -- Latitude  
  htp.print('               long        CDATA #IMPLIED');    -- Longitude 
  htp.print('               depth       CDATA #IMPLIED');    -- Depth of event
  htp.print('               depth_units CDATA #IMPLIED');    -- Depth units
  htp.print('               mag         CDATA #IMPLIED');    -- Magnitude
  htp.print('               magtype     CDATA #IMPLIED');    -- Magnitude Type
  htp.print('               state       CDATA #IMPLIED');    -- State
  htp.print('               source      CDATA #IMPLIED>]>'); --Source
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred in dtd_and_columns(): '||SQLERRM);
  END dtd_and_columns;
--
--
END co2_events_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON  co2_events_pkg to apex_public_user;