-- * PLSQL:       co2_sensors_pkg.sql Version 1.1 06/16/2015
-- * Author:      John R. Victorine
-- * Description: This Package will build the Brine Data XML File.
-- * Copyright (c) 2015 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE co2_sensors_pkg AS
--
  PROCEDURE getXML;
--
  PROCEDURE dtd_and_columns;
--
END co2_sensors_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY co2_sensors_pkg AS
--
-- PROCEDURE    getXML
-- Description: This procedure will get brine data as xml by Key.  
-- 
  PROCEDURE getXML IS
--
    l_count NUMBER;
--
    o_kid   iqstrat.co2_seismic_sensors.kid%TYPE;             -- Sensor KID
    o_id    iqstrat.co2_seismic_sensors.id%TYPE;              -- Sensor ID 
    o_name  iqstrat.co2_seismic_sensors.name%TYPE;            -- Sensor Name
    o_lat   iqstrat.co2_seismic_sensors.nad27_latitude%TYPE;  -- Latitude
    o_long  iqstrat.co2_seismic_sensors.nad27_longitude%TYPE; -- Longitude 
    o_elev  iqstrat.co2_seismic_sensors.elevation_gl%TYPE;    -- Elevation
--
    o_temp  VARCHAR(4096);
--
   CURSOR crsr IS
     SELECT kid, 
            id,
            name,
            nad27_latitude,
            nad27_longitude,
            elevation_gl
       FROM co2_seismic_sensors
     ORDER BY id;
--
  BEGIN
--
--  ADD DTD to XML
--
    dtd_and_columns;
--
    SELECT COUNT(kid)
      INTO l_count
      FROM co2_seismic_sensors;
--
    htp.print('<sensors>');
    htp.print('<data records="'||l_count||'">');
--
--  GET Sensor Data 
--
    OPEN crsr;
    LOOP
      FETCH crsr
       INTO o_kid,  -- Sensor Unique KEY
            o_id,   -- Sensor ID
            o_name, -- Sensor Name 
            o_lat,  -- Latitude
            o_long, -- Longitude
            o_elev; -- Elevation
      EXIT WHEN crsr%NOTFOUND;
--      
      o_temp := '<row KID="'||o_kid||'" ';
      o_temp := o_temp||'ID="'||o_id||'" ';
      o_temp := o_temp||'NAME="'||o_name||'" ';
      o_temp := o_temp||'LAT="'||o_lat||'" ';
      o_temp := o_temp||'LONG="'||o_long||'" ';
      o_temp := o_temp||'ELEV="'||o_elev||'"/>';
--      
      htp.print(o_temp);
--
    END LOOP;
    CLOSE crsr;
--
    htp.print('</data>');
    htp.print('</sensors>');
--             
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred in getXML(): '||SQLERRM);
  END getXML;
--
--
-- PROCEDURE    dtd_and_columns
-- Description: This procedure will build the DTD.
--
  PROCEDURE dtd_and_columns IS
--
  BEGIN
--
  htp.print('<?xml version="1.0"?>');
  htp.print('<!DOCTYPE sensors [');
  htp.print('<!ELEMENT sensors (data*)+>');
  htp.print('<!ELEMENT data (row*)>');
  htp.print('<!ATTLIST data records CDATA #REQUIRED>');
  htp.print('<!ELEMENT row EMPTY>');
  htp.print('<!ATTLIST row  KID     CDATA #REQUIRED'); -- Sensor Primary Key
  htp.print('               ID      CDATA #REQUIRED'); -- Sensor ID Number 
  htp.print('               NAME    CDATA #REQUIRED'); -- Sensor Name
  htp.print('               LAT     CDATA #REQUIRED'); -- Latitude  
  htp.print('               LONG    CDATA #REQUIRED'); -- Longitude 
  htp.print('               ELEV    CDATA #REQUIRED>]>'); -- Ground Level Elevation  
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred in dtd_and_columns(): '||SQLERRM);
  END dtd_and_columns;
--
--
END co2_sensors_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON  co2_sensors_pkg to apex_public_user;