-- * PLSQL:       ks_earthquakes_swd_pkg.sql Version 1.1 10/11/2007
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the Headers information.
-- * Copyright (c) 2007 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE ks_earthquakes_swd_pkg AS
  PROCEDURE getXML;
  PROCEDURE getData(sKID IN VARCHAR2);
  PROCEDURE dtd_and_columns;
END ks_earthquakes_swd_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY ks_earthquakes_swd_pkg AS
--
-- PROCEDURE    getXML()
-- Description: This procedure will retrieve well_headers information from the
--              well_headers table and construct a XML.
-- Input:       lat  = Township direction
--              long = Range direction
--
  PROCEDURE getXML IS
--
    l_count  NUMBER;
    sTRS     VARCHAR2(200);
    o_kid    qualified.well_headers.kid%TYPE;        -- headers table primary key
    o_api    qualified.well_headers.api_number%TYPE; -- well api-number
--
--  Centered around the primary earthquake clusters in Harper & Sumner Counties
--
    CURSOR crsr (TRS VARCHAR2) IS
      SELECT kid, api_number
        FROM qualified.well_headers
       WHERE NAD27_Longitude > -98.35
         AND NAD27_Longitude < -97.35
         AND NAD27_Latitude > 37.0
         AND NAD27_Latitude < 37.5
         AND (status = 'SWD'
         AND  (rotary_total_depth_formation = 'ARBUCKLE'
          OR   rotary_total_depth > 5500))
          OR kid IN (1044998939, 1043234355, 1043234370)
      ORDER BY api_number;
--
  BEGIN
--
    SELECT COUNT(kid)
      INTO l_count
      FROM qualified.well_headers
     WHERE NAD27_Longitude > -98.35
       AND NAD27_Longitude < -97.35
       AND NAD27_Latitude  > 37.0
       AND NAD27_Latitude  < 37.5
       AND (status = 'SWD'
       AND  (rotary_total_depth_formation = 'ARBUCKLE'
        OR   rotary_total_depth > 5500))
        OR kid IN (1044998939, 1043234355, 1043234370);
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr(sTRS);
      LOOP
        FETCH crsr
         INTO o_kid,    -- headers table primary key
              o_api;    -- api-number of well
        EXIT WHEN crsr%NOTFOUND;
--
        getData(o_kid);
--
      END LOOP;
      CLOSE crsr;
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE"/>');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="ks_earthquakes_swd_pkg '||SQLERRM||'"/>');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getXML;
--
--
-- PROCEDURE    getData()
-- Description: This procedure will retrieve headers information from the
--              headers table and construct a XML.
-- Input:       sKID = Headers Primary Key of the header information data 
--              sKEY    = User Created Primary Key
--              sUser   = User Primary Key
--              iAccess = User Access to data
--
  PROCEDURE getData(sKID IN VARCHAR2) IS
--
    l_count      NUMBER;
--    
    o_kid        qualified.well_headers.kid%TYPE;        -- Primary Key for table
    o_type       headers.type%TYPE;                      -- Type of header
    o_api        qualified.well_headers.api_number%TYPE; -- Well API-Number or UWI 
    o_name       VARCHAR(200);                           -- Well Name or Outcrop Name
    o_status     qualified.well_headers.status%TYPE;     -- well status or Outcrop Type  
-- Other well Data Columns
    o_field      qualified.well_headers.field_name%TYPE;    -- Field Name       (well)
    o_field_kid  qualified.well_headers.field_kid%TYPE;     -- Field KID        (well)
    o_operator   qualified.well_headers.operator_name%TYPE; -- Operator Name    (well)
    o_oper_kid   qualified.well_headers.operator_kid%TYPE;  -- Operator KID     (well)
-- Location Columns
    o_state_cd   qualified.well_headers.state_code%TYPE;   -- State Code
    o_state      global.states.name%TYPE;                  -- State Name
    o_county_cd  qualified.well_headers.county_code%TYPE;  -- County Code
    o_county     global.states_counties.county_name%TYPE;  -- County Name
    o_location   headers.location%TYPE;                    -- Location 
    o_township   qualified.well_headers.township%TYPE;           -- Township
    o_town_dir   qualified.well_headers.township_direction%TYPE; -- Township direction
    o_range      qualified.well_headers.range%TYPE;              -- Range
    o_range_dir  qualified.well_headers.range_direction%TYPE;    -- Range direction
    o_section    qualified.well_headers.section%TYPE;            -- Section
-- XY Position of Columns
    o_latitude   qualified.well_headers.nad27_latitude%TYPE;     -- Latitude in decimal degrees
    o_longitude  qualified.well_headers.nad27_longitude%TYPE;    -- Longitude in decimal degrees
    o_utm_x      qualified.well_headers.nad27_utm_x%TYPE;        -- UTM X-Coordinate
    o_utm_y      qualified.well_headers.nad27_utm_y%TYPE;        -- UTM Y-Coordinate
    o_utm_zone   qualified.well_headers.nad27_utm_zone%TYPE;     -- UTM Zone
-- Z Position - Depth, Elevation Columns
    o_depth      qualified.well_headers.rotary_total_depth%TYPE;  -- depth of well or height of outcrop
    o_top        qualified.well_headers.rotary_total_depth_formation%TYPE; -- TD Tops
    o_kb         qualified.well_headers.elevation_kb%TYPE;    -- elevation kelly bushing (well)
    o_gl         qualified.well_headers.elevation_gl%TYPE;    -- elevation ground level
    o_df         qualified.well_headers.elevation_df%TYPE;    -- elevation derrick floor (well)
-- Miscellaneous Columns
    o_by         qualified.well_headers.update_initials%TYPE; -- update by
    o_date       VARCHAR(20);                                 -- update date
    o_comments   qualified.well_headers.comments%TYPE;        -- general comments
--
    l_cnt        NUMBER(6);  -- Number of LAS Files
    t_cnt        NUMBER(6);  -- Number of tops
    c_cnt        NUMBER(6);  -- Number of Core Data
    i_cnt        NUMBER(6);  -- Number of Image Data
--
    o_txt        VARCHAR2(255);
--
    CURSOR crsr (sKID VARCHAR2) IS
      SELECT kid,                    
             'WELL',       
             NVL(api_number, '-99'), 
             NVL(REPLACE((lease_name||' '||well_name),'&','&amp;'), '-99'),
             NVL(REPLACE(status,'&','&amp;'), '-99'),  
             NVL(REPLACE(field_name,'&','&amp;'), '-99'), 
             NVL(field_kid, -99), 
             NVL(REPLACE(operator_name,'&','&amp;'), '-99'),
             NVL(operator_kid, -99),
             NVL(state_code, -9),
             NVL((SELECT name 
                    FROM global.states 
                   WHERE code = A.state_code), '-99'), 
             NVL(county_code, -99),  
             NVL((SELECT county_name 
                    FROM global.states_counties 
                   WHERE state_code = A.state_code
                     AND county_code = A.county_code), '-99'), 
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(nad27_latitude, -99), 
             NVL(nad27_longitude, -99), 
             NVL(nad27_utm_x, -99), 
             NVL(nad27_utm_y, -99), 
             NVL(nad27_utm_zone, -99), 
             NVL(rotary_total_depth, -99),    
             NVL(rotary_total_depth_formation, '-99'),    
             NVL(elevation_kb, -99),
             NVL(elevation_gl, -99), 
             NVL(elevation_df, -99), 
             NVL(update_initials, '-99'), 
             TO_CHAR(update_date, 'MM/DD/YYYY'),
             NVL(REPLACE(comments,'&','&amp;'), '-99')         
        FROM qualified.well_headers A
       WHERE well_header_kid = kid
         AND well_header_kid = sKID;
--
  BEGIN
--
    o_kid       := '-99';
    o_type      := '-99';  -- Type of header - WELL or OUTCROP
    o_api       := '-99';  -- Well API-Number or UWI 
    o_name      := '-99';  -- Well Name or Outcrop Name
    o_status    := '-99';  -- well status or Outcrop Type  
-- Other well Data Columns
    o_field     := '-99';  -- Field Name       (well)
    o_field_kid := -99;    -- Field KID        (well)
    o_operator  := '-99';  -- Operator Name    (well)
    o_oper_kid  := -99;    -- Operator KID     (well)
-- Location Columns
    o_state_cd  := -9;     -- State Code
    o_state     := '-99';  -- State Name
    o_county_cd := -99;    -- County Code
    o_county    := '-99';  -- County Name
    o_location  := '-99';  -- Location 
    o_township  := -99;    -- Township
    o_town_dir  := 'X';    -- Township direction
    o_range     := -99;    -- Range
    o_range_dir := 'X';    -- Range direction
    o_section   := -9;     -- Section
-- XY Position of Columns
    o_latitude  := -99;    -- Latitude in decimal degrees
    o_longitude := -99;    -- Longitude in decimal degrees
    o_utm_x     := -99;    -- UTM X-Coordinate
    o_utm_y     := -99;    -- UTM Y-Coordinate
    o_utm_zone  := -99;    -- UTM Zone
-- Z Position - Depth, Elevation Columns
    o_depth     := -99;    -- depth of well or height of outcrop
    o_top       := '99';
    o_kb        := -99;    -- elevation kelly bushing (well)
    o_gl        := -99;    -- elevation ground level
    o_df        := -99;    -- elevation derrick floor (well)
-- Miscellaneous Columns
    o_by        := '-99';  -- update by
    o_date      := '-99';  -- update date
    o_comments  := '-99';  -- general comments
--  
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_kid,       -- Primary Key for table
            o_type,      -- Type of header - WELL or OUTCROP
            o_api,       -- Well API-Number or UWI 
            o_name,      -- Well Name or Outcrop Name
            o_status,    -- well status or Outcrop Type  
            -- Other well Data Columns
            o_field,     -- Field Name       (well)
            o_field_kid, -- Field KID        (well)
            o_operator,  -- Operator Name    (well)
            o_oper_kid,  -- Operator KID     (well)
            -- Location Columns
            o_state_cd,  -- State Code
            o_state,     -- State Name
            o_county_cd, -- County Code
            o_county,    -- County Name
            o_township,  -- Township
            o_town_dir,  -- Township direction
            o_range,     -- Range
            o_range_dir, -- Range direction
            o_section,   -- Section
            -- XY Position of Columns
            o_latitude,  -- Latitude in decimal degrees
            o_longitude, -- Longitude in decimal degrees
            o_utm_x,     -- UTM X-Coordinate
            o_utm_y,     -- UTM Y-Coordinate
            o_utm_zone,  -- UTM Zone
            -- Z Position - Depth, Elevation Columns
            o_depth,     -- depth of well or height of outcrop
            o_top,       -- total depth formation
            o_kb,        -- elevation kelly bushing (well)
            o_gl,        -- elevation ground level
            o_df,        -- elevation derrick floor (well)
            -- Miscellaneous Columns
            o_by,        -- update by
            o_date,      -- update date
            o_comments;  -- general comments
      EXIT WHEN crsr%NOTFOUND;
--
--      Identification Information
--
        htp.print('  <data>');
--
        o_txt := '    <info kid="0" '||
                           'well_kid="'||o_kid||'" ';
--
        IF (o_type != '-99') THEN
          o_txt := o_txt||'type="'||o_type||'" ';
        END IF;
--        
        IF (o_api != '-99') THEN
          o_txt := o_txt||'api="'||o_api||'" ';
        END IF;
--        
        IF (o_name != '-99') THEN
          o_txt := o_txt||'name="'||o_name||'" ';
        END IF;
--        
        IF (o_status != '-99') THEN
          o_txt := o_txt||'status="'||o_status||'" ';
        END IF;
--
        o_txt := o_txt||'/>';
        htp.print(o_txt);
        o_txt := ' ';
--
--    Other well information
--
      IF ((o_field != '-99')   OR (o_field_kid != -99) OR
          (o_operator!= '-99') OR (o_oper_kid != -99)) THEN
--            
        o_txt := '    <other ';
--          
        IF (o_operator != '-99') THEN
          o_txt := o_txt||'operator="'||o_operator||'" ';
        END IF;       
--          
        IF (o_oper_kid != -99) THEN
          o_txt := o_txt||'oper_kid="'||o_oper_kid||'" ';
        END IF;
--          
        IF (o_field != '-99') THEN
          o_txt := o_txt||'field="'||o_field||'" ';
        END IF;
--          
        IF (o_field_kid != -99) THEN
          o_txt := o_txt||'field_kid="'||o_field_kid||'" ';
        END IF;
--
        o_txt := o_txt||'/>';
        htp.print(o_txt);
        o_txt := ' ';
      END IF;
--
--    Location Information
--
      IF ((o_state_cd != -9)    OR (o_state != '-99')   OR 
          (o_county_cd != -99)  OR (o_county != '-99')  OR 
          (o_location != '-99') OR 
          (o_township != -99)   OR (o_town_dir != 'X')  OR 
          (o_range != -99)      OR (o_range_dir != 'X') OR 
          (o_section != -9)) THEN
--            
        o_txt := '    <loc ';
--          
        IF (o_state != '-99') THEN
          o_txt := o_txt||'state="'||o_state||'" ';
        END IF;       
--          
        IF (o_state_cd != -9) THEN
          o_txt := o_txt||'state_cd="'||o_state_cd||'" ';
        END IF;       
--          
        IF (o_county != '-99') THEN
          o_txt := o_txt||'county="'||o_county||'" ';
        END IF;       
--          
        IF (o_county_cd != -99) THEN
          o_txt := o_txt||'county_cd="'||o_county_cd||'" ';
        END IF;       
--          
        IF (o_location != '-99') THEN
          o_txt := o_txt||'loc="'||o_location||'" ';
        END IF;       
--          
        IF (o_township != -99) THEN
          o_txt := o_txt||'town="'||o_township||'" ';
        END IF;       
--          
        IF (o_town_dir != 'X') THEN
          o_txt := o_txt||'town_dir="'||o_town_dir||'" ';
        END IF;       
--          
        IF (o_range != -99) THEN
          o_txt := o_txt||'range="'||o_range||'" ';
        END IF;       
--          
        IF (o_range_dir != 'X') THEN
          o_txt := o_txt||'range_dir="'||o_range_dir||'" ';
        END IF;       
--          
        IF (o_section != -9) THEN
          o_txt := o_txt||'section="'||o_section||'" ';
        END IF;       
--
        o_txt := o_txt||'/>';
        htp.print(o_txt);
        o_txt := ' ';
      END IF;
--
--    XY Position Information
--
      IF ((o_latitude != -99) OR (o_longitude != -99) OR 
          (o_utm_x != -99) OR (o_utm_y != -99)  OR (o_utm_zone != -99)) THEN
--            
        o_txt := '    <xy ';
--          
        IF (o_latitude != -99) THEN
          o_txt := o_txt||'latitude="'||o_latitude||'" ';
        END IF;       
--          
        IF (o_longitude != -99) THEN
          o_txt := o_txt||'longitude="'||o_longitude||'" ';
        END IF;       
--          
        IF (o_utm_zone != -99) THEN
          o_txt := o_txt||'zone="'||o_utm_zone||'" ';
        END IF;       
--          
        IF (o_utm_x != -99) THEN
          o_txt := o_txt||'utm_x="'||o_utm_x||'" ';
        END IF;       
--          
        IF (o_utm_y != -99) THEN
          o_txt := o_txt||'utm_y="'||o_utm_y||'" ';
        END IF;       
--
        o_txt := o_txt||'/>';
        htp.print(o_txt);
        o_txt := ' ';
      END IF;
--
--    Z Position - Depth, Elevation
--
      IF ((o_depth != -99) OR (o_kb != -99) OR (o_gl != -99) OR (o_df != -99)) THEN
--            
        o_txt := '    <z ';
--          
        IF (o_depth != -99) THEN
          o_txt := o_txt||'depth="'||o_depth||'" ';
        END IF;       
--          
        IF (o_top != '-99') THEN
          o_txt := o_txt||'top="'||o_top||'" ';
        END IF;       
--          
        IF (o_gl != -99) THEN
          o_txt := o_txt||'gl="'||o_gl||'" ';
        END IF;       
--          
        IF (o_kb != -99) THEN
          o_txt := o_txt||'kb="'||o_kb||'" ';
        END IF;       
--          
        IF (o_df != -99) THEN
          o_txt := o_txt||'df="'||o_df||'" ';
        END IF;       
--
        o_txt := o_txt||'/>';
        htp.print(o_txt);
        o_txt := ' ';
      END IF;
--      
--    Comments
--
      IF (o_comments != '-99') THEN
        htp.print('    <comments> '||o_comments||'</comments>');
      END IF;
--
--    Miscellaneous Fields
--
      o_txt := '    <misc ';
--          
      IF (o_by != '-99') THEN
--        htp.print('user="'||o_by||'" ');
          o_txt := o_txt||'user="'||o_by||'" ';
      END IF;       
--         
      IF (o_date != '-99') THEN
--        htp.print('date="'||o_date||'" ');
          o_txt := o_txt||'date="'||o_date||'" ';
      END IF;       
--
      o_txt := o_txt||'/>';
      htp.print(o_txt);
      o_txt := ' ';
--
      l_cnt := 0;
      SELECT COUNT(*)
        INTO l_cnt
        FROM las.well_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE kid = o_kid);
--
      t_cnt := 0;
      SELECT COUNT(*)
        INTO t_cnt
        FROM qualified.well_tops
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE kid = o_kid);
--
      c_cnt := 0;
      SELECT COUNT(*)
        INTO c_cnt
        FROM core_library.core_data_and_descriptions
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE kid = o_kid)
         AND depth_top_core_ft IS NOT NULL;
--
      i_cnt := 0;
      SELECT COUNT(*)
        INTO i_cnt
        FROM qualified.images
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE kid = o_kid)
         AND file_url IS NOT NULL;
--
      htp.print('    <cnt  las="'||l_cnt||'" '||
                          'tops="'||t_cnt||'" '||
                          'core="'||c_cnt||'" '||
                          'images="'||i_cnt||'"/>');
--        
      htp.print('  </data>');
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
--
  END getData;
--
--
-- PROCEDURE    dtd_and_columns
-- Description: This procedure will build the DTD and the Columns in the core
--              data table.
  PROCEDURE dtd_and_columns IS
--
  BEGIN
--
    htp.print('<?xml version="1.0"?>');
    htp.print('<!DOCTYPE headers [');
    htp.print('<!ELEMENT headers (data*)>');                  
    htp.print('<!ATTLIST headers records CDATA #IMPLIED>');    -- Total # of Records
    htp.print('<!ELEMENT data (info*, ');                      
    htp.print('                other?, ');                     
    htp.print('                loc?, ');                       
    htp.print('                xy?, ');                        
    htp.print('                z?, ');                         
    htp.print('                comments?, ');                  
    htp.print('                misc?, ');                  
    htp.print('                cnt?)>');                      
    htp.print('<!ELEMENT info  EMPTY>');                       
    htp.print('<!ATTLIST info  kid   CDATA #IMPLIED');          -- Primary KGS KEY
    htp.print('                well_kid   CDATA #IMPLIED');     -- Primary KEY Defined
    htp.print('                key   CDATA #IMPLIED');          -- Primary KEY Defined
    htp.print('                type  CDATA #IMPLIED');          -- type of data
    htp.print('                api   CDATA #IMPLIED');          -- API Number of Well
    htp.print('                name   CDATA #IMPLIED');         -- Outcrop Name
    htp.print('                status CDATA #IMPLIED');         -- Well Status
    htp.print('                error  CDATA #IMPLIED>');        -- Error
    htp.print('<!ELEMENT other EMPTY>');                       
    htp.print('<!ATTLIST other operator  CDATA #IMPLIED');      -- Operator Name
    htp.print('                oper_kid  CDATA #IMPLIED');      -- Operator KID
    htp.print('                field     CDATA #IMPLIED');      -- Field Name
    htp.print('                field_kid CDATA #IMPLIED>');     -- Field KID
    htp.print('<!ELEMENT loc EMPTY>');                         
    htp.print('<!ATTLIST loc state     CDATA #IMPLIED');        -- State Name
    htp.print('              state_cd  CDATA #IMPLIED');        -- State Code
    htp.print('              county    CDATA #IMPLIED');        -- County Name
    htp.print('              county_cd CDATA #IMPLIED');        -- County Code
    htp.print('              loc       CDATA #IMPLIED');        -- Location
    htp.print('              town      CDATA #IMPLIED');        -- township
    htp.print('              town_dir  CDATA #IMPLIED');        -- township direction
    htp.print('              range     CDATA #IMPLIED');        -- range
    htp.print('              range_dir CDATA #IMPLIED');        -- range direction
    htp.print('              section   CDATA #IMPLIED>');       -- section
    htp.print('<!ELEMENT xy  EMPTY>');                         
    htp.print('<!ATTLIST xy  latitude  CDATA #IMPLIED');        -- Latitude
    htp.print('              longitude CDATA #IMPLIED');        -- Longitude
    htp.print('              zone      CDATA #IMPLIED');        -- UTM X-Position
    htp.print('              utm_x     CDATA #IMPLIED');        -- UTM X-Position
    htp.print('              utm_y     CDATA #IMPLIED>');       -- UTM Y-Position
    htp.print('<!ELEMENT z   EMPTY>');                         
    htp.print('<!ATTLIST z   depth     CDATA #IMPLIED');        -- Depth or Height
    htp.print('              top       CDATA #IMPLIED');        -- TD Tops
    htp.print('              gl        CDATA #IMPLIED');        -- Ground Level
    htp.print('              kb        CDATA #IMPLIED');        -- Kelly Bushing
    htp.print('              df        CDATA #IMPLIED>');       -- Derrick Floor
    htp.print('<!ELEMENT comments (#PCDATA)>');                 -- Comments
    htp.print('<!ELEMENT misc EMPTY>');                        
    htp.print('<!ATTLIST misc user      CDATA #IMPLIED');       -- user update info
    htp.print('               access    CDATA #IMPLIED');       -- access of data
    htp.print('               source    CDATA #IMPLIED');       -- source of this data
    htp.print('               date      CDATA #IMPLIED>');      -- Date modified    
    htp.print('<!ELEMENT cnt  EMPTY>');
    htp.print('<!ATTLIST cnt  las       CDATA #IMPLIED');
    htp.print('               tops      CDATA #IMPLIED');
    htp.print('               core      CDATA #IMPLIED');
    htp.print('               images    CDATA #IMPLIED>]>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END dtd_and_columns;
--
--
END ks_earthquakes_swd_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON ks_earthquakes_swd_pkg to apex_public_user;