-- * PLSQL:       ok_earthquakes_pkg.sql Version 1.1 08/03/2015
-- * Author:      John R. Victorine
-- * Description: This Package will build the Kansas Earthquake Data XML File.
-- * Copyright (c) 2015 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE ok_earthquakes_pkg AS
--
  PROCEDURE getXML;
  PROCEDURE build_csv_page;
--
  PROCEDURE dtd_and_columns;
--
END ok_earthquakes_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY ok_earthquakes_pkg AS
--
-- PROCEDURE    getXML
-- Description: This procedure will get earthquake data as xml by Key.  
-- 
  PROCEDURE getXML IS
--
    l_count NUMBER;
--
    o_kid      gis_webinfo.earthquakes.objectid%TYPE;  -- Primary Key
    o_date     VARCHAR2(60);                           -- 'YYYY-MM-DD HH24:MI:SS'
    o_date2    VARCHAR2(60);                           -- 'MM/DD/YYYY HH24:MI:SS'
    o_central  VARCHAR2(60);                           -- 'MM/DD/YYYY HH24:MI:SS'
    o_lat      gis_webinfo.earthquakes.latitude%TYPE;  -- latitude
    o_long     gis_webinfo.earthquakes.longitude%TYPE; -- longitude
    o_depth    gis_webinfo.earthquakes.depth%TYPE;     -- depth
    o_mag      gis_webinfo.earthquakes.mag%TYPE;       -- magnitude
    o_magtype  gis_webinfo.earthquakes.magtype%TYPE;   -- magnitude type
    o_state    gis_webinfo.earthquakes.state%TYPE;     -- State
    o_src      gis_webinfo.earthquakes.source%TYPE;    -- Source
--
    o_temp     VARCHAR(4096);
--
   CURSOR crsr IS
     SELECT objectid, 
            TO_CHAR(time, 'YYYY-MM-DD HH24:MI:SS') AS str,
            TO_CHAR(time, 'MM/DD/YYYY HH24:MI:SS'),
            TO_CHAR(central_standard_time, 'MM/DD/YYYY HH24:MI:SS'),
            latitude,
            longitude,
            depth,
            mag,
            magtype,
            state,
            source
       FROM gis_webinfo.earthquakes
      WHERE time is NOT NULL
        AND state='OK'
     ORDER BY str;
--
  BEGIN
--
--  ADD DTD to XML
--
    dtd_and_columns;
--
--
    SELECT COUNT(objectid)
      INTO l_count
      FROM gis_webinfo.earthquakes
     WHERE time is NOT NULL
       AND state='OK';
--
    htp.print('<event>');
    htp.print('  <data records="'||l_count||'">');
--
--  GET Sensor Data 
--
    OPEN crsr;
    LOOP
      FETCH crsr
       INTO o_kid,     -- Unique KEY
            o_date,    -- Date
            o_date2,   -- Date 2
            o_central, -- Date - Central Time Zone
            o_lat,     -- Latitude
            o_long,    -- Longitude
            o_depth,   -- Depth
            o_mag,     -- Magnitude
            o_magtype, -- magnitude type
            o_state,   -- State
            o_src;     -- Source of data
      EXIT WHEN crsr%NOTFOUND;
--      
      o_temp := '    <row KID="'||o_kid||'" ';
      o_temp := o_temp||'utc="'||o_date2||'" ';
      o_temp := o_temp||'central="'||o_central||'" ';
      o_temp := o_temp||'lat="'||o_lat||'" ';
      o_temp := o_temp||'long="'||o_long||'" ';
      o_temp := o_temp||'depth="'||o_depth||'" ';
      o_temp := o_temp||'mag="'||o_mag||'" ';
      o_temp := o_temp||'magtype="'||o_magtype||'" ';
      o_temp := o_temp||'state="'||o_state||'" ';
      o_temp := o_temp||'source="'||o_src||'"/>';
--      
      htp.print(o_temp);
--
    END LOOP;
    CLOSE crsr;
--
    htp.print('  </data>');
    htp.print('</event>');
--             
--             
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred in getXML(): '||SQLERRM);
  END getXML;
--
--
-- PROCEDURE build_csv_page
-- Description: This procedure will get earthquake data as xml by Key.  
-- 
  PROCEDURE build_csv_page IS
--
    l_count NUMBER;
--
    o_kid      gis_webinfo.earthquakes.objectid%TYPE;  -- Primary Key
    o_date     VARCHAR2(60);                           -- 'YYYY-MM-DD HH24:MI:SS'
    o_date2    VARCHAR2(60);                           -- 'MM/DD/YYYY HH24:MI:SS'
    o_central  VARCHAR2(60);                           -- 'MM/DD/YYYY HH24:MI:SS'
    o_lat      gis_webinfo.earthquakes.latitude%TYPE;  -- latitude
    o_long     gis_webinfo.earthquakes.longitude%TYPE; -- longitude
    o_depth    gis_webinfo.earthquakes.depth%TYPE;     -- depth
    o_mag      gis_webinfo.earthquakes.mag%TYPE;       -- magnitude
    o_magtype  gis_webinfo.earthquakes.magtype%TYPE;   -- magnitude type
    o_state    gis_webinfo.earthquakes.state%TYPE;     -- State
    o_src      gis_webinfo.earthquakes.source%TYPE;    -- Source
--
    o_temp     VARCHAR(4096);
--
   CURSOR crsr IS
     SELECT objectid, 
            TO_CHAR(time, 'YYYY-MM-DD HH24:MI:SS') AS str,
            TO_CHAR(time, 'MM/DD/YYYY HH24:MI:SS'),
            TO_CHAR(central_standard_time, 'MM/DD/YYYY HH24:MI:SS'),
            latitude,
            longitude,
            depth,
            mag,
            magtype,
            state,
            source
       FROM gis_webinfo.earthquakes
      WHERE time is NOT NULL
        AND state='OK'
     ORDER BY str;
--
  BEGIN
--
    SELECT COUNT(objectid)
      INTO l_count
      FROM gis_webinfo.earthquakes
     WHERE time is NOT NULL
       AND state='OK';
--
--  Start HTML
--
    htp.print('<HTML><HEAD><TITLE>Kansas Seismic Events</TITLE></HEAD><BODY>');
    htp.p( 'Summary Page for Kansas Earthquakes Data <br>');
--
    o_temp := 'UTC,CENTRAL,latitude,longitude,depth,mag,type,source, <br>';
    htp.p( o_temp );
--
--
--  GET Sensor Data 
--
    OPEN crsr;
    LOOP
      FETCH crsr
       INTO o_kid,     -- Unique KEY
            o_date,    -- Date
            o_date2,   -- Date 2
            o_central, -- Date - Central Time Zone
            o_lat,     -- Latitude
            o_long,    -- Longitude
            o_depth,   -- Depth
            o_mag,     -- Magnitude
            o_magtype, -- magnitude type
            o_state,   -- State
            o_src;     -- Source of data
      EXIT WHEN crsr%NOTFOUND;
--  
      o_temp := o_date2||','||o_central||','||o_lat||','||o_long||','||o_depth||','||o_mag||','||o_magtype||','||o_src||',<br>';
--      
      htp.print(o_temp);
--
    END LOOP;
    CLOSE crsr;
--
    htp.print('</BODY></HTML>');
--             
--             
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred in getXML(): '||SQLERRM);
  END build_csv_page;
--
--
-- PROCEDURE    dtd_and_columns
-- Description: This procedure will build the DTD.
--
  PROCEDURE dtd_and_columns IS
--
  BEGIN
--
  htp.print('<?xml version="1.0"?>');
  htp.print('<!DOCTYPE event [');
  htp.print('<!ELEMENT event (data*)+>');
  htp.print('<!ELEMENT data (row*)>');
  htp.print('<!ATTLIST data records  CDATA #REQUIRED>');
  htp.print('<!ELEMENT row EMPTY>');
  htp.print('<!ATTLIST row  KID      CDATA #IMPLIED');    -- Primary KEY
  htp.print('               utc      CDATA #IMPLIED');    -- Date and Time String
  htp.print('               central  CDATA #IMPLIED');    -- Central Date and Time String
  htp.print('               lat      CDATA #IMPLIED');    -- Latitude  
  htp.print('               long     CDATA #IMPLIED');    -- Longitude 
  htp.print('               depth    CDATA #IMPLIED');    -- Depth of event
  htp.print('               mag      CDATA #IMPLIED');    -- Magnitude
  htp.print('               magtype  CDATA #IMPLIED');    -- Magnitude Type
  htp.print('               state    CDATA #IMPLIED');    -- State
  htp.print('               source   CDATA #IMPLIED>]>'); --Source
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred in dtd_and_columns(): '||SQLERRM);
  END dtd_and_columns;
--
--
END ok_earthquakes_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON  ok_earthquakes_pkg to apex_public_user;