-- ------------------------------------------------------------------------
-- * SQL:         db_create_brine_tables.sql Version 1.0 04/20/2015
-- * Author:      John R. Victorine
-- * Description: This File contains scripts to build brine tables.
-- * Copyright (c) 2015 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
-- ------------------------------------------------------------------------
set time on;
set echo on;
spool c:\PLSQL\IQSTRAT\db_create_brine_tables.lst;
--
-- ------------------------------------------------------------------------
-- TABLE: CO2_BRINE_LABORATORY
-- This Table holds the laboratory information doing analysis.
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.CO2_BRINE_LABORATORY(
     KID		NUMBER(10),
     Name		VARCHAR2(100),
     address		VARCHAR2(60),
     address2		VARCHAR2(60),
     city		VARCHAR2(60),
     state_code         NUMBER(2),	
     zipcode		VARCHAR2(10),
     telephone          VARCHAR2(12),
     telephone2         VARCHAR2(12),
     CONSTRAINT i_co2_brine_lab_p PRIMARY KEY (KID));
--
--
-- ------------------------------------------------------------------------
-- TABLE: CO2_BRINE_DATA_TYPE
-- This Table holds the Data Type Mnemonics and ID as reference to the measured data.
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.CO2_BRINE_DATA_TYPE(
     ID                 NUMBER(3),
     Mnemonic           VARCHAR2(10),
     Description        VARCHAR2(60),
     Other              VARCHAR2(60),
     CONSTRAINT i_co2_brine_data_type_p PRIMARY KEY (ID));
--
--
-- ------------------------------------------------------------------------
-- TABLE: CO2_BRINE_SAMPLE
-- This Table holds the common information for the brine sample data set
-- ------------------------------------------------------------------------
--
DROP TABLE IQSTRAT.CO2_BRINE_SAMPLE;
--
CREATE TABLE IQSTRAT.CO2_BRINE_SAMPLE(
     KID		NUMBER(10),
     Well_KID		NUMBER(10),	
     Lab_KID		NUMBER(10),	
     Lab_Number		VARCHAR2(60),
     Sampled_Date	DATE,
     Amount_Fluid	NUMBER(10),
     Amount_Fluid_Units	VARCHAR2(20),
     Recieved_Date	DATE,
     Reported_Date	DATE,
     File_Number	VARCHAR2(60),
     Order_Number	VARCHAR2(60),
     Sample_Number	VARCHAR2(60),
     Description	VARCHAR2(255),
     CONSTRAINT i_co2_brine_sample_p PRIMARY KEY (KID));
--
ALTER TABLE IQSTRAT.CO2_BRINE_SAMPLE ADD (
     Field_name         VARCHAR2(40));
--
UPDATE co2_brine_sample SET field_name = 'Wellington';
COMMIT;
--
ALTER TABLE IQSTRAT.CO2_BRINE_SAMPLE modify (
     Field_name         VARCHAR2(40) NOT NULL);
--
ALTER TABLE IQSTRAT.CO2_BRINE_SAMPLE ADD (
     Group_No           NUMBER(4));
ALTER TABLE IQSTRAT.CO2_BRINE_SAMPLE ADD (
     Group_ID           VARCHAR2(10));
--
--
--
-- ------------------------------------------------------------------------
-- TABLE: CO2_BRINE_DATA
-- This Table holds the the measured data.
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.CO2_BRINE_DATA(
     Sample_KID		NUMBER(10),	
     Data_Type_KID	NUMBER(3),	
     Analysis		VARCHAR2(100),
     Value		VARCHAR2(20),
     Units		VARCHAR2(20),
     CONSTRAINT i_co2_brine_data_p PRIMARY KEY (Sample_KID, Data_Type_KID));
--
--
-- ------------------------------------------------------------------------
-- TABLE: CO2_BRINE_ANALYSIS
-- This Table holds the miscellaneous information for the measured data.
-- ------------------------------------------------------------------------
--
DROP TABLE IQSTRAT.CO2_BRINE_ANALYSIS;
--
CREATE TABLE IQSTRAT.CO2_BRINE_ANALYSIS(
     Sample_KID		NUMBER(10),	
     Data_Type_KID	NUMBER(3),	
     Dilation_Factor    VARCHAR2(20),
     LoQ		VARCHAR2(20),
     Book_Page		VARCHAR2(60),
     QC_Batch		VARCHAR2(60),
     INST_Batch         VARCHAR2(60),
     Prepared_Date	DATE,
     Analyzed_Date	DATE,
     Analyst		VARCHAR2(20),
     Method             VARCHAR2(60),
     CONSTRAINT i_co2_brine_analysis_p PRIMARY KEY (Sample_KID, Data_Type_KID));
--
ALTER TABLE IQSTRAT.CO2_BRINE_ANALYSIS ADD (
     Kit_Number         VARCHAR2(60),
     Test_Range         VARCHAR2(225));
--
--
-- ------------------------------------------------------------------------
-- TABLE: CO2_BRINE_WELLS
-- This Table holds the well header information for wells.  This was created
-- because the information for SW-3 did not exist in the KGS water well 
-- database.
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.CO2_brine_Wells(
     KID                    NUMBER(10),
     STATE_CODE             NUMBER(2),
     COUNTY_CODE            NUMBER(3),
     NAME                   VARCHAR2(60),
     TOWNSHIP               NUMBER(3),
     TOWNSHIP_DIRECTION     VARCHAR2(1),
     RANGE                  NUMBER(3),
     RANGE_DIRECTION        VARCHAR2(1),
     SECTION                NUMBER(2),
     SUBDIVISION_1_LARGEST  VARCHAR2(2),
     SUBDIVISION_2          VARCHAR2(2),
     SUBDIVISION_3          VARCHAR2(2),
     SUBDIVISION_4_SMALLEST VARCHAR2(2),
     STATUS                 VARCHAR2(20),
     ELEVATION_KB           NUMBER(10,4),
     ELEVATION_GL           NUMBER(10,4),
     ELEVATION_DF           NUMBER(10,4),
     ROTARY_TOTAL_DEPTH     NUMBER(5),
     API_NUMBER             VARCHAR2(40),
     NAD27_LATITUDE         NUMBER(12,7),
     NAD27_LONGITUDE        NUMBER(12,7),
     NAD27_UTM_X            NUMBER(12,2),
     NAD27_UTM_Y            NUMBER(12,2),
     NAD27_UTM_ZONE         NUMBER(2),
     CONSTRAINT i_co2_brine_wells_p PRIMARY KEY (KID));
--
--
--
CREATE TABLE IQSTRAT.CO2_brine_well AS
	SELECT KID,
	       api_number,
	       lease_name,
	       well_name,
	       township,
	       township_direction,
	       range,
	       range_direction,
	       section,
	       status,
	       elevation_kb,
	       elevation_gl,
	       elevation_df,
	       rotary_total_depth,
	       nad27_latitude,
	       nad27_longitude,
	       nad27_utm_x,
	       nad27_utm_y,
	       nad27_utm_zone
	  FROM qualified.well_headers qwh	  
	 WHERE qwh.kid IN (SELECT UNIQUE(well_kid)
	                    FROM co2_brine_sample);
--
--
spool off;
set time off;
set echo off;
