-- ------------------------------------------------------------------------
-- * SQL:         db_create_co2_pressure_data_tables.sql Version 1.0 06/15/2015
-- * Author:      John R. Victorine
-- * Description: This File contains scripts to build seismic data tables.
-- * Copyright (c) 2015 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
-- ------------------------------------------------------------------------
set time on;
set echo on;
spool c:\PLSQL\IQSTRAT\db_create_co2_pressure_data_tables.lst;
--
-- ------------------------------------------------------------------------
-- TABLE: PRESSURE_FILES
-- This Table holds the location informationn for the pressure data CSV files.
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.PRESSURE_FILES(
    KID                 NUMBER(10),     -- Primary Key for table
    file_type           VARCHAR2(10),   -- XML, CSV, etc
    file_URL            VARCHAR2(255),  -- Base URL to the File
    file_path           VARCHAR2(255),  -- Directory Path to File
    file_name           VARCHAR2(255),  -- Filename
    zone                VARCHAR2(100),  -- Time Zone
    start_date          DATE,           -- Start Date
    end_date            DATE,           -- End Date
    CONSTRAINT i_pressure_files_p PRIMARY KEY (KID));
--
--
ALTER TABLE IQSTRAT.PRESSURE_FILES ADD (
     psi_corr          NUMBER(12,6));
--     
UPDATE iqstrat.pressure_files
   SET psi_corr = 0.0;
COMMIT;
--
--
ALTER TABLE IQSTRAT.PRESSURE_FILES ADD (
     psi_hrs_from_utc    NUMBER(3));
--     
UPDATE iqstrat.pressure_files
   SET psi_corr = 5;
COMMIT;
--
--
-- ------------------------------------------------------------------------
-- TABLE: PRESSURE_DATA_FILES
-- This Table holds the location informationn for the pressure output files.
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.PRESSURE_DATA_FILES(
    KID                 NUMBER(10),     -- Primary Key for table also reference to pressure_files.kid
    file_type           VARCHAR2(10),   -- XML, CSV, etc
    file_URL            VARCHAR2(255),  -- Base URL to the File
    file_path           VARCHAR2(255),  -- Directory Path to File
    file_name           VARCHAR2(255),  -- Filename
    CONSTRAINT i_pressure_data_files_p PRIMARY KEY (KID, file_type));
--
--
-- ------------------------------------------------------------------------
-- TABLE: PRESSURE_PLOT_INFO
-- This Table holds the plot parameters data information.
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.PRESSURE_PLOT_INFO(
    KID                 NUMBER(10),     -- Primary Key for table also reference to pressure_files.kid
    aquifer_porosity    NUMBER(6,4),    -- Aquifer Porosity [PU]
    aquifer_temperature NUMBER(12,4),   -- Aquifer Temperature [degrees F]
    compressibility     NUMBER(12,6),   -- Compressibility of fluid (Cw) [1/Pa]
    psi_slope_start     NUMBER(12,6),   -- Pressure Slope Start [psi]
    psi_slope_end       NUMBER(12,6),   -- Pressure Slope End [psi]
    correction          NUMBER(12,6),   -- Correction due to start time [degrees]
    Scale_Minimum       NUMBER(12,6),   -- Plot Scale Minimum
    Scale_Maximum       NUMBER(12,6),   -- Plot Scale Maximum
    CONSTRAINT i_pressure_plot_info_p PRIMARY KEY (KID));
--
ALTER TABLE IQSTRAT.PRESSURE_PLOT_INFO ADD (
     baro_eff           NUMBER(12,6));
--
-- ------------------------------------------------------------------------
-- TABLE: EVENTS_BY_DAY
-- This Table holds the data for events by day
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.EVENTS_BY_DAY(
    KID                 NUMBER(10),     -- Primary Key for table
    pressure_files_kid  NUMBER(10),     -- Primary Key of the Pressure file
    zone                VARCHAR2(100),  -- Time Zone
    start_date          DATE,           -- Start Date
    end_date            DATE,           -- End Date
    aquifer_porosity    NUMBER(6,4),    -- Aquifer Porosity [PU]
    aquifer_temperature NUMBER(12,4),   -- Aquifer Temperature [degrees F]
    compressibility     NUMBER(12,6),   -- Compressibility of fluid (Cw) [1/Pa]
    psi_slope_start     NUMBER(12,6),   -- Pressure Slope Start [psi]
    psi_slope_end       NUMBER(12,6),   -- Pressure Slope End [psi]
    correction          NUMBER(12,6),   -- Correction due to start time [degrees]
    CONSTRAINT i_events_by_day_p PRIMARY KEY (KID));
--
--  1 - Earth = Earthquakes
--  2 - Air   = Barometric Pressure Changes
--  3 - Water = Brine (CO2) Injection
--
ALTER TABLE IQSTRAT.EVENTS_BY_DAY ADD (
     Type_No           NUMBER(2),
     Type_Description  VARCHAR2(255));
--
--
-- ------------------------------------------------------------------------
-- TABLE: EVENT_GROUP
-- This Table holds the data for event group
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.EVENT_GROUP(
    event_by_day_KID    NUMBER(10),     -- Primary Key for the events by day table
    group_id            VARCHAR2(50),   -- Group ID Phrase, etc.
    event_no            NUMBER(5),      -- event number
    description         VARCHAR2(255),  -- Description of the event
    zone                VARCHAR2(100),  -- Time Zone
    start_date          DATE,           -- Start Date/time
    end_date            DATE,           -- End Date/time
    event_date          DATE,		-- Event Date/time
    event_magnitude	NUMBER(12,6),   -- Maximum or Minimum value of the Event
    event_base 		NUMBER(12,6),   -- Slope at the Minimum or Maximum Value
    event_units		VARCHAR2(20),   -- the units of the data 
    CONSTRAINT i_event_group_p PRIMARY KEY (event_by_day_KID, group_id, event_no));
--
--
spool off;
