-- ------------------------------------------------------------------------
-- * SQL:         db_create_co2_seismic_tables.sql Version 1.0 06/15/2015
-- * Author:      John R. Victorine
-- * Description: This File contains scripts to build seismic data tables.
-- * Copyright (c) 2015 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
-- ------------------------------------------------------------------------
set time on;
set echo on;
spool c:\PLSQL\IQSTRAT\db_create_co2_seismic_tables.lst;
--
-- ------------------------------------------------------------------------
-- TABLE: CO2_EVENTS
-- This Table holds the events computed by ALEX.
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.CO2_EVENTS(
    KID		NUMBER(10),
    EVENT       DATE,
    LATITUDE   	NUMBER(12,7),
    LONGITUDE  	NUMBER(12,7),
    DEPTH     	NUMBER(13,7),
    UNITS	VARCHAR2(4),
    TES         VARCHAR2(20),
    LOCAL_MAG	NUMBER(6,3),
    MOMENT_MAG	NUMBER(6,3),
    CONSTRAINT i_co2_events_p PRIMARY KEY (KID));
--    
--
-- ------------------------------------------------------------------------
-- TABLE: CO2_SEISMIC_SENSORS
-- This Table holds the location informationn for the seismic sensors.
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.CO2_SEISMIC_SENSORS(
    KID			NUMBER(10),
    ID		     	NUMBER(4),
    NAME	     	VARCHAR2(60),
    NAD27_LATITUDE   	NUMBER(12,7),
    NAD27_LONGITUDE  	NUMBER(12,7),
    ELEVATION_GL     	NUMBER(10,4),
    CONSTRAINT i_co2_seismic_sensors_p PRIMARY KEY (KID));
--
--
-- ------------------------------------------------------------------------
-- TABLE: CO2_SENSOR_RAW
-- This Table holds the raw data for a single event.
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.CO2_SENSOR_RAW(
    KID			NUMBER(10),
    SENSOR_KID		NUMBER(10),
    CHANNEL		VARCHAR2(20),
    EVENT_TIME		DATE,
    EVENT_MAGNITUDE	NUMBER(6,3),
    SENSOR_ORDER	NUMBER(2),
    SP_TIME_DIFF	NUMBER(12,7),
    SP_TIME_UNITS	VARCHAR(20),
    S_WAVE_ARRIVAL	DATE,
    P_WAVE_ARRIVAL	DATE,
    Vp			NUMBER(20,9),
    Vs			NUMBER(20,9),
    DISTANCE		NUMBER(20,9),
    VELOCITY_UNITS	VARCHAR2(20),
    DISTANCE_UNITS	VARCHAR2(20),
    CONSTRAINT i_co2_sensor_raw_p PRIMARY KEY (KID));
--
--
-- ------------------------------------------------------------------------
-- TABLE: CO2_EVENT_DISTANCE
-- This Table holds the computed data to predict the distance from a single
-- sensor to an event.
-- ------------------------------------------------------------------------
--
--CREATE TABLE IQSTRAT.CO2_EVENT_DISTANCE(
--    KID			NUMBER(10),
--    SENSOR_RAW_KID	NUMBER(10),
--    SENSOR_ORDER	NUMBER(2),
--    DATA_SET           	NUMBER(6),
--    Vp			NUMBER(20,9),
--    Vs			NUMBER(20,9),
--    DISTANCE		NUMBER(20,9),
--    VELOCITY_UNITS	VARCHAR2(20),
--    DISTANCE_UNITS	VARCHAR2(20),
--    CONSTRAINT i_co2_event_distace_p PRIMARY KEY (KID));
--
--
-- ------------------------------------------------------------------------
-- TABLE: CO2_EVENT_LOCATION
-- This Table holds the computed location of a sigle event.
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.CO2_EVENT_LOCATION(
    KID			NUMBER(10),
    EVENT_TIME		DATE,
    EVENT_MAGNITUDE	NUMBER(6,3),
    NAD27_LATITUDE   	NUMBER(12,7),
    NAD27_LONGITUDE  	NUMBER(12,7),
    DEPTH	     	NUMBER(13,7),
    DEPTH_UNITS		VARCHAR2(20),
    CONSTRAINT i_co2_event_location_p PRIMARY KEY (KID));
--
--
-- ------------------------------------------------------------------------
-- TABLE: CO2_MINISEED_ID
-- This Table holds the location informationn for the seismic sensors.
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.CO2_MINISEED_ID(
    KID			NUMBER(10),
    ID		     	VARCHAR2(10),
    NAME	     	VARCHAR2(60),
    NAD27_LATITUDE   	NUMBER(12,7),
    NAD27_LONGITUDE  	NUMBER(12,7),
    ELEVATION_GL     	NUMBER(10,4),
    CONSTRAINT i_co2_miniseed_id_p PRIMARY KEY (KID));
--
--
CREATE TABLE IQSTRAT.MINISEED_FILES(
    file_year           NUMBER(4),      -- Year of Seismic Files
    file_day            VARCHAR2(4),    -- Day of Seismic Files
    file_type           VARCHAR2(10),   -- m-miniseed fike
    file_URL            VARCHAR2(255),  -- Base URL to the File
    file_path           VARCHAR2(255),  -- Directory Path to File
    equiv_date          DATE,           -- Equivalent Date
    CONSTRAINT i_miniseed_files_p PRIMARY KEY (file_year, file_day));
--
ALTER TABLE IQSTRAT.MINISEED_FILES add (
     wk01         VARCHAR2(4),
     wk02         VARCHAR2(4),
     wk03         VARCHAR2(4),
     wk04         VARCHAR2(4),
     wk05         VARCHAR2(4),
     wk06         VARCHAR2(4),
     wk07         VARCHAR2(4),
     wk08         VARCHAR2(4),
     wk09         VARCHAR2(4),
     wk10         VARCHAR2(4),
     wk11         VARCHAR2(4),
     wk12         VARCHAR2(4),
     wk13         VARCHAR2(4),
     wk14         VARCHAR2(4),
     wk15         VARCHAR2(4));
--
UPDATE IQSTRAT.MINISEED_FILES
   SET wk01='YES',
       wk02='NO',
       wk03='YES',
       wk04='YES',
       wk05='YES',
       wk06='NO',
       wk07='YES',
       wk08='NO',
       wk09='NO',
       wk10='NO',
       wk11='YES',
       wk12='YES',
       wk13='NO',
       wk14='NO',
       wk15='NO';
COMMIT;       
--
--
spool off;
set time off;
set echo off;

