-- ------------------------------------------------------------------------
-- * SQL:         db_create_fluid_level_tables.sql Version 1.0 03/03/2016
-- * Author:      John R. Victorine
-- * Description: This File contains scripts to build brine tables.
-- * Copyright (c) 2016 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
-- ------------------------------------------------------------------------
set time on;
set echo on;
spool c:\PLSQL\IQSTRAT\db_create_fluid_level_tables.lst;
--
-- ------------------------------------------------------------------------
-- TABLE: CO2_Producer_Test_Data
-- This Table holds the Producer Test Data for monitoring wells
-- ------------------------------------------------------------------------
--
CREATE TABLE IQSTRAT.CO2_well_static_data(
     Well_KID				NUMBER(10),
     joints_in_well			NUMBER(6),
     open_hole_start_depth_ft		NUMBER(8,2),
     open_hole_end_depth_ft		NUMBER(8,2),
     open_hole_mid_depth_ft		NUMBER(8,2),
     SN_depth_ft			NUMBER(8,2),
     Avg_Joint_Length_ft		NUMBER(6,2),
     specific_gravity_water		NUMBER(8,5),
     CONSTRAINT i_co2_well_static_data_p PRIMARY KEY (Well_KID));
--
--
CREATE TABLE IQSTRAT.CO2_static_by_dates(
     Well_KID				NUMBER(10),
     measured_date			DATE,
     joints_to_fluid			NUMBER(6,2),
     bottom_hole_pressure_psig		NUMBER(12,2),
     CONSTRAINT i_co2_static_by_dates_p PRIMARY KEY (Well_KID,measured_date));
--
--
CREATE TABLE IQSTRAT.CO2_Producer_Test_Data(
     Well_KID				NUMBER(10),
     test_date				DATE,
     total_fluid_bbl			NUMBER(12,4),
     oil_cut_perc			NUMBER(14,7),
     fluid_levels_ft			NUMBER(12,2),
     joints_in_well			NUMBER(6),
     barrels_of_oil_per_day		NUMBER(18,8),
     est_bottom_hole_pressure_psig	NUMBER(12,2),
     CONSTRAINT i_co2_producer_test_p PRIMARY KEY (Well_KID,test_date));
--
ALTER TABLE IQSTRAT.CO2_Producer_Test_Data ADD (
     Group_No           NUMBER(4),
     Group_ID           VARCHAR2(10));
--
--
CREATE TABLE IQSTRAT.CO2_Injection_Data(
     Well_KID				NUMBER(10),
     inj_date				DATE,
     barrels_of_water_per_day		NUMBER(18,8),
     barrels_of_CO2_per_day		NUMBER(18,8),
     tubing_pressure_psig		NUMBER(12,2),
     comments				VARCHAR2(255),
     CONSTRAINT i_co2_injection_p PRIMARY KEY (Well_KID,inj_date));
--
ALTER TABLE IQSTRAT.CO2_Injection_Data ADD (
     tons_of_CO2_per_day		NUMBER(18,8));
--
ALTER TABLE IQSTRAT.CO2_Injection_Data ADD (
     depth			     	NUMBER(13,7),
     injection_zone			VARCHAR2(255),
     days_of_injection			NUMBER(3),
     max_inj_pressure_psi		NUMBER(12,2));
--
--
CREATE TABLE IQSTRAT.CO2_and_Offset_Gas(
     Well_KID				NUMBER(10),
     measured_date			DATE,
     CO2_percent			NUMBER(6,2),
     GAS_MCF_per_day 			NUMBER(8,2),
     CONSTRAINT i_co2_and_offset_gas_p PRIMARY KEY (Well_KID,measured_date));
--
ALTER TABLE IQSTRAT.CO2_and_Offset_Gas ADD (
     Group_No           NUMBER(4),
     Group_ID           VARCHAR2(10));
--
--
spool off;
set time off;
set echo off;
